from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_ST_STM32G0 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'STM32G030C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030C_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030J6Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030J6Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030j6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030J6Mx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC14/PB7/PB8/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NRST/PA0/PA1/PA2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PB0/PB1/PA8/PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/PA15/PB5/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030K_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C_4-6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C_4-6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C_4-6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C_4-6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C_4-6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C_4-6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031F_4-6-8_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031F_4-6-8_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031F_4-6-8_Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031G_4-6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031G_4-6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031g4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031G_4-6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031J_4-6_Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031J_4-6_Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031j4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031J_4-6_Mx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14/PB7/PB8/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB0/PB1/PA8/PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/PA15/PB5/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K_4-6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K_4-6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K_4-6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K_4-6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K_4-6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K_4-6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031Y8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031Y8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-18_1.86x2.14mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-18_1.86x2.14mm_P0.4mm_Stagger', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031y8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031Y8Yx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA3/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF2/PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041F_6-8_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041F_6-8_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041F_6-8_Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041G_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041G_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041G_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041J6Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041J6Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041j6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041J6Mx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14/PB7/PB8/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB0/PB1/PA8/PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/PA15/PB5/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041Y8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041Y8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-18_1.86x2.14mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-18_1.86x2.14mm_P0.4mm_Stagger', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041y8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041Y8Yx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA3/PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PF2/PA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G050C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G050C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g050c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G050C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G050C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G050C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g050c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G050C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G050F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G050F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g050f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G050F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G050K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G050K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g050k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G050K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G050K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G050K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g050k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G050K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051F8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051F8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-20_1.94x2.40mm_Layout4x5_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-20_1.94x2.40mm_Layout4x5_P0.4mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051F8Yx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051F_6-8_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051F_6-8_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051F_6-8_Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051G_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051G_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051G_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061F8Yx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061F8Yx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-20_1.94x2.40mm_Layout4x5_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-20_1.94x2.40mm_Layout4x5_P0.4mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061F8Yx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PF2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061F_6-8_Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061F_6-8_Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061F_6-8_Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061G_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061G_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061G_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K_6-8_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K_6-8_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K_6-8_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K_6-8_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K_6-8_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K_6-8_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G070CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G070CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g070cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G070CBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G070KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G070KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g070kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G070KBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G070RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G070RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g070rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G070RBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C_6-8-B_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C_6-8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C_6-8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C_6-8-B_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071EBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071EBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-25_2.30x2.48mm_Layout5x5_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-25_2.30x2.48mm_Layout5x5_P0.4mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071eb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071EBYx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071G_6-8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071G_6-8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071g.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071G_6-8-B_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071G_8-B_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071G_8-B_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071G_8-B_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K_6-8-B_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K_6-8-B_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K_6-8-B_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K_6-8-B_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K_8-B_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K_8-B_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K_8-B_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K_8-B_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K_8-B_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K_8-B_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071RBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071RBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071RBIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071R_6-8-B_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071R_6-8-B_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071r.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071R_6-8-B_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081CBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081CBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081EBYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081EBYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-25_2.30x2.48mm_Layout5x5_P0.4mm'], 'footprint':'Package_CSP:ST_WLCSP-25_2.30x2.48mm_Layout5x5_P0.4mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081eb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081EBYx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PF2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081GBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081GBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081gb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081GBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081GBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081GBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081gb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081GBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081KBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081KBTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081KBTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081KBTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081KBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081KBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081KBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081KBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081KBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081KBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081RBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081RBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081RBIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G081RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G081RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g081rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G081RBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B0CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B0CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b0ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B0CETx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B0KETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B0KETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b0ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B0KETx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B0RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B0RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b0re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B0RETx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B0VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B0VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b0ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B0VETx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1C_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1C_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1C_B-C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1C_B-C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1C_B-C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1C_B-C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1C_B-C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1C_B-C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1C_B-C-E_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1C_B-C-E_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1C_B-C-E_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1C_B-C-E_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1K_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1K_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1K_B-C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1K_B-C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1K_B-C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1K_B-C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1K_B-C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1K_B-C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1K_B-C-E_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1K_B-C-E_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1K_B-C-E_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1K_B-C-E_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1M_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1M_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1M_B-C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1NEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1NEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-52_3.09x3.15mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-52_3.09x3.15mm_P0.4mm_Stagger', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1NEYx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1R_B-C-E_IxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1R_B-C-E_IxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1R_B-C-E_IxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1R_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1R_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1R_B-C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1R_B-C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1R_B-C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1R_B-C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1V_B-C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1V_B-C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1V_B-C-E_Ix\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1V_B-C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1V_B-C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1V_B-C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1C_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1C_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1C_C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1C_C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1C_C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1C_C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1C_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1C_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1C_C-E_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1C_C-E_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1C_C-E_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1C_C-E_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1K_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1K_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1K_C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1K_C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1K_C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1K_C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1K_C-E_Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1K_C-E_Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1K_C-E_Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1K_C-E_UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1K_C-E_UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1K_C-E_UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1M_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1M_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1M_C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1NEYx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1NEYx'}), 'ref_prefix':'U', 'fplist':['Package_CSP:ST_WLCSP-52_3.09x3.15mm_P0.4mm_Stagger'], 'footprint':'Package_CSP:ST_WLCSP-52_3.09x3.15mm_P0.4mm_Stagger', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ne.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1NEYx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A10',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='B13',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='C12',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='D11',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='F13',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F9',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='H13',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='PA7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1R_C-E_IxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1R_C-E_IxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1R_C-E_IxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1R_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1R_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1R_C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1R_C-E_TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1R_C-E_TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1R_C-E_TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1V_C-E_Ix', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1V_C-E_Ix'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1V_C-E_Ix\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1V_C-E_Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1V_C-E_Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1V_C-E_Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G030K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G030K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g030k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G030K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x0 Value line', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NRST',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C4Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C4Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031C8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031F4Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031F4Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031f4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031F4Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031F8Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031F8Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031F8Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031G4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031G4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031g4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031G4Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031G6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031G8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031G8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031G8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031J4Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031J4Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031j4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031J4Mx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14/PB7/PB8/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB0/PB1/PA8/PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/PA15/PB5/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031J6Mx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031J6Mx'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031j6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031J6Mx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14/PB7/PB8/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PF2/PA0/PA1/PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PB0/PB1/PA8/PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA14/PA15/PB5/PB6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K4Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K4Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K4Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K4Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K4Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k4.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K4Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G031K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G031K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g031k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G031K8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041C8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041F8Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041F8Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041F8Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041G6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041G8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041G8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041G8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G041K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G041K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g041k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G041K8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051C8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051F8Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051F8Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051F8Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051G6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051G8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051G8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051G8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G051K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G051K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g051k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G051K8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061C8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061F6Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061F6Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061f6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061F6Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061F8Px', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061F8Px'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061f8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061F8Px\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB7/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0/PB1/PB2/PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA14/PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14/PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3/PB4/PB5/PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061G6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061G8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061G8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061G8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G061K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G061K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g061k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G061K8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/NC',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071C8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071C8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071c8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071C8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071CBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071CBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071G6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071G6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071g6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071G6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071G8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071G8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071G8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071G8UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071G8UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071g8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071G8UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071GBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071GBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071gb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071GBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071GBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071GBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm'], 'footprint':'Package_DFN_QFN:QFN-28_4x4mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071gb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071GBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K6Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K6Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K6Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K8TxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K8TxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K8TxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K8Ux', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K8Ux'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K8Ux\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071K8UxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071K8UxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071k8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071K8UxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071KBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071KBTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071KBTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071KBTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071KBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071KBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071KBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071KBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071KBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071KBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071R6Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071R6Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071r6.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071R6Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071R8Tx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071R8Tx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071r8.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071R8Tx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G071RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G071RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g071rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G071RBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CBTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CBTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CBTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CCUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CCUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CCUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CCUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CEUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1CEUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1CEUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1CEUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KBTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KBTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KBTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KBUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KBUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KBUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KBUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KBUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KBUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KCUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KCUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KCUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KCUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KEUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1KEUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1KEUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1KEUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1MBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1MBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1mb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1MBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1MCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1MCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1MCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1METx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RBIxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RBIxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RBIxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RBTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RBTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RBTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RCIxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RCIxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RCIxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1REIxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1REIxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1REIxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1RETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1RETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1RETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VBIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VBIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VBIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VBTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VBTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vb.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VBTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VCIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VEIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0B1VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0B1VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0b1ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0B1VETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CCUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CCUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CCUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1cc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CCUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CEUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1CEUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1CEUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.6x5.6mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ce.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1CEUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PF1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KCUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KCUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KCUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KCUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KCUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1kc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KCUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'Package_QFP:LQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:LQFP-32_7x7mm_P0.8mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KEUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KEUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KEUx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1KEUxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1KEUxN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ke.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1KEUxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1MCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1MCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1mc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1MCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1METx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1METx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'Package_QFP:LQFP-80_12x12mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-80_12x12mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1me.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1METx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='80',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VREF+',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1RCIxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1RCIxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1RCIxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1RCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1RCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1RCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1RCTxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1RCTxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1rc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1RCTxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1REIxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1REIxN'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm'], 'footprint':'Package_BGA:UFBGA-64_5x5mm_Layout8x8_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1REIxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='D3',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='E2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='PB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1RETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1RETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1RETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1RETxN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1RETxN'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1re.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1RETxN\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1VCIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1VCIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1VCIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1VCTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1VCTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1vc.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1VCTx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1VEIx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1VEIx'}), 'ref_prefix':'U', 'fplist':['Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:UFBGA-100_7x7mm_Layout12x12_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1VEIx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='A1',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='C10',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='D10',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='E10',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='E3',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='F11',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='G11',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='H10',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K4',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='K5',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='K8',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='K9',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='PE11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STM32G0C1VETx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STM32G0C1VETx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'Arm Cortex-M0+ STM32G0 STM32G0x1', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stm32g0c1ve.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_ST_STM32G0.kicad_sym\nSTM32G0C1VETx\n\nArm Cortex-M0+ STM32G0 STM32G0x1', 'pins':[
            Pin(num='1',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREF+',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC10',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC11',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PE8',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PE9',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE10',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PE11',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PE12',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PE13',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PE14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PE15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PA9/UCPD1_DBCC1',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PD8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PD9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PD10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PD11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='VDDIO2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='PD12',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='PD13',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='PD14',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='PD15',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='PA10/UCPD1_DBCC2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PC12',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PA11/PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='PA12/PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='PF8',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='PA13',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='PA14',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='PC8',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='PC9',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='PF9',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='PF10',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='PF11',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='PF12',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='PF13',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='PB7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])