from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_Filter = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'BFCN-1445', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1445'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1445+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1445\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-152W-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-152W-75'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-7'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-7', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1445+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-152W-75\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1560', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1560'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1560+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1560\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1860', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1860'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1860+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1860\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1900'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-5'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-5', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1900+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1900\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-5100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-5100'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-6'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-6', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-5100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-5100\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BPF-A355', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BPF-A355'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HQ1157'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HQ1157', 'keywords':'Bandpass Filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BPF-A355+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBPF-A355\n\nBandpass Filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1322', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1322'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1322+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1322\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-440', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-440'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-440+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-440\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-672', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-672'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-672+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-672\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-113', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-113'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-113+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-113\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-80'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-80+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-80\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPF-B0R3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPF-B0R3'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HZ1198_LandPatternPL-247'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HZ1198_LandPatternPL-247', 'keywords':'low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LPF-B0R3+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLPF-B0R3\n\nlow pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RBP-280', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RBP-280'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_GP731_LandPatternPL-176'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_GP731_LandPatternPL-176', 'keywords':'bandpass filter rf', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/RBP-280+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nRBP-280\n\nbandpass filter rf', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RBPF-246', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RBPF-246'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CK605_LandPatternPL-012'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CK605_LandPatternPL-012', 'keywords':'Bandpass Filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/RBPF-246+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nRBPF-246\n\nBandpass Filter', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RLP-30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RLP-30'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_GP1212_LandPatternPL-176'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_GP1212_LandPatternPL-176', 'keywords':'Low Pass Filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/RLP-30+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nRLP-30\n\nLow Pass Filter', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SCHF-31', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SCHF-31'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_YY161_LandPatternPL-049'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_YY161_LandPatternPL-049', 'keywords':'highpass filter rf', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/SCHF-31+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSCHF-31\n\nhighpass filter rf', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SXBP-140', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SXBP-140'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'keywords':'Mini-Circuits Band-Pass Filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/SXBP-140+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSXBP-140\n\nMini-Circuits Band-Pass Filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TA0232A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TA0232A'}), 'ref_prefix':'X', 'fplist':['Filter:Filter_SAW-8_3.8x3.8mm'], 'footprint':'Filter:Filter_SAW-8_3.8x3.8mm', 'keywords':'SAW Filter 1090 bandpass', 'description':'', 'datasheet':'https://www.golledge.com/media/1831/ma05497.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nTA0232A\n\nSAW Filter 1090 bandpass', 'pins':[
            Pin(num='1',name='IN_1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN_2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TA0970B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TA0970B'}), 'ref_prefix':'X', 'fplist':['Filter:Filter_SAW-6_3.8x3.8mm'], 'footprint':'Filter:Filter_SAW-6_3.8x3.8mm', 'keywords':'SAW Filter 1090 bandpass MP08167', 'description':'', 'datasheet':'https://www.golledge.com/media/3785/mp08167.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nTA0970B\n\nSAW Filter 1090 bandpass MP08167', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B3715', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B3715'}), 'ref_prefix':'X', 'fplist':['Filter:Filter_SAW-6_3.8x3.8mm', 'Filter:Filter_SAW_Epcos_DCC6C_3x3mm'], 'footprint':'Filter:Filter_SAW-6_3.8x3.8mm', 'keywords':'SAW Filter 869 bandpass', 'description':'', 'datasheet':'https://www.mouser.de/datasheet/2/842/epcos16633_1-2300371.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nB3715\n\nSAW Filter 869 bandpass', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1525', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1525'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1525+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1525\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1575', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1575'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1575+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1575\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1690', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1690'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1690+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1690\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1840', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1840'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1840+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1840\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1855', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1855'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1855+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1855\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-1945', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-1945'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-1945+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-1945\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2275', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2275'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2275+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2275\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2360', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2360'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2360+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2360\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2435', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2435'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2435+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2435\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2450', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2450'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2450+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2450\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2500\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2555', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2555'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2555+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2555\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2700\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2840', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2840'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2840+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2840\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2850', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2850'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2850+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2850\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2900'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2900+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2900\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2910', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2910'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2910+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2910\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-2975', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-2975'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-2975+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-2975\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3010', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3010'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3010+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3010\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3085', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3085'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3085+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3085\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3085A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3085A'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3085A+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3085A\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3115', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3115'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3115+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3115\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3600'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3600+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3600\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-3700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-3700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-3700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-3700\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-4100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-4100'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-4100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-4100\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-4440', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-4440'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-4440+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-4440\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-4800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-4800'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-4800+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-4800\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-5200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-5200'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-5200+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-5200\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-5540', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-5540'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-5540+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-5540\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-5750', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-5750'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-5750+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-5750\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7200'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7200+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7200\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7331', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7331'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7331+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7331\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7350'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7350+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7350\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7500\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7700\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-7900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-7900'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-7900+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-7900\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-8000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-8000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-8000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-8000\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-8350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-8350'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-8350+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-8350\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-8450', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-8450'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-8450+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-8450\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BFCN-8650', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BFCN-8650'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits band pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/BFCN-8650+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nBFCN-8650\n\nMini-Circuits band pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1000\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1080', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1080'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1080+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1080\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1100'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1100\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1150'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1150+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1150\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1200'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1200+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1200\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1200D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1200D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1200D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1200D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1300'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1300+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1300\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1300D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1300D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1300D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1300D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1320'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1320+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1320\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1320D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1320D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1320D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1320D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1500\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1500D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1600'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1600+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1600\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1600D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1600D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1600D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1600D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1760', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1760'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1760+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1760\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1810'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1810+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1810\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1810D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1810D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1810D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1810D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1910', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1910'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1910+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1910\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-1910D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-1910D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-1910D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-1910D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2000.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2000\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2100'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2100\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2100D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2100D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2100D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2100D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2275', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2275'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2275+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2275\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2700\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2700A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2700A'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2700A+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2700A\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-2700AD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-2700AD'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-2700AD+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-2700AD\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3100'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3100\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3100D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3100D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3100D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3100D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3500\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3500D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3800'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3800+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3800\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-3800D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-3800D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-3800D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-3800D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-4400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-4400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-4400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-4400\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-4400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-4400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-4400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-4400D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-4600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-4600'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-4600+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-4600\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-5050', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-5050'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-5050+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-5050\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-5500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-5500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-5500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-5500\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-5500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-5500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-5500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-5500D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-6010', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-6010'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-6010+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-6010\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-650', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-650'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-650+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-650\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-650D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-650D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-650D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-650D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-7150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-7150'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-7150+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-7150\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-740', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-740'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-740+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-740\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-740D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-740D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-740D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-740D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-7971', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-7971'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-7971+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-7971\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-8400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-8400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-8400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-8400\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-8400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-8400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1', 'Filter:Filter_Mini-Circuits_FV1206-1'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-1', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-8400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-8400D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-880', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-880'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-880+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-880\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-880D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-880D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-880D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-880D\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HFCN-9700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HFCN-9700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits high pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/HFCN-9700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nHFCN-9700\n\nMini-Circuits high pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1000\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1000D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1000D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1000D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1000D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-105', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-105'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-105+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-105\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-120'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-120+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-120\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1200'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1200+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1200\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1200D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1200D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1200D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1200D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-123'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-123+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-123\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1282', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1282'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1282+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1282\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1325', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1325'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1325+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1325\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1450', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1450'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1450+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1450\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1500\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1500D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1525', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1525'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1525+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1525\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1525D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1525D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1525D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1525D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1575', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1575'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1575+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1575\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1575D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1575D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1575D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1575D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-160'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-160+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-160\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1700\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1700D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1700D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1700D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1700D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-180', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-180'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-180+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-180\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1800'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1800+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1800\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-1800D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-1800D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-1800D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-1800D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-190', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-190'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-190+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-190\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2000\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2000D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2000D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2000D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2000D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-225', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-225'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-225+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-225\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2250', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2250'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2250+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2250\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2250D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2250D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2250D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2250D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-225D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-225D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-225D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-225D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2290', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2290'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2290+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2290\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2500\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2500D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2600'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2600+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2600\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2600D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2600D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2600D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2600D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2750', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2750'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2750+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2750\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2750D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2750D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2750D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2750D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2850', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2850'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2850+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2850\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-2850D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-2850D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-2850D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-2850D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3000\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3000D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3000D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3000D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3000D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-320'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-320+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-320\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-320D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-320D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-320D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-320D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3800'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3800+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3800\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-3800D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-3800D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-3800D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-3800D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-4400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-4400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-4400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-4400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-4400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-4400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-4400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-4400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-490', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-490'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-490+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-490\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-490D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-490D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-490D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-490D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5000\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5000D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5000D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5000D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5000D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-530', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-530'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-530+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-530\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-530D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-530D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-530D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-530D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5500', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5500'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5500+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5500\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5500D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5500D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5500D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5500D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-575', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-575'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-575+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-575\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-575D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-575D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-575D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-575D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5850', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5850'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5850+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5850\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-5850D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-5850D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-5850D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-5850D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6000'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6000+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6000\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6000D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6000D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6000D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6000D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-630', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-630'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-630+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-630\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-630D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-630D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-630D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-630D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6400D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6400D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6400D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6400D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6700', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6700'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6700+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6700\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-6700D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-6700D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-6700D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-6700D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-7200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-7200'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-7200+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-7200\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-7200D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-7200D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-7200D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-7200D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-722', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-722'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-722+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-722\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-800', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-800'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-800+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-800\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-800D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-800D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-800D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-800D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-8400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-8400'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-8400+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-8400\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-8440', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-8440'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-8440+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-8440\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-900'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-900+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-900\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-900D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-900D'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-900D+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-900D\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-9170', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-9170'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4', 'Filter:Filter_Mini-Circuits_FV1206-4'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206-4', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-9170+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-9170\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LFCN-95', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LFCN-95'}), 'ref_prefix':'FL', 'fplist':['Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206', 'Filter:Filter_Mini-Circuits_FV1206'], 'footprint':'Filter:Filter_Mini-Circuits_FV1206', 'keywords':'Mini-Circuits low pass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/LFCN-95+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nLFCN-95\n\nMini-Circuits low pass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STA0232A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STA0232A'}), 'ref_prefix':'X', 'fplist':['Filter:Filter_SAW-8_3.8x3.8mm', 'Filter:Filter_SAW-8_3.8x3.8mm'], 'footprint':'Filter:Filter_SAW-8_3.8x3.8mm', 'keywords':'SAW Filter 1090 bandpass', 'description':'', 'datasheet':'https://www.golledge.com/media/1831/ma05497.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSTA0232A\n\nSAW Filter 1090 bandpass', 'pins':[
            Pin(num='1',name='IN_1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN_2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT_1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='OUT_2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STA1090EC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STA1090EC'}), 'ref_prefix':'X', 'fplist':['Filter:Filter_SAW-6_3.8x3.8mm', 'Filter:Filter_SAW_Epcos_DCC6C_3x3mm', 'Filter:Filter_SAW-6_3.8x3.8mm'], 'footprint':'Filter:Filter_SAW-6_3.8x3.8mm', 'keywords':'SAW Filter 1090 bandpass', 'description':'', 'datasheet':'https://www.golledge.com/media/3785/mp08167.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSTA1090EC\n\nSAW Filter 1090 bandpass', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SXBP-100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SXBP-100'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'keywords':'bandpass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/SXBP-100+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSXBP-100\n\nbandpass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SXBP-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SXBP-202'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'keywords':'bandpass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/SXBP-202+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSXBP-202\n\nbandpass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SXBP-27R5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SXBP-27R5'}), 'ref_prefix':'U', 'fplist':['RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_HF1139_LandPatternPL-230', 'keywords':'bandpass filter', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/SXBP-27R5+.pdf', 'search_text':'/usr/share/kicad/symbols/RF_Filter.kicad_sym\nSXBP-27R5\n\nbandpass filter', 'pins':[
            Pin(num='1',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] })])