from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Diode = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'1.5KExxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1.5KExxA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'transient voltage suppressor TRANSZORBÂ®', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1.5KExxA\n\ntransient voltage suppressor TRANSZORBÂ®', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1.5KExxCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1.5KExxCA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'transient voltage suppressor TRANSZORBÂ®', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1.5KExxCA\n\ntransient voltage suppressor TRANSZORBÂ®', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4001'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4001\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5711UR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5711UR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MELF'], 'footprint':'Diode_SMD:D_MELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/131890-lds-0040-1-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5711UR\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5820', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5820'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88526/1n5820.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5820\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N6263', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N6263'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/1n6263.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N6263\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'2BZX84Cxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'2BZX84Cxx'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/bzx84c2v4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n2BZX84Cxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B120-E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B120-E3'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88946/b120.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB120-E3\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B220', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B220'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB220\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B320', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B320'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB320\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAR42FILM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAR42FILM'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/bar42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAR42FILM\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS16TW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS16TW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30154.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS16TW\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'BAS16W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS16W'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAS16_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS16W\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS40-04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS40-04'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'Schottky, Diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85701/bas40v.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS40-04\n\nSchottky, Diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT160A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT160A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-223'], 'footprint':'Package_TO_SOT_SMD:SOT-223', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT160_SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT160A\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT160C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT160C'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-223'], 'footprint':'Package_TO_SOT_SMD:SOT-223', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT160_SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT160C\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT160S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT160S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-223'], 'footprint':'Package_TO_SOT_SMD:SOT-223', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT160_SERIES.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT160S\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'schottky diode', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds11005.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54A\n\nschottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54ADW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54ADW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30152.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54ADW\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '3']}] }),
        Part(**{ 'name':'BAT54AW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54AW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT54W_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54AW\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54C'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'schottky diode common cathode', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds11005.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54C\n\nschottky diode common cathode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54CW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54CW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT54W_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54CW\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'schottky diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds11005.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54S\n\nschottky diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54SDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54SDW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/BAT54TW_ADW_CDW_SDW_BRW.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54SDW\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'BAT54W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54W'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT54W_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54W\n\nschottky diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV70', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV70'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV70_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV70\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV70S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV70S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV70_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV70S\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'BAV756S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV756S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV756S_BAW56_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV756S\n\nDiode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='CA',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '5', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2', '4']}] }),
        Part(**{ 'name':'BAV99', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV99'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV99_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV99\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV99S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV99S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV99_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV99S\n\nDiode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K3A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K1A2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='A3',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '4']}] }),
        Part(**{ 'name':'BZX84Cxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZX84Cxx'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/bzx84c2v4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZX84Cxx\n\nzener diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D02060F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D02060F'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220F-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220F-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/35/C3D02060F.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D02060F\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06060G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06060G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-263-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-263-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/137/C3D06060G.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06060G\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D16060D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D16060D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/98/C3D16060D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D16060D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D1P7060Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D1P7060Q'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_QFN_3.3x3.3mm_P0.65mm'], 'footprint':'Diode_SMD:D_QFN_3.3x3.3mm_P0.65mm', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/846/C3D1P7060Q.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D1P7060Q\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D10120H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D10120H'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/1189/C4D10120H.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D10120H\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSD01060E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSD01060E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/87/CSD01060.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCSD01060E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DB3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB3'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'AC diode DIAC', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A100/DB%203%23st.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDB3\n\nAC diode DIAC', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESD9B5.0ST5G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESD9B5.0ST5G'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-923'], 'footprint':'Diode_SMD:D_SOD-923', 'keywords':'diode TVS ESD', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/ESD9B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESD9B5.0ST5G\n\ndiode TVS ESD', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD04G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD04G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD04G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628f749daa0e03', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD04G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL41'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MiniMELF'], 'footprint':'Diode_SMD:D_MiniMELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85659/bat41.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nLL41\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR735', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR735'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MBR735-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR735\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2005EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2005EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2005EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010AET', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010AET'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010AEH_PMEG2010AET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010AET\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4050EP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4050EP'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-128'], 'footprint':'Diode_SMD:D_SOD-128', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4050EP.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4050EP\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG40T10ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG40T10ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG40T10ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG40T10ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG45A10EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG45A10EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG45A10EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG45A10EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Rohm_UMN1N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Rohm_UMN1N'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode', 'description':'', 'datasheet':'https://fscdn.rohm.com/en/products/databook/datasheet/discrete/diode/switching/umn1ntr-e.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nRohm_UMN1N\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'Rohm_UMP11N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Rohm_UMP11N'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://fscdn.rohm.com/en/products/databook/datasheet/discrete/diode/switching/ump11ntn-e.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nRohm_UMP11N\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'SB120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB120'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds23022.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB120\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD05_SOD323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD05_SOD323'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sd_c_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD05_SOD323\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD103ATW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD103ATW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'schottky barrier diode array', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds30374.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD103ATW\n\nschottky barrier diode array', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'SM6T6V8A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T6V8A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T6V8A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM712_SOT23', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM712_SOT23'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sm712_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM712_SOT23\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='common',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STTH2002D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STTH2002D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'diode', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stth2002.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTTH2002D\n\ndiode', 'pins':[
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STTH2002G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STTH2002G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-263-2'], 'footprint':'Package_TO_SOT_SMD:TO-263-2', 'keywords':'diode', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stth2002.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTTH2002G\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STTH212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STTH212S'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stth212.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTTH212S\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VS-6ESU06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VS-6ESU06'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-277A'], 'footprint':'Package_TO_SOT_SMD:TO-277A', 'keywords':'diode fred', 'description':'', 'datasheet':'https://www.vishay.com/docs/94987/vs-6esu06hm3.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nVS-6ESU06\n\ndiode fred', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZPYxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZPYxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85790/zpy3v9.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZPYxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1.5SMCxxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1.5SMCxxA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'transient voltage suppressor TRANSZORBÂ®', 'description':'', 'datasheet':'https://www.vishay.com/docs/88303/15smc.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1.5SMCxxA\n\ntransient voltage suppressor TRANSZORBÂ®', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1.5SMCxxCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1.5SMCxxCA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'transient voltage suppressor TRANSZORBÂ®', 'description':'', 'datasheet':'https://www.vishay.com/docs/88303/15smc.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1.5SMCxxCA\n\ntransient voltage suppressor TRANSZORBÂ®', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4002'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4002\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4003'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4003\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4004'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4004\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4005'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4005\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4006', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4006'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4006\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4007', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4007'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88503/1n4001.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4007\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4148'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/1N4148_1N4448.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4148\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4148W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4148W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85748/1n4148w.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4148W\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4148WS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4148WS'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85751/1n4148ws.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4148WS\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4148WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4148WT'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds30396.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4148WT\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4149', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4149'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.microsemi.com/document-portal/doc_view/11580-lds-0239', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4149\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4151', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4151'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.microsemi.com/document-portal/doc_view/11580-lds-0239', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4151\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4448', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4448'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/1N4148_1N4448.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4448\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4448W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4448W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85722/1n4448w.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4448W\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4448WS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4448WS'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/81387/1n4448ws.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4448WS\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N4448WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N4448WT'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/149/1N4148WT-461550.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N4448WT\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N47xxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N47xxA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85816/1n4728a.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N47xxA\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N53xxB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N53xxB'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/1n5345b.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N53xxB\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5400'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5400\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5401'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5401\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5402', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5402'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5402\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5403', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5403'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5403\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5404', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5404'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5404\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5405', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5405'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5405\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5406', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5406'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5406\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5407', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5407'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5407\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5408', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5408'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88516/1n5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5408\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5711', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5711'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5711\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5712', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5712'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5712\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5712UR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5712UR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_SMD:D_MELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/131890-lds-0040-1-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5712UR\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5817', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5817'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88525/1n5817.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5817\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5818', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5818'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88525/1n5817.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5818\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5819', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5819'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88525/1n5817.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5819\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5819WS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5819WS'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/2204281430_Guangdong-Hottech-1N5819WS_C191023.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5819WS\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5821', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5821'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88526/1n5820.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5821\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N5822', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N5822'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88526/1n5820.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N5822\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N62xxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N62xxA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N62xxA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N62xxCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N62xxCA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N62xxCA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N630xA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N630xA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N630xA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N630xCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N630xCA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/docs/88301/15ke.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N630xCA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N6857', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N6857'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N6857\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N6857UR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N6857UR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_SMD:D_MELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/131890-lds-0040-1-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N6857UR\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N6858', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N6858'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N6858\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N6858UR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N6858UR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_SMD:D_MELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/131890-lds-0040-1-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N6858UR\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N914', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N914'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85622/1n914.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N914\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1N914WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1N914WT'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.mouser.com/ds/2/149/1N4148WT-461550.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1N914WT\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'1SS355VM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'1SS355VM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://fscdn.rohm.com/en/products/databook/datasheet/discrete/diode/switching/1ss355vmte-17-e.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n1SS355VM\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'5KPxxA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'5KPxxA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_P600_R-6_P20.00mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/5kp65.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n5KPxxA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'5KPxxCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'5KPxxCA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_SMD:D_SMC', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'Diode_THT:D_P600_R-6_P20.00mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AE_P15.24mm_Horizontal', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/5kp65.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\n5KPxxCA\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B130-E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B130-E3'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88946/b120.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB130-E3\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B140-E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B140-E3'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88946/b120.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB140-E3\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B150-E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B150-E3'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88946/b120.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB150-E3\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B160-E3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B160-E3'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/88946/b120.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB160-E3\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B230', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B230'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB230\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B240'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB240\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B250', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B250'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB250\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B260', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B260'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB260\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B330', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B330'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC', 'Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB330\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B340', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B340'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB340\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B350'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB350\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'B360', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'B360'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC', 'Diode_SMD:D_SMC'], 'footprint':'Diode_SMD:D_SMC', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.jameco.com/Jameco/Products/ProdDS/1538777.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nB360\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA157'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/88536/ba157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA157\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA158', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA158'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/88536/ba157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA158\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA159', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA159'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/88536/ba157.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA159\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA243'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/BA243_TFK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA243\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA244', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA244'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/BA243_TFK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA244\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA282', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA282'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://docs-europe.electrocomponents.com/webdocs/1304/0900766b813040d6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA282\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BA283', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BA283'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://docs-europe.electrocomponents.com/webdocs/1304/0900766b813040d6.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBA283\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAR43FILM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAR43FILM'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/bar43.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAR43FILM\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS16VY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS16VY'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAS16_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS16VY\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'BAS19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS19'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/Ds12004.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS19\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS20'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/Ds12004.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS20\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS21'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/Ds12004.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS21\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS316', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS316'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAS16_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS316\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAS516', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAS516'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAS16_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAS516\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT41'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85659/bat41.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT41\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT42', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT42'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85660/bat42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT42\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT42W-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT42W-V'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85660/bat42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT42W-V\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT43'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85660/bat42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT43\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT43W-V', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT43W-V'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85660/bat42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT43W-V\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT46', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT46'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85662/bat46.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT46\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT48JFILM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT48JFILM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/bat48.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT48JFILM\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT48RL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT48RL'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/bat48.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT48RL\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT48ZFILM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT48ZFILM'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/bat48.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT48ZFILM\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT54J.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54J\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT54SW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT54SW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'dual schottky diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT54W_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT54SW\n\ndual schottky diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT60A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT60A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-BAT60ASERIES-DS-v01_01-en.pdf?fileId=db3a304313d846880113def70c9304a9', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT60A\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT85', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT85'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT85.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT85\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT86'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAT86.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT86\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAT86S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAT86S'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85514/bat86s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAT86S\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV16W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV16W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds30086.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV16W\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV17'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85543/bav17.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV17\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV18'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85543/bav17.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV18\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV19'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85543/bav17.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV19\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV199DW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV199DW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'Quad diode', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds30417.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV199DW\n\nQuad diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K3A4',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K1A2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='A3',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'BAV20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV20'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85543/bav17.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV20\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV21', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV21'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85543/bav17.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV21\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV300', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV300'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85545/bav300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV300\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV301'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85545/bav300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV301\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV302'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85545/bav300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV302\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV303'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85545/bav300.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV303\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV70M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV70M'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-883'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV70_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV70M\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV70T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV70T'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-883', 'Package_TO_SOT_SMD:SOT-416'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV70_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV70T\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'BAV70W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAV70W'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-883', 'Package_TO_SOT_SMD:SOT-416', 'Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV70_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAV70W\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'BAW56DW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAW56DW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30146.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAW56DW\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '3']}] }),
        Part(**{ 'name':'BAW56S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAW56S'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BAV756S_BAW56_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAW56S\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'BAW75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAW75'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85550/baw75.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAW75\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAW76', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAW76'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85551/baw76.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAW76\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BAY93', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BAY93'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://cdn-reichelt.de/documents/datenblatt/A400/BAY93_TFK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBAY93\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BYV79-100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BYV79-100'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/philips/BYV79-100.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBYV79-100\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BYV79-150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BYV79-150'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/philips/BYV79-100.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBYV79-150\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BYV79-200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BYV79-200'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://pdf.datasheetcatalog.com/datasheet/philips/BYV79-100.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBYV79-200\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZD27Cxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZD27Cxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85153/bzd27series.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZD27Cxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZM55Bxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZM55Bxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85597/bzm55.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZM55Bxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZM55Cxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZM55Cxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85597/bzm55.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZM55Cxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZT52Bxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZT52Bxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/bzt52b2v4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZT52Bxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B10'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B10\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B11'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B11\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B12'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B12\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B13'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B13\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B15'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B15\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B16'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B16\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B18'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B18\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B20'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B20\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B22'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B22\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B24'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B24\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B27', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B27'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B27\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B2V4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B2V4'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B2V4\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B2V7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B2V7'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B2V7\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B30'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B30\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B33'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B33\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B36', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B36'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B36\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B39', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B39'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B39\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B3V0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B3V0'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B3V0\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B3V3'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B3V3\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B3V6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B3V6'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B3V6\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B3V9', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B3V9'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B3V9\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B43'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B43\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B47', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B47'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B47\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B4V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B4V3'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B4V3\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B4V7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B4V7'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B4V7\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B51'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B51\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B56', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B56'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B56\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B5V1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B5V1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B5V1\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B5V6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B5V6'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B5V6\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B62', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B62'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B62\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B68'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B68\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B6V2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B6V2'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B6V2\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B6V8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B6V8'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B6V8\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B75'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B75\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B7V5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B7V5'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B7V5\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B8V2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B8V2'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B8V2\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55B9V1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55B9V1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55B9V1\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C10'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C10\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C11'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C11\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C12'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C12\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C13'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C13\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C15'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C15\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C16'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C16\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C18'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C18\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C20'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C20\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C22'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C22\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C24'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C24\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C27', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C27'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C27\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C2V4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C2V4'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C2V4\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C2V7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C2V7'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C2V7\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C30'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C30\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C33'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C33\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C36', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C36'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C36\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C39', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C39'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C39\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C3V0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C3V0'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C3V0\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C3V3'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C3V3\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C3V6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C3V6'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C3V6\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C3V9', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C3V9'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C3V9\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C43'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C43\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C47', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C47'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C47\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C4V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C4V3'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C4V3\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C4V7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C4V7'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C4V7\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C51', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C51'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C51\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C56', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C56'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C56\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C5V1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C5V1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C5V1\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C5V6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C5V6'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C5V6\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C62', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C62'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C62\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C68', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C68'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C68\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C6V2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C6V2'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C6V2\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C6V8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C6V8'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C6V8\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C75'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C75\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C7V5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C7V5'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C7V5\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C8V2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C8V2'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C8V2\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZV55C9V1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZV55C9V1'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/BZV55_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZV55C9V1\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BZX384xxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BZX384xxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85764/bzx384.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nBZX384xxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D02060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D02060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/55/C3D02060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D02060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D02060E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D02060E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/116/C3D02060E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D02060E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D02065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D02065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/118/C3D02065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D02065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D03060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D03060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/57/C3D03060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D03060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D03060E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D03060E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/119/C3D03060E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D03060E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D03060F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D03060F'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220F-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/39/C3D03060F.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D03060F\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D03065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D03065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/121/C3D03065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D03065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D04060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D04060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/845/C3D04060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D04060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D04060E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D04060E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/122/C3D04060E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D04060E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D04060F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D04060F'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220F-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/41/C3D04060F.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D04060F\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D04065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D04065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/841/C3D04065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D04065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D04065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D04065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/124/C3D04065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D04065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/844/C3D06060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06060F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06060F'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical', 'Package_TO_SOT_THT:TO-220F-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220F-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/43/C3D06060F.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06060F\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/65/C3D06065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/125/C3D06065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D06065I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D06065I'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/44/C3D06065I.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D06065I\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D08060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D08060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/843/C3D08060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D08060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D08060G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D08060G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-263-2_TabPin1', 'Package_TO_SOT_SMD:TO-263-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-263-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/141/C3D08060G.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D08060G\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D08065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D08065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/840/C3D08065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D08065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D08065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D08065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/839/C3D08065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D08065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D08065I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D08065I'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/47/C3D08065I.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D08065I\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/842/C3D10060A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10060G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10060G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-263-2_TabPin1', 'Package_TO_SOT_SMD:TO-263-2_TabPin1', 'Package_TO_SOT_SMD:TO-263-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-263-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/143/C3D10060G.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10060G\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/73/C3D10065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10065E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10065E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/127/C3D10065E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10065E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10065I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10065I'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/49/C3D10065I.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10065I\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D10170H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D10170H'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/96/C3D10170H.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D10170H\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D12065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D12065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/963/C3D12065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D12065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D16065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D16065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/964/C3D16065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D16065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D16065D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D16065D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/99/C3D16065D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D16065D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D20060D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D20060D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/100/C3D20060D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D20060D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D20065D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D20065D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/102/C3D20065D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D20065D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D25170H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D25170H'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/103/C3D25170H.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D25170H\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C3D30065D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C3D30065D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/969/C3D30065D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC3D30065D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D02120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D02120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/75/C4D02120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D02120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D02120E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D02120E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/128/C4D02120E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D02120E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D05120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D05120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/77/C4D05120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D05120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D05120E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D05120E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/130/C4D05120E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D05120E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D08120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D08120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/80/C4D08120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D08120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D08120E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D08120E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/132/C4D08120E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D08120E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D10120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D10120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/82/C4D10120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D10120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D10120D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D10120D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/104/C4D10120D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D10120D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D10120E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D10120E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'Package_TO_SOT_SMD:TO-252-2_TabPin1'], 'footprint':'Package_TO_SOT_SMD:TO-252-2_TabPin1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/134/C4D10120E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D10120E\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D15120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D15120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/84/C4D15120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D15120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D15120D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D15120D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/848/C4D15120D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D15120D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D15120H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D15120H'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/1190/C4D15120H.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D15120H\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D20120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D20120A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/85/C4D20120A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D20120A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D20120D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D20120D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/106/C4D20120D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D20120D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D20120H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D20120H'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical', 'Package_TO_SOT_THT:TO-247-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/1191/C4D20120H.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D20120H\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D30120D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D30120D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/108/C4D30120D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D30120D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C4D40120D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C4D40120D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/109/C4D40120D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC4D40120D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C5D50065D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C5D50065D'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical', 'Package_TO_SOT_THT:TO-247-3_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-247-3_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/111/C5D50065D.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nC5D50065D\n\nsic diode', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CD4148W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CD4148W'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.dccomponents.com/upload/product/original/623524775088.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCD4148W\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDBA3100-HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDBA3100-HF'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/CDBA340-HF%20Thru193640.%20CDBA3100-HF%20RevB.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCDBA3100-HF\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDBA340-HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDBA340-HF'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/CDBA340-HF%20Thru193640.%20CDBA3100-HF%20RevB.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCDBA340-HF\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDBA360-HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDBA360-HF'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/CDBA340-HF%20Thru193640.%20CDBA3100-HF%20RevB.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCDBA360-HF\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDBU40-HF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDBU40-HF'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_0603_1608Metric'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.comchiptech.com/admin/files/product/QW-G1012-CDBU40-HF-RevA321692.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCDBU40-HF\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CSD01060A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CSD01060A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/87/CSD01060.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCSD01060A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CVFD20065A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CVFD20065A'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.wolfspeed.com/media/downloads/89/CVFD20065A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCVFD20065A\n\nsic diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Central_Semi_CMKD4448', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Central_Semi_CMKD4448'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.centralsemi.com/PDFs/products/CMKD4448.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCentral_Semi_CMKD4448\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'Central_Semi_CMKD6001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Central_Semi_CMKD6001'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.centralsemi.com/PDFs/products/CMKD6001.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nCentral_Semi_CMKD6001\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'Comchip_ACDSV6-4448TI-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Comchip_ACDSV6-4448TI-G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.comchiptech.com/cms/UserFiles/ACDSV6-4448TI-G%20RevA285610.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nComchip_ACDSV6-4448TI-G\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'Comchip_CDSV6-4148-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Comchip_CDSV6-4148-G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.comchiptech.com/cms/UserFiles/CDSV6-16-G,4148-G%20RevA272279.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nComchip_CDSV6-4148-G\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'Comchip_CDSV6-4448TI-G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Comchip_CDSV6-4448TI-G'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.comchiptech.com/cms/UserFiles/CDSV6-4448XX-G%20RevC285574.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nComchip_CDSV6-4448TI-G\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'DB4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DB4'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'AC diode DIAC', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A100/DB%203%23st.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDB4\n\nAC diode DIAC', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DC34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DC34'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'AC diode DIAC', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A100/DB%203%23st.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDC34\n\nAC diode DIAC', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSB2810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSB2810'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDSB2810\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DSB5712', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DSB5712'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microsemi.com/document-portal/doc_download/8865-lds-0040-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDSB5712\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S030X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S030X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S03000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S030X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S033X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S033X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S03300L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S033X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S036X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S036X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S03600L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S036X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S039X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S039X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S03900L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S039X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S047X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S047X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S04700L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S047X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S051X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S051X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S05100L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S051X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S056X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S056X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S05600L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S056X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S068X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S068X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S06800L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S068X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S082X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S082X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S08200L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S082X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S100X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S100X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S10000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S100X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S110X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S110X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S11000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S110X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S120X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S120X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S12000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S120X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S130X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S130X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S13000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S130X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S150X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S150X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S15000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S150X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S160X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S160X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S16000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S160X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S180X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S180X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S18000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S180X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S200X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S200X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S20000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S200X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DZ2S360X0L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DZ2S360X0L'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://industrial.panasonic.com/content/data/SC/ds/ds4/DZ2S36000L_E.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nDZ2S360X0L\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESD131-B1-W0201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESD131-B1-W0201'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-923', 'Diode_SMD:Infineon_SG-WLL-2-3_0.58x0.28_P0.36mm'], 'footprint':'Diode_SMD:D_SOD-923', 'keywords':'diode TVS ESD', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-ESD131-B1-W0201-DataSheet-v02_00-EN.pdf?fileId=5546d4625cc9456a015ce94850964889', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESD131-B1-W0201\n\ndiode TVS ESD', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESD5Zxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESD5Zxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'esd tvs unidirectional diode', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/esd5z2.5t1-d.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESD5Zxx\n\nesd tvs unidirectional diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESD9B3.3ST5G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESD9B3.3ST5G'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-923', 'Diode_SMD:Infineon_SG-WLL-2-3_0.58x0.28_P0.36mm', 'Diode_SMD:D_SOD-923'], 'footprint':'Diode_SMD:D_SOD-923', 'keywords':'diode TVS ESD', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/ESD9B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESD9B3.3ST5G\n\ndiode TVS ESD', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESH2PB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESH2PB'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode ', 'description':'', 'datasheet':'https://www.vishay.com/docs/89016/esh2pb.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESH2PB\n\ndiode ', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESH2PC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESH2PC'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/89016/esh2pb.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESH2PC\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESH2PD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESH2PD'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/89016/esh2pb.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nESH2PD\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HN2D02FU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HN2D02FU'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/HN2D02FUTW1T1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nHN2D02FU\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '3']}] }),
        Part(**{ 'name':'IDDD06G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD06G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD06G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628f86ff8c0e09', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD06G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD08G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD08G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD08G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628ff7d31a104b', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD08G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD10G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD10G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD10G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628ff848ec1051', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD10G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD12G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD12G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD12G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628f86ec3e0e06', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD12G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD16G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD16G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD16G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628f8711b50e0c', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD16G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDDD20G65C6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDDD20G65C6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1'], 'footprint':'Package_TO_SOT_SMD:Infineon_PG-HDSOP-10-1', 'keywords':'sic diode', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IDDD20G65C6-DS-v02_00-EN.pdf?fileId=5546d462625a528f01628ff837cf104e', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nIDDD20G65C6\n\nsic diode', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL4148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL4148'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85557/ll4148.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nLL4148\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL42', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL42'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_SMD:D_MiniMELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85672/ll42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nLL42\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL43'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_SMD:D_MiniMELF', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.vishay.com/docs/85672/ll42.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nLL43\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL4448', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL4448'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85557/ll4148.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nLL4448\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0520', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0520'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0520\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0520LT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0520LT'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MBR0520LT1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0520LT\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0530', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0530'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0530\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0540', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0540'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0540\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0550', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0550'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0550\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0560', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0560'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0560\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0570', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0570'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0570\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR0580', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR0580'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.mccsemi.com/up_pdf/MBR0520~MBR0580(SOD123).pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR0580\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR1020VL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR1020VL'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MBR1020VL-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR1020VL\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR340', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR340'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MBR340-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR340\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBR745', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBR745'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-2_Vertical', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MBR735-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBR745\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MBRA340', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MBRA340'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_0603_1608Metric', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMA', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MBRA340T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMBRA340\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCL4148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCL4148'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85566/mlc4148.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMCL4148\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCL4448', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCL4448'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/85566/mlc4148.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMCL4448\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MM3Zxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MM3Zxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/mm3z2v4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMM3Zxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MM5Zxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MM5Zxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/mm5z2v4.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMM5Zxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MMBD4148TW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMBD4148TW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30154.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMBD4148TW\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'MMBD4448HADW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMBD4448HADW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30153.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMBD4448HADW\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'MMBD4448HCQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMBD4448HCQW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30153.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMBD4448HCQW\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'MMBD4448HTW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMBD4448HTW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.diodes.com/datasheets/ds30153.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMBD4448HTW\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'MMBZxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMBZxx'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'dual zener diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/MMBZ5V6ALT1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMBZxx\n\ndual zener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MMSD4148', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMSD4148'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MMSD4148T1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMSD4148\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MMSD914', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MMSD914'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/MMSD914T1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMMSD914\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MRA4003T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MRA4003T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMRA4003T3G\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MRA4004T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MRA4004T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMRA4004T3G\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MRA4005T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MRA4005T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMRA4005T3G\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MRA4006T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MRA4006T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMRA4006T3G\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MRA4007T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MRA4007T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nMRA4007T3G\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRVA4003T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRVA4003T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNRVA4003T3G\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRVA4004T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRVA4004T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNRVA4004T3G\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRVA4005T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRVA4005T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNRVA4005T3G\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRVA4006T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRVA4006T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNRVA4006T3G\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NRVA4007T3G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NRVA4007T3G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MRA4003T3-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNRVA4007T3G\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NSR0340HT1G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSR0340HT1G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NSR0340H-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nNSR0340HT1G\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG030V030EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG030V030EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG030V030EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG030V030EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG030V050EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG030V050EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG030V050EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG030V050EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG040V030EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG040V030EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG040V030EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG040V030EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG040V050EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG040V050EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG040V050EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG040V050EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045T050EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045T050EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045T050EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045T050EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045T100EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045T100EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045T100EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045T100EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045T150EIPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045T150EIPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045T150EIPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045T150EIPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045T150EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045T150EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045T150EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045T150EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045V050EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045V050EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045V050EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045V050EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045V100EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045V100EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045V100EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045V100EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG045V150EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG045V150EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG045V150EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG045V150EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG050T150EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG050T150EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG050T150EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG050T150EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG050V030EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG050V030EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG050V030EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG050V030EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG050V150EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG050V150EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG050V150EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG050V150EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG060V030EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG060V030EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG060V030EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG060V030EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG060V050EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG060V050EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG060V050EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG060V050EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG060V100EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG060V100EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG060V100EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG060V100EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG10010ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG10010ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG10010ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG10010ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG10020AELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG10020AELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG10020AELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG10020AELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG10020ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG10020ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG10020ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG10020ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG100V060ELPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG100V060ELPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG100V060ELPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG100V060ELPD\n\nir diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG100V080ELPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG100V080ELPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG100V080ELPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG100V080ELPD\n\nir diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG100V100ELPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG100V100ELPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG100V100ELPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG100V100ELPD\n\nir diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG1020EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG1020EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG1020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG1020EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG1020EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG1020EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG1020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG1020EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG1030EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG1030EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG1030EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG1030EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG1030EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG1030EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG1030EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG1030EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2005EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2005EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2005EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010AEH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010AEH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010AEH_PMEG2010AET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010AEH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010AEJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010AEJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010AEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010AEJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010BER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010BER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010BER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010BER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2010ET', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2010ET'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2010ET\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2015EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2015EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2015EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2015EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2015EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2015EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2015EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2015EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2020EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2020EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2020EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG2020EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG2020EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG2020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG2020EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3002EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3002EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3002EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3002EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3005EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3005EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3005EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3005EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3005EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3005EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010BER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010BER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010BER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010BER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010CEH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010CEH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010CEH_PMEG3010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010CEH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010CEJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010CEJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010CEH_PMEG3010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010CEJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3010ET', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3010ET'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3010ET\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3015EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3015EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3015EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3015EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3015EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3015EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3015EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3015EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3020BER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3020BER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3020BER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3020BER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3020EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3020EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3020EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3020EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3020EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3020EH_EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3020EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG3020ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG3020ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG3020ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG3020ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4002EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4002EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4002EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4002EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4005CEJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4005CEJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4005CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4005CEJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4005EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4005EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4005EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4005EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4005EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEGXX05EH_EJ_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4005EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010CEH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010CEH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010CEH_PMEG4010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010CEH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010CEJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010CEJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010CEH_PMEG4010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010CEJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010EH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010EH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010EH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4010ET', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4010ET'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4010EH_EJ_ET.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4010ET\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4020ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4020ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4020ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4020ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG4030ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG4030ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG4030ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG4030ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG40T20ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG40T20ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG40T20ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG40T20ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG40T30ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG40T30ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG40T30ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG40T30ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG45T15EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG45T15EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG45T15EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG45T15EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG45U10EPD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG45U10EPD'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289'], 'footprint':'Package_TO_SOT_SMD:Nexperia_CFP15_SOT-1289', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG45U10EPD.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG45U10EPD\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6002EJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6002EJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6002EJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6002EJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6010CEH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6010CEH'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6010CEH_PMEG6010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6010CEH\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6010CEJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6010CEJ'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-323F'], 'footprint':'Diode_SMD:D_SOD-323F', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6010CEH_PMEG6010CEJ.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6010CEJ\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6010ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6010ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6010ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6010ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6010ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6010ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6010ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6010ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6020AELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6020AELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6020AELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6020AELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6020ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6020ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6020ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6020ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6020ER', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6020ER'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6020ER.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6020ER\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6030EP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6030EP'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-128', 'Diode_SMD:D_SOD-128'], 'footprint':'Diode_SMD:D_SOD-128', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6030EP.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6030EP\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG6045ETP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG6045ETP'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-128', 'Diode_SMD:D_SOD-128', 'Diode_SMD:D_SOD-128'], 'footprint':'Diode_SMD:D_SOD-128', 'keywords':'forward voltage diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG6045ETP.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG6045ETP\n\nforward voltage diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG60T10ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG60T10ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG60T10ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG60T10ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG60T20ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG60T20ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG60T20ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG60T20ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PMEG60T30ELR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PMEG60T30ELR'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W', 'Diode_SMD:Nexperia_CFP3_SOD-123W'], 'footprint':'Diode_SMD:Nexperia_CFP3_SOD-123W', 'keywords':'ir diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PMEG60T30ELR.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPMEG60T30ELR\n\nir diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS10VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS10VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS10VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS10VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS12VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS12VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS12VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS12VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS15VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS15VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS15VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS15VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS18VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS18VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS18VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS18VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS20VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS20VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS20VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS20VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS22VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS22VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS22VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS22VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS26VZ1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS26VZ1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS26VZ1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS26VZ1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS5V0Z1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS5V0Z1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS5V0Z1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS5V0Z1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS5V0Z1USKP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS5V0Z1USKP'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS5V0Z1USKP.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS5V0Z1USKP\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTVS7V5Z1USK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTVS7V5Z1USK'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'TVS diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PTVS7V5Z1USK.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPTVS7V5Z1USK\n\nTVS diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Panasonic_MA5J002E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Panasonic_MA5J002E'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode', 'description':'', 'datasheet':'http://www.semicon.panasonic.co.jp/ds4/MA5J002E_BED_discon.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nPanasonic_MA5J002E\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'RF01VM2S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RF01VM2S'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://fscdn.rohm.com/en/products/databook/datasheet/discrete/diode/fast_recovery/rf01vm2s.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nRF01VM2S\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'S2JTR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'S2JTR'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.smc-diodes.com/propdf/S2A-S2M%20N0562%20REV.A.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nS2JTR\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB130', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB130'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds23022.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB130\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB140', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB140'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds23022.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB140\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB150'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds23022.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB150\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB160'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'http://www.diodes.com/_files/datasheets/ds23022.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB160\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB5H100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB5H100'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88722/sb5h90.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB5H100\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SB5H90', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SB5H90'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88722/sb5h90.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSB5H90\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD12_SOD323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD12_SOD323'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sd_c_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD12_SOD323\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD15_SOD323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD15_SOD323'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sd_c_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD15_SOD323\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD24_SOD323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD24_SOD323'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sd_c_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD24_SOD323\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SD36_SOD323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SD36_SOD323'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'transient voltage suppressor thyrector transil', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sd_c_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSD36_SOD323\n\ntransient voltage suppressor thyrector transil', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM2000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM2000'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM2000\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4001'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4001\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4002'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4002\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4003'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4003\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4004'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4004\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4005'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4005\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4006', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4006'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4006\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM4007', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM4007'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM4007\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM513'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM513\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM516', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM516'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM516\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM518', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM518'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://cdn-reichelt.de/documents/datenblatt/A400/SMD1N400%23DIO.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM518\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T100A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T100A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T100A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T10A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T10A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T12A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T12A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T12A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T150A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T150A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T150A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T15A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T15A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T15A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T18A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T18A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T18A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T200A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T200A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T220A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T220A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T220A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T22A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T22A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T22A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T24A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T24A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T24A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T27A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T27A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T27A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T30A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T30A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T33A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T33A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T33A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T36A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T36A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T36A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T39A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T39A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T39A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T56A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T56A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T56A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T68A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T68A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T68A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T75A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T75A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T75A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SM6T7V5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SM6T7V5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/sm6t.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSM6T7V5A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ100A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ100A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ100A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ100CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ100CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ100CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ10A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ10A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ10CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ10CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ10CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ110A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ110A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ110A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ110CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ110CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ110CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ11A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ11A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ11A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ11CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ11CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ11CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ120A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ120A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ120A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ120CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ120CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ120CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ12A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ12A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ12A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ12CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ12CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ12CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ130A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ130A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ130A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ130CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ130CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ130CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ13A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ13A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ13A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ13CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ13CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ13CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ14A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ14A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ14A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ14CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ14CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ14CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ150A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ150A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ150A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ150CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ150CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ150CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ15A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ15A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ15A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ15CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ15CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ15CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ160A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ160A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ160A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ160CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ160CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ160CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ16A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ16A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ16CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ16CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ16CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ170A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ170A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ170A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ170CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ170CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ170CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ17A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ17A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ17A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ17CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ17CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ17CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ180A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ180A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ180A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ180CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ180CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ180CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ188A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ188A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ188A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ188CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ188CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ188CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ18A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ18A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ18A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ18CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ18CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ18CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ200A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ200A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ200A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ200CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ200CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ200CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ20A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ20A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ20CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ20CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ20CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ220A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ220A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ220A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ220CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ220CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ220CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ22A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ22A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ22A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ22CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ22CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ22CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ24A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ24A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ24A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ24CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ24CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ24CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ250A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ250A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ250A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ250CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ250CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ250CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ26A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ26A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ26A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ26CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ26CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ26CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ28A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ28A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ28A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ28CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ28CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ28CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ300A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ300A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ300A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ300CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ300CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ300CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ30A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ30A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ30CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ30CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ30CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ33A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ33A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ33A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ33CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ33CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ33CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ350A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ350A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ350A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ350CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ350CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ350CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ36A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ36A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ36A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ36CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ36CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ36CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ400A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ400A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ400A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ400CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ400CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ400CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ40A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ40A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ40A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ40CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ40CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ40CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ43A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ43A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ43A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ43CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ43CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ43CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ440A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ440A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ440A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ440CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ440CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ440CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ45A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ45A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ45A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ45CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ45CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ45CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ48A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ48A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ48A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ48CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ48CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ48CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ5.0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ5.0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ5.0A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ5.0CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ5.0CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ5.0CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ51A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ51A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ51A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ51CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ51CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ51CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ54A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ54A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ54A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ54CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ54CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ54CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ58A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ58A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ58A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ58CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ58CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ58CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ6.0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ6.0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ6.0A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ6.0CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ6.0CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ6.0CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ6.5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ6.5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ6.5A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ6.5CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ6.5CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ6.5CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ60A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ60A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ60A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ60CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ60CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ60CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ64A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ64A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ64A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ64CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ64CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ64CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ7.0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ7.0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ7.0A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ7.0CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ7.0CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ7.0CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ7.5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ7.5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ7.5A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ7.5CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ7.5CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ7.5CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ70A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ70A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ70A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ70CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ70CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ70CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ75A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ75A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ75A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ75CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ75CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ75CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ78A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ78A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ78A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ78CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ78CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ78CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ8.0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ8.0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ8.0A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ8.0CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ8.0CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ8.0CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ8.5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ8.5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ8.5A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ8.5CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ8.5CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ8.5CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ85A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ85A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ85A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ85CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ85CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ85CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ9.0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ9.0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ9.0A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ9.0CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ9.0CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ9.0CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ90A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ90A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'unidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ90A\n\nunidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMAJ90CA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMAJ90CA'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_SMD:D_SOD-323', 'keywords':'bidirectional diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.littelfuse.com/media?resourcetype=datasheets&itemid=75e32973-b177-4ee3-a0ff-cedaf1abdb93&filename=smaj-datasheet', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMAJ90CA\n\nbidirectional diode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF10A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF10A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF10A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF11A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF11A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF11A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF12A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF12A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF12A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF13A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF13A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF13A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF14A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF14A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF14A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF15A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF15A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF15A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF16A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF16A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF17A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF17A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF17A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF18A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF18A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF18A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF20A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF20A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF20A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF22A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF22A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF22A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF24A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF24A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF24A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF26A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF26A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF26A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF28A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF28A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF28A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF30A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF30A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF33A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF33A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF33A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF36A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF36A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF36A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF40A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF40A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF40A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF43A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF43A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF43A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF45A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF45A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF45A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF48A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF48A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF48A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF51A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF51A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF51A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF54A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF54A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF54A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF58A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF58A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF58A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF5V0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF5V0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF5V0A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF6V0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF6V0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF6V0A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF6V5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF6V5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF6V5A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF7V0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF7V0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF7V0A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF7V5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF7V5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF7V5A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF8V0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF8V0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF8V0A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF8V5A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF8V5A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF8V5A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMF9V0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMF9V0A'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF', 'Diode_SMD:D_SMF'], 'footprint':'Diode_SMD:D_SMB', 'keywords':'diode TVS voltage suppressor', 'description':'', 'datasheet':'https://www.vishay.com/doc?85881', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMF9V0A\n\ndiode TVS voltage suppressor', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SMZxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SMZxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/smz1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSMZxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS110', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS110'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.smc-diodes.com/propdf/SS12-SS110%20N0229%20REV.C.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS110\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS1150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS1150'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.wontop.com/uploadfiles/56/sort_excel/pdf/ss1150.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS1150\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS12'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88746/ss12.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS12\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS1200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS1200'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.wontop.com/uploadfiles/56/sort_excel/pdf/ss1150.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS1200\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS13'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88746/ss12.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS13\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS14'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88746/ss12.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS14\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS15'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88746/ss12.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS15\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS16'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88746/ss12.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS16\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS18'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.smc-diodes.com/propdf/SS12-SS110%20N0229%20REV.C.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS18\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS210', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS210'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.wontop.com/uploadfiles/56/sort_excel/pdf/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS210\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS2150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS2150'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS22-THRU-SS2200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS2150\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS22', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS22'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88748/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS22\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS2200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS2200'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS22-THRU-SS2200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS2200\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS23', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS23'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88748/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS23\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS24'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88748/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS24\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS25', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS25'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88748/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS25\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS26', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS26'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88748/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS26\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS28'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.wontop.com/uploadfiles/56/sort_excel/pdf/ss22.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS28\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS310', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS310'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS32-THRU-SS3200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS310\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS3150', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS3150'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS32-THRU-SS3200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS3150\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS32'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88751/ss32.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS32\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS3200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS3200'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS32-THRU-SS3200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS3200\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS33'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88751/ss32.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS33\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS34'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88751/ss32.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS34\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS35', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS35'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88751/ss32.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS35\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS36', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS36'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.vishay.com/docs/88751/ss32.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS36\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SS38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SS38'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode Schottky', 'description':'', 'datasheet':'https://www.microdiode.com/uploadfiles//PDF/SS32-THRU-SS3200-SMA.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSS38\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STBR3008WY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STBR3008WY'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stbr3008-y.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTBR3008WY\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STBR3012WY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STBR3012WY'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stbr3012-y.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTBR3012WY\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STBR6008WY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STBR6008WY'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stbr6008-y.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTBR6008WY\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STBR6012WY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STBR6012WY'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'AEC-Q101', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stbr6012-y.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTBR6012WY\n\nAEC-Q101', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STTH212U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STTH212U'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/stth212.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSTTH212U\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SZESD9B5.0ST5G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SZESD9B5.0ST5G'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:D_SOD-923', 'Diode_SMD:Infineon_SG-WLL-2-3_0.58x0.28_P0.36mm', 'Diode_SMD:D_SOD-923', 'Diode_SMD:D_SOD-923'], 'footprint':'Diode_SMD:D_SOD-923', 'keywords':'diode TVS ESD', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/ESD9B-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nSZESD9B5.0ST5G\n\ndiode TVS ESD', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Toshiba_HN1D01FU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Toshiba_HN1D01FU'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'http://www.toshiba.com/taec/components2/Datasheet_Sync/200901/DST_HN1D01FU-TDE_EN_1882.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nToshiba_HN1D01FU\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'UF5400', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5400'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5400\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5401'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5401\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5402', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5402'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5402\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5403', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5403'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5403\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5404', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5404'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5404\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5405', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5405'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5405\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5406', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5406'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5406\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5407', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5407'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5407\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'UF5408', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'UF5408'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'diode', 'description':'', 'datasheet':'http://www.vishay.com/docs/88756/uf5400.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUF5408\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1A'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1A\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1B'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1B\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1D'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1D\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1G'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1G\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1J', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1J'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1J\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1K'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1K\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US1M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US1M'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Ultra Fast', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds16008.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS1M\n\nUltra Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2AA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2AA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2AA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2BA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2BA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2BA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2DA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2DA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2DA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2FA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2FA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2FA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2GA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2GA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2GA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2JA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2JA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2JA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2KA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2KA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2KA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'US2MA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'US2MA'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-123', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Diode_THT:D_DO-35_SOD27_P7.62mm_Horizontal', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Package_TO_SOT_THT:TO-220-2_Vertical', 'Diode_SMD:D_0805_2012Metric', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_SMP_DO-220AA', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SOD-123', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SMB', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_THT:D_DO-247_Vertical', 'Diode_SMD:D_SMB', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_THT:D_DO-201AD_P15.24mm_Horizontal', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'Super Fast', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/US2AA-D.PDF', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nUS2MA\n\nSuper Fast', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Z1SMAxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z1SMAxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/z1sma1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZ1SMAxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Z2SMBxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z2SMBxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/z2smb1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZ2SMBxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Z3SMCxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Z3SMCxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/z3smc1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZ3SMCxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZMDxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZMDxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'http://diotec.com/tl_files/diotec/files/pdf/datasheets/zmd1', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZMDxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZMMxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZMMxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/zmm1.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZMMxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZMYxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZMYxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MELF'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://www.vishay.com/docs/85788/zmy3v9.pdf', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZMYxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZPDxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZPDxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-35_SOD27_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'http://diotec.com/tl_files/diotec/files/pdf/datasheets/zpd1', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZPDxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZYxxx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZYxxx'}), 'ref_prefix':'D', 'fplist':['Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'Diode_THT:D_DO-201_P15.24mm_Horizontal', 'Diode_SMD:D_SMF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_MicroMELF', 'Diode_SMD:D_SOD-123F', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_SOD-323', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-523', 'Diode_SMD:D_SOD-323F', 'Diode_SMD:D_SOD-523', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:Nexperia_DSN1608-2_1.6x0.8mm', 'Diode_SMD:D_MELF', 'Diode_SMD:D_SMA', 'Diode_SMD:D_SMB', 'Diode_SMD:D_SMC', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MiniMELF', 'Diode_SMD:D_MELF', 'Diode_THT:D_DO-35_SOD27_P10.16mm_Horizontal', 'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal'], 'footprint':'Diode_THT:D_DO-41_SOD81_P10.16mm_Horizontal', 'keywords':'zener diode', 'description':'', 'datasheet':'https://diotec.com/tl_files/diotec/files/pdf/datasheets/zy1', 'search_text':'/usr/share/kicad/symbols/Diode.kicad_sym\nZYxxx\n\nzener diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])