from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Device = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'Ammeter_AC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ammeter_AC'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'ammeter AC ampere meter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAmmeter_AC\n\nammeter AC ampere meter', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Ammeter_DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ammeter_DC'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'ammeter DC ampere meter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAmmeter_DC\n\nammeter DC ampere meter', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Antenna', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Antenna'}), 'ref_prefix':'AE', 'fplist':[''], 'footprint':'', 'keywords':'antenna', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAntenna\n\nantenna', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Antenna_Chip', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Antenna_Chip'}), 'ref_prefix':'AE', 'fplist':[''], 'footprint':'', 'keywords':'antenna', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAntenna_Chip\n\nantenna', 'pins':[
            Pin(num='1',name='FEED',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PCB_Trace',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Antenna_Dipole', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Antenna_Dipole'}), 'ref_prefix':'AE', 'fplist':[''], 'footprint':'', 'keywords':'dipole antenna', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAntenna_Dipole\n\ndipole antenna', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Antenna_Loop', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Antenna_Loop'}), 'ref_prefix':'AE', 'fplist':[''], 'footprint':'', 'keywords':'loop antenna', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAntenna_Loop\n\nloop antenna', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Antenna_Shield', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Antenna_Shield'}), 'ref_prefix':'AE', 'fplist':[''], 'footprint':'', 'keywords':'antenna', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nAntenna_Shield\n\nantenna', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Shield',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Battery', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Battery'}), 'ref_prefix':'BT', 'fplist':[''], 'footprint':'', 'keywords':'batt voltage-source cell', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nBattery\n\nbatt voltage-source cell', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Battery_Cell', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Battery_Cell'}), 'ref_prefix':'BT', 'fplist':[''], 'footprint':'', 'keywords':'battery cell', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nBattery_Cell\n\nbattery cell', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Buzzer', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Buzzer'}), 'ref_prefix':'BZ', 'fplist':[''], 'footprint':'', 'keywords':'quartz resonator ceramic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nBuzzer\n\nquartz resonator ceramic', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_45deg', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_45deg'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'capacitor cap', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_45deg\n\ncapacitor cap', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Feedthrough', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Feedthrough'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'EMI filter feedthrough capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Feedthrough\n\nEMI filter feedthrough capacitor', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Network04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Network04'}), 'ref_prefix':'CN', 'fplist':[''], 'footprint':'', 'keywords':'C network star-topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Network04\n\nC network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Network05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Network05'}), 'ref_prefix':'CN', 'fplist':[''], 'footprint':'', 'keywords':'C network star-topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Network05\n\nC network star-topology', 'pins':[
            Pin(num='6',name='C5',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Network06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Network06'}), 'ref_prefix':'CN', 'fplist':[''], 'footprint':'', 'keywords':'C network star-topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Network06\n\nC network star-topology', 'pins':[
            Pin(num='6',name='C5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C6',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Network07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Network07'}), 'ref_prefix':'CN', 'fplist':[''], 'footprint':'', 'keywords':'C network star-topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Network07\n\nC network star-topology', 'pins':[
            Pin(num='6',name='C5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='C7',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Network08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Network08'}), 'ref_prefix':'CN', 'fplist':[''], 'footprint':'', 'keywords':'C network star-topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Network08\n\nC network star-topology', 'pins':[
            Pin(num='6',name='C5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='C7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='C8',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='C4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_Series_2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_Series_2C'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_Series_2C\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_Small'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_Small\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_Small_Series_2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_Small_Series_2C'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_Small_Series_2C\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_Small_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_Small_US'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_Small_US\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_Small_US_Series_2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_Small_US_Series_2C'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_Small_US_Series_2C\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_US'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_US\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Polarized_US_Series_2C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Polarized_US_Series_2C'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'cap capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Polarized_US_Series_2C\n\ncap capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Small'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'capacitor cap', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Small\n\ncapacitor cap', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Trim', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Trim'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'trimmer variable capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Trim\n\ntrimmer variable capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Trim_Differential', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Trim_Differential'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'trimmer capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Trim_Differential\n\ntrimmer capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Trim_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Trim_Small'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'trimmer variable capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Trim_Small\n\ntrimmer variable capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'C_Variable', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'C_Variable'}), 'ref_prefix':'C', 'fplist':[''], 'footprint':'', 'keywords':'trimmer capacitor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nC_Variable\n\ntrimmer capacitor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_1P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_1P'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_1P\n\nCB', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_1P_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_1P_US'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_1P_US\n\nCB', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_2P'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB 2P', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_2P\n\nCB 2P', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_2P_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_2P_US'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB 2P', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_2P_US\n\nCB 2P', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_3P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_3P'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB 3P', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_3P\n\nCB 3P', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CircuitBreaker_3P_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CircuitBreaker_3P_US'}), 'ref_prefix':'CB', 'fplist':[''], 'footprint':'', 'keywords':'CB 3P', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCircuitBreaker_3P_US\n\nCB 3P', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND2'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND2\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND23', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND23'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND23\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND23_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND23_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND23_Small\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND24'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND24\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND24_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND24_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND24_Small\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND2_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND2_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND2_Small\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND3'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND3\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_GND3_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_GND3_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_GND3_Small\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Crystal_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Crystal_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'quartz ceramic resonator oscillator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nCrystal_Small\n\nquartz ceramic resonator oscillator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIAC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIAC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'AC diode DIAC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nDIAC\n\nAC diode DIAC', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DIAC_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DIAC_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'AC diode DIAC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nDIAC_Filled\n\nAC diode DIAC', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_45deg', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_45deg'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'Diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_45deg\n\nDiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_45deg_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_45deg_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'Diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_45deg_Filled\n\nDiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_AAK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Bridge_+-AA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Bridge_+-AA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'rectifier ACDC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Bridge_+-AA\n\nrectifier ACDC', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Bridge_+A-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Bridge_+A-A'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'rectifier ACDC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Bridge_+A-A\n\nrectifier ACDC', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Bridge_+AA-', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Bridge_+AA-'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'rectifier ACDC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Bridge_+AA-\n\nrectifier ACDC', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Bridge_-A+A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Bridge_-A+A'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'rectifier ACDC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Bridge_-A+A\n\nrectifier ACDC', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Bridge_-AA+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Bridge_-AA+'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'rectifier ACDC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Bridge_-AA+\n\nrectifier ACDC', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Capacitance', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Capacitance'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'capacitance diode varicap varactor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Capacitance\n\ncapacitance diode varicap varactor', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Capacitance_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Capacitance_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'capacitance diode varicap varactor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Capacitance_Filled\n\ncapacitance diode varicap varactor', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Current-regulator', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Current-regulator'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode constant-current current limit regulator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Current-regulator\n\ndiode constant-current current limit regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Current-regulator_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Current-regulator_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode constant-current current limit regulator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Current-regulator_Small\n\ndiode constant-current current limit regulator', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_AKK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_AKK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_AKK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_AKK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_AKK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_AKK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_AKK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_AKK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_AKK_Split\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']}] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KAK\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KAK_Split\n\ndiode', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KKA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonAnode_KKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonAnode_KKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonAnode_KKA_Split\n\ndiode', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AAK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AAK_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AKA\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_AKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_AKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_AKA_Split\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Dual_CommonCathode_KAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_KAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_KAA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_KAA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_KAA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_KAA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_CommonCathode_KAA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_CommonCathode_KAA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_CommonCathode_KAA_Split\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Dual_Series_ACK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_ACK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_ACK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_ACK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_ACK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_ACK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_ACK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_ACK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_ACK_Split\n\ndiode', 'pins':[
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Dual_Series_AKC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_AKC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_AKC\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_AKC_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_AKC_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_AKC_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_AKC_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_AKC_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_AKC_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='common',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Dual_Series_CAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CAK\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_CAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_CAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CAK_Split\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']}] }),
        Part(**{ 'name':'D_Dual_Series_CKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CKA\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_CKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_CKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_CKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_CKA_Split\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '1']}] }),
        Part(**{ 'name':'D_Dual_Series_KAC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KAC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KAC\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_KAC_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KAC_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KAC_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_KAC_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KAC_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KAC_Split\n\ndiode', 'pins':[
            Pin(num='3',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Dual_Series_KCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KCA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KCA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_KCA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KCA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KCA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Dual_Series_KCA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Dual_Series_KCA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Dual_Series_KCA_Split\n\ndiode', 'pins':[
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '1']}] }),
        Part(**{ 'name':'D_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Filled\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_KAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_KAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_KAA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_KAK\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_KKA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Laser_1A3C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Laser_1A3C'}), 'ref_prefix':'LD', 'fplist':[''], 'footprint':'', 'keywords':'opto laserdiode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Laser_1A3C\n\nopto laserdiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Laser_1C2A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Laser_1C2A'}), 'ref_prefix':'LD', 'fplist':[''], 'footprint':'', 'keywords':'opto laserdiode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Laser_1C2A\n\nopto laserdiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Laser_Photo_MType', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Laser_Photo_MType'}), 'ref_prefix':'LD', 'fplist':[''], 'footprint':'', 'keywords':'opto laserdiode photodiode', 'description':'', 'datasheet':'http://www.egismos.disonhu.com/laser/diode-package.htm', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Laser_Photo_MType\n\nopto laserdiode photodiode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Laser_Photo_NType', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Laser_Photo_NType'}), 'ref_prefix':'LD', 'fplist':[''], 'footprint':'', 'keywords':'opto laserdiode photodiode', 'description':'', 'datasheet':'http://www.egismos.disonhu.com/laser/diode-package.htm', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Laser_Photo_NType\n\nopto laserdiode photodiode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Laser_Photo_PType', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Laser_Photo_PType'}), 'ref_prefix':'LD', 'fplist':[''], 'footprint':'', 'keywords':'opto laserdiode photodiode', 'description':'', 'datasheet':'http://www.egismos.disonhu.com/laser/diode-package.htm', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Laser_Photo_PType\n\nopto laserdiode photodiode', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Photo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Photo'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'photodiode diode opto', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Photo\n\nphotodiode diode opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Photo_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Photo_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'photodiode diode opto', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Photo_Filled\n\nphotodiode diode opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Radiation', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Radiation'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'radiation detector diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Radiation\n\nradiation detector diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Radiation_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Radiation_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'radiation detector diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Radiation_Filled\n\nradiation detector diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_AAK\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_AKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_AKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_AKA\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_AKK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_AKK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_AKK\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_AKK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_AKK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_AKK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_AKK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_AKK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_AKK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_AKK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_AKK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_AKK_Split\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KAK\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KAK_Split\n\ndiode', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KKA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonAnode_KKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonAnode_KKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonAnode_KKA_Split\n\ndiode', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AAK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AAK_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AKA\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_AKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_AKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_AKA_Split\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_KAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_KAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_KAA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_KAA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_KAA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_KAA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_CommonCathode_KAA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_CommonCathode_KAA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_CommonCathode_KAA_Split\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_ACK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_ACK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_ACK\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_ACK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_ACK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_ACK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_ACK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_ACK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_ACK_Split\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_AKC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_AKC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_AKC\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_AKC_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_AKC_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_AKC_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_AKC_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_AKC_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_AKC_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CAK\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CAK_Split\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CKA\n\ndiode', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_CKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_CKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_CKA_Split\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '2']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KAC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KAC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KAC\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='common',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KAC_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KAC_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KAC_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KAC_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KAC_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KAC_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']}] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KCA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KCA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KCA\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='common',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KCA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KCA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KCA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Dual_Series_KCA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Dual_Series_KCA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Dual_Series_KCA_Split\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '1']}] }),
        Part(**{ 'name':'D_Schottky_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Filled\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_KAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_KAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_KAA\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_KAK\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky SCHDPAK', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_KKA\n\ndiode Schottky SCHDPAK', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Small\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Schottky_Small_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Schottky_Small_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode Schottky', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Schottky_Small_Filled\n\ndiode Schottky', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Shockley', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Shockley'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'Shockley diode PNPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Shockley\n\nShockley diode PNPN', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_SiPM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_SiPM'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SiPM MPPC SPAD photon counting', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_SiPM\n\nSiPM MPPC SPAD photon counting', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Small\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Small_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Small_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Small_Filled\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Dual_AAC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Dual_AAC'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Dual_AAC\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='common',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Dual_ACA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Dual_ACA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Dual_ACA\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Dual_CAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Dual_CAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Dual_CAA\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Filled\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Small\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TVS_Small_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TVS_Small_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode TVS thyrector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TVS_Small_Filled\n\ndiode TVS thyrector', 'pins':[
            Pin(num='1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TemperatureDependent', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TemperatureDependent'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'temperature sensor diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TemperatureDependent\n\ntemperature sensor diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_TemperatureDependent_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_TemperatureDependent_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'temperature sensor diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_TemperatureDependent_Filled\n\ntemperature sensor diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Tunnel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Tunnel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'tunnel diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Tunnel\n\ntunnel diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Tunnel_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Tunnel_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'tunnel diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Tunnel_Filled\n\ntunnel diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Unitunnel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Unitunnel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'unitunnel diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Unitunnel\n\nunitunnel diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Unitunnel_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Unitunnel_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'unitunnel diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Unitunnel_Filled\n\nunitunnel diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_AKK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_AKK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_AKK\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_AKK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_AKK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_AKK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_AKK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_AKK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_AKK_Split\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']}] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KAK\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KAK_Split\n\ndiode', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KKA\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonAnode_KKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonAnode_KKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonAnode_KKA_Split\n\ndiode', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AAK\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AAK_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AAK_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AAK_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AAK_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AAK_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AAK_Split\n\ndiode', 'pins':[
            Pin(num='3',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3']}] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AKA\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AKA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AKA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AKA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_AKA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_AKA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_AKA_Split\n\ndiode', 'pins':[
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_KAA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_KAA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode zener dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_KAA\n\ndiode zener dual', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='3',name='A',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_KAA_Parallel', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_KAA_Parallel'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_KAA_Parallel\n\ndiode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE),
            Pin(num='3',name='K',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Dual_CommonCathode_KAA_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Dual_CommonCathode_KAA_Split'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Dual_CommonCathode_KAA_Split\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']}] }),
        Part(**{ 'name':'D_Zener_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Filled\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Small\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D_Zener_Small_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D_Zener_Small_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nD_Zener_Small_Filled\n\ndiode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DelayLine', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DelayLine'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'delay propagation retard impedance', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nDelayLine\n\ndelay propagation retard impedance', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='COMMUN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Earphone', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Earphone'}), 'ref_prefix':'LS', 'fplist':[''], 'footprint':'', 'keywords':'earphone speaker headphone', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nEarphone\n\nearphone speaker headphone', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ElectromagneticActor', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ElectromagneticActor'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'electromagnet coil inductor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nElectromagneticActor\n\nelectromagnet coil inductor', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FerriteBead', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FerriteBead'}), 'ref_prefix':'FB', 'fplist':[''], 'footprint':'', 'keywords':'L ferrite bead inductor filter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFerriteBead\n\nL ferrite bead inductor filter', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FerriteBead_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FerriteBead_Small'}), 'ref_prefix':'FB', 'fplist':[''], 'footprint':'', 'keywords':'L ferrite bead inductor filter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFerriteBead_Small\n\nL ferrite bead inductor filter', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_CLC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_CLC'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'EMI T-filter', 'description':'', 'datasheet':'http://www.murata.com/~/media/webrenewal/support/library/catalog/products/emc/emifil/c31e.ashx?la=en-gb', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_CLC\n\nEMI T-filter', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LCL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LCL'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'EMI T-filter', 'description':'', 'datasheet':'http://www.murata.com/~/media/webrenewal/support/library/catalog/products/emc/emifil/c31e.ashx?la=en-gb', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LCL\n\nEMI T-filter', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LL'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'EMI filter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LL\n\nEMI filter', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LLL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LLL'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'three phase common mode choke', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LLL\n\nthree phase common mode choke', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LLLL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LLLL'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'common mode quadruple choke quad coil', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LLLL\n\ncommon mode quadruple choke quad coil', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LLLL_15263748', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LLLL_15263748'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'common mode quadruple choke quad coil', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LLLL_15263748\n\ncommon mode quadruple choke quad coil', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LLL_162534', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LLL_162534'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'three phase common mode choke', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LLL_162534\n\nthree phase common mode choke', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_LL_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_LL_1423'}), 'ref_prefix':'FL', 'fplist':[''], 'footprint':'', 'keywords':'EMI filter common-mode choke', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_LL_1423\n\nEMI filter common-mode choke', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'FrequencyCounter', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'FrequencyCounter'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'frequency counter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFrequencyCounter\n\nfrequency counter', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fuse', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fuse'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'fuse', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFuse\n\nfuse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fuse_Polarized', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fuse_Polarized'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'fuse', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFuse_Polarized\n\nfuse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fuse_Polarized_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fuse_Polarized_Small'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'fuse', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFuse_Polarized_Small\n\nfuse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Fuse_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Fuse_Small'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'fuse', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFuse_Small\n\nfuse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GDT_2Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GDT_2Pin'}), 'ref_prefix':'GD', 'fplist':[''], 'footprint':'', 'keywords':'gdt', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nGDT_2Pin\n\ngdt', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GDT_3Pin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GDT_3Pin'}), 'ref_prefix':'GD', 'fplist':[''], 'footprint':'', 'keywords':'gdt', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nGDT_3Pin\n\ngdt', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Galvanometer', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Galvanometer'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'galvanometer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nGalvanometer\n\ngalvanometer', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HallGenerator', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HallGenerator'}), 'ref_prefix':'HG', 'fplist':[''], 'footprint':'', 'keywords':'Hall generator magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nHallGenerator\n\nHall generator magnet', 'pins':[
            Pin(num='1',name='U1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='U2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='UH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='UH2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Heater', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Heater'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'heater R resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nHeater\n\nheater R resistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED\n\nLED diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_45deg', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_45deg'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_45deg\n\nLED diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_45deg_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_45deg_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_45deg_Filled\n\nLED diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_ABGR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_ABGR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_ABGR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_ABRG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_ABRG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_ABRG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_AGBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_AGBR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_AGBR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_AGRB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_AGRB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_AGRB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_ARBG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_ARBG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_ARBG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_ARGB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_ARGB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_ARGB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BAGR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BAGR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BAGR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BARG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BARG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BARG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BGAR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BGAR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BGAR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BGKR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BGKR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BGKR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BGRA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BGRA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BGRA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BGRK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BGRK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BGRK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BKGR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BKGR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BKGR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BKRG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BKRG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BKRG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BRAG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BRAG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BRAG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BRGA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BRGA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BRGA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BRGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BRGK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BRGK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_BRKG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_BRKG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_BRKG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_AAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_AAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_AAK\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_AAKK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_AAKK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_AAKK\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='K2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_AKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_AKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_AKA\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_AKAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_AKAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_AKAK\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='K2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_AKKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_AKKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_AKKA\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_Bidirectional', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_Bidirectional'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_Bidirectional\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='KA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_KAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_KAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_KAK\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_KAKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_KAKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_KAKA\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Dual_KKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Dual_KKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode bicolor dual', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Dual_KKA\n\nLED diode bicolor dual', 'pins':[
            Pin(num='1',name='K1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Filled\n\nLED diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GABR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GABR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GABR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GARB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GARB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GARB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GBAR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GBAR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GBAR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GBKR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GBKR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GBKR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GBRA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GBRA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GBRA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GBRK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GBRK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GBRK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GKBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GKBR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GKBR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GKRB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GKRB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GKRB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GRAB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GRAB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GRAB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GRBA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GRBA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GRBA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GRBK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GRBK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GRBK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_GRKB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_GRKB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_GRKB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KBGR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KBGR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KBGR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KBRG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KBRG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KBRG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KGBR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KGBR'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KGBR\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KGRB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KGRB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KGRB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KRBG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KRBG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KRBG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_KRGB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_KRGB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_KRGB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Pad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Pad'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode pad', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Pad\n\nLED diode pad', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RABG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RABG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RABG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RAGB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RAGB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RAGB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RBAG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RBAG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RBAG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RBGA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RBGA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RBGA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RBGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RBGK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RBGK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RBKG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RBKG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RBKG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGAB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGAB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGAB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BK',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGBA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGBA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGBA\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGBK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGBK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGBK\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGB_EP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGB_EP'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGB_EP\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RK',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GK',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RGKB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RGKB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RGKB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RKBG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RKBG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RKBG\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='BA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_RKGB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_RKGB'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED RGB diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_RKGB\n\nLED RGB diode', 'pins':[
            Pin(num='1',name='RA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='BA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Series', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Series'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Series\n\nLED diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Series_Pad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Series_Pad'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode pad', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Series_Pad\n\nLED diode pad', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Small'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode light-emitting-diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Small\n\nLED diode light-emitting-diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LED_Small_Filled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LED_Small_Filled'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'LED diode light-emitting-diode', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLED_Small_Filled\n\nLED diode light-emitting-diode', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_45deg', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_45deg'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic inductor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_45deg\n\ninductor choke coil reactor magnetic inductor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_Small\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_Small_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_Small_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_Small_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_Small_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_Small_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_Small_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_Small_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_Small_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_Small_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Coupled_Small_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Coupled_Small_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Coupled_Small_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_Small\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_Small_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_Small_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_Small_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_Small_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_Small_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_Small_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_Small_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_Small_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_Small_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Coupled_Small_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Coupled_Small_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Coupled_Small_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Ferrite_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Ferrite_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Ferrite_Small\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_Small\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_Small_1243', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_Small_1243'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_Small_1243\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_Small_1324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_Small_1324'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_Small_1324\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_Small_1342', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_Small_1342'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_Small_1342\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Coupled_Small_1423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Coupled_Small_1423'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic coupled', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Coupled_Small_1423\n\ninductor choke coil reactor magnetic coupled', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Iron_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Iron_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Iron_Small\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Pack04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Pack04'}), 'ref_prefix':'LN', 'fplist':[''], 'footprint':'', 'keywords':'L network parallel topology', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Pack04\n\nL network parallel topology', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Small'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Small\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L_Trim', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L_Trim'}), 'ref_prefix':'L', 'fplist':[''], 'footprint':'', 'keywords':'inductor choke coil reactor magnetic', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nL_Trim\n\ninductor choke coil reactor magnetic', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Lamp', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Lamp'}), 'ref_prefix':'LA', 'fplist':[''], 'footprint':'', 'keywords':'lamp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLamp\n\nlamp', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Lamp_Flash', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Lamp_Flash'}), 'ref_prefix':'LA', 'fplist':[''], 'footprint':'', 'keywords':'flash lamp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLamp_Flash\n\nflash lamp', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Lamp_Neon', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Lamp_Neon'}), 'ref_prefix':'NE', 'fplist':[''], 'footprint':'', 'keywords':'neon lamp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nLamp_Neon\n\nneon lamp', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Memristor', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Memristor'}), 'ref_prefix':'MR', 'fplist':[''], 'footprint':'', 'keywords':'memristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nMemristor\n\nmemristor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Microphone', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Microphone'}), 'ref_prefix':'MK', 'fplist':[''], 'footprint':'', 'keywords':'microphone', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nMicrophone\n\nmicrophone', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Microphone_Condenser', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Microphone_Condenser'}), 'ref_prefix':'MK', 'fplist':[''], 'footprint':'', 'keywords':'capacitance condenser microphone', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nMicrophone_Condenser\n\ncapacitance condenser microphone', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Microphone_Crystal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Microphone_Crystal'}), 'ref_prefix':'MK', 'fplist':[''], 'footprint':'', 'keywords':'microphone crystal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nMicrophone_Crystal\n\nmicrophone crystal', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NetTie_2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NetTie_2'}), 'ref_prefix':'NT', 'fplist':[''], 'footprint':'', 'keywords':'net tie short', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nNetTie_2\n\nnet tie short', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NetTie_3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NetTie_3'}), 'ref_prefix':'NT', 'fplist':[''], 'footprint':'', 'keywords':'net tie short', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nNetTie_3\n\nnet tie short', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NetTie_3_Tee', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NetTie_3_Tee'}), 'ref_prefix':'NT', 'fplist':[''], 'footprint':'', 'keywords':'net tie short', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nNetTie_3_Tee\n\nnet tie short', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NetTie_4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NetTie_4'}), 'ref_prefix':'NT', 'fplist':[''], 'footprint':'', 'keywords':'net tie short', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nNetTie_4\n\nnet tie short', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NetTie_4_Cross', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NetTie_4_Cross'}), 'ref_prefix':'NT', 'fplist':[''], 'footprint':'', 'keywords':'net tie short', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nNetTie_4_Cross\n\nnet tie short', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Ohmmeter', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ohmmeter'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'ohmmeter resistance', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nOhmmeter\n\nohmmeter resistance', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Opamp_Dual', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Opamp_Dual'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'dual opamp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nOpamp_Dual\n\ndual opamp', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'Opamp_Quad', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Opamp_Quad'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'quad opamp', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nOpamp_Quad\n\nquad opamp', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=4),
            Pin(num='11',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '10', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '13', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '4']}] }),
        Part(**{ 'name':'Oscilloscope', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Oscilloscope'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'oscilloscope', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nOscilloscope\n\noscilloscope', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PeltierElement', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PeltierElement'}), 'ref_prefix':'PE', 'fplist':[''], 'footprint':'', 'keywords':'Peltier TEC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nPeltierElement\n\nPeltier TEC', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Polyfuse', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Polyfuse'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'resettable fuse PTC PPTC polyfuse polyswitch', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nPolyfuse\n\nresettable fuse PTC PPTC polyfuse polyswitch', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Polyfuse_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Polyfuse_Small'}), 'ref_prefix':'F', 'fplist':[''], 'footprint':'', 'keywords':'resettable fuse PTC PPTC polyfuse polyswitch', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nPolyfuse_Small\n\nresettable fuse PTC PPTC polyfuse polyswitch', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Dual_NMOS_G1S2G2D2S1D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NMOS_G1S2G2D2S1D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NMOS_G1S2G2D2S1D1\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3', '4']}] }),
        Part(**{ 'name':'Q_Dual_NMOS_S1G1D2S2G2D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NMOS_S1G1D2S2G2D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NMOS_S1G1D2S2G2D1\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='G',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'Q_Dual_NMOS_S1G1S2G2D2D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NMOS_S1G1S2G2D2D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NMOS_S1G1S2G2D2D1\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4', '5']}] }),
        Part(**{ 'name':'Q_Dual_NMOS_S1G1S2G2D2D2D1D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NMOS_S1G1S2G2D2D2D1D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NMOS_S1G1S2G2D2D2D1D1\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '8', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4', '5', '6']}] }),
        Part(**{ 'name':'Q_Dual_NPN_C2C1E1E2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_C2C1E1E2'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_C2C1E1E2\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Dual_NPN_NPN_BRT_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_NPN_BRT_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_NPN_BRT_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '4', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '2', '6']}] }),
        Part(**{ 'name':'Q_Dual_NPN_NPN_BRT_No_R2_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_NPN_BRT_No_R2_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_NPN_BRT_No_R2_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '5', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '2']}] }),
        Part(**{ 'name':'Q_Dual_NPN_NPN_C2E2C1E1B1B2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_NPN_C2E2C1E1B1B2'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_NPN_C2E2C1E1B1B2\n\ntransistor NPN', 'pins':[
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '3', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '1', '2']}] }),
        Part(**{ 'name':'Q_Dual_NPN_NPN_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_NPN_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_NPN_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4', '5']}] }),
        Part(**{ 'name':'Q_Dual_NPN_PNP_BRT_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_PNP_BRT_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_PNP_BRT_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'Q_Dual_NPN_PNP_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_NPN_PNP_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_NPN_PNP_E1B1C2E2B2C1\n\ntransistor NPN PNP', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '5']}] }),
        Part(**{ 'name':'Q_Dual_PMOS_G1S2G2D2S1D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PMOS_G1S2G2D2S1D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PMOS_G1S2G2D2S1D1\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2', '4']}] }),
        Part(**{ 'name':'Q_Dual_PMOS_S1G1D2S2G2D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PMOS_S1G1D2S2G2D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PMOS_S1G1D2S2G2D1\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='G',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'Q_Dual_PMOS_S1G1S2G2D2D2D1D1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PMOS_S1G1S2G2D2D2D1D1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PMOS_S1G1S2G2D2D2D1D1\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='G',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='D',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='D',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4', '5', '6']}] }),
        Part(**{ 'name':'Q_Dual_PNP_C2C1E1E2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_C2C1E1E2'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_C2C1E1E2\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='C2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Dual_PNP_NPN_BRT_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_NPN_BRT_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_NPN_BRT_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '4']}] }),
        Part(**{ 'name':'Q_Dual_PNP_PNP_BRT_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_PNP_BRT_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_PNP_BRT_E1B1C2E2B2C1\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '3']}] }),
        Part(**{ 'name':'Q_Dual_PNP_PNP_C1B1B2C2E2E1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_PNP_C1B1B2C2E2E1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ds30437.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_PNP_C1B1B2C2E2E1\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B2',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='E2',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3', '5']}] }),
        Part(**{ 'name':'Q_Dual_PNP_PNP_C2E2C1E1B1B2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_PNP_C2E2C1E1B1B2'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_PNP_C2E2C1E1B1B2\n\ntransistor PNP', 'pins':[
            Pin(num='3',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '3', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '2']}] }),
        Part(**{ 'name':'Q_Dual_PNP_PNP_E1B1C2E2B2C1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Dual_PNP_PNP_E1B1C2E2B2C1'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Dual_PNP_PNP_E1B1C2E2B2C1\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='E1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='C1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='E2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='B2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '4']}] }),
        Part(**{ 'name':'Q_NIGBT_CEG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_CEG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_CEG\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_CGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_CGE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_CGE\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_ECG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_ECG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_ECG\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_ECGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_ECGC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_ECGC\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_EGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_EGC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_EGC\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_GCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_GCE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_GCE\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_GCEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_GCEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_GCEC\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NIGBT_GEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NIGBT_GEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor IGBT N-IGBT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NIGBT_GEC\n\ntransistor IGBT N-IGBT', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_DGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_DGS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_DGS\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_DSG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_DSG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_DSG\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_GDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_GDS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_GDS\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_GSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_GSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_GSD\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_SDG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_SDG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_SDG\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NJFET_SGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NJFET_SGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NJFET N-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NJFET_SGD\n\ntransistor NJFET N-JFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_DGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_DGS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_DGS\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_DSG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_DSG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_DSG\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_DGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_DGS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_DGS\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_DSG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_DSG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_DSG\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_GDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_GDS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_GDS\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_GSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_GSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_GSD\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_SDG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_SDG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_SDG\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_Depletion_SGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_Depletion_SGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'Depletion-mode N-channel MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_Depletion_SGD\n\nDepletion-mode N-channel MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_GDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_GDS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_GDS\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_GDSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_GDSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_GDSD\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_GSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_GSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_GSD\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_SDG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_SDG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_SDG\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_SDGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_SDGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_SDGD\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NMOS_SGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NMOS_SGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NMOS N-MOS N-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NMOS_SGD\n\ntransistor NMOS N-MOS N-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_BCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_BCE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_BCE\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_BCEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_BCEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_BCEC\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_BEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_BEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_BEC\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_BEC_BRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_BEC_BRT'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_BEC_BRT\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_CBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_CBE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_CBE\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_CEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_CEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_CEB\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_BCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_BCE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_BCE\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_BCEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_BCEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_BCEC\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_BEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_BEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_BEC\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_CBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_CBE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_CBE\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_CEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_CEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_CEB\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_EBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_EBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_EBC\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_ECB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_ECB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_ECB\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_Darlington_ECBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_Darlington_ECBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_Darlington_ECBC\n\ntransistor NPN Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_EBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_EBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_EBC\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_ECB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_ECB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_ECB\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_ECBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_ECBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_ECBC\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NPN_ECB_BRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NPN_ECB_BRT'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NPN_ECB_BRT\n\ntransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_NUJT_BEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_NUJT_BEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor UJT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_NUJT_BEB\n\ntransistor UJT', 'pins':[
            Pin(num='1',name='B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_DGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_DGS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_DGS\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_DSG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_DSG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_DSG\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_GDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_GDS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_GDS\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_GSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_GSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_GSD\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_SDG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_SDG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_SDG\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PJFET_SGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PJFET_SGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PJFET P-JFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PJFET_SGD\n\ntransistor PJFET P-JFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_DGS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_DGS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_DGS\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_DSG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_DSG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_DSG\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_GDS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_GDS'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_GDS\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_GDSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_GDSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_GDSD\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_GSD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_GSD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_GSD\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_SDG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_SDG'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_SDG\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_SDGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_SDGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_SDGD\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PMOS_SGD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PMOS_SGD'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PMOS P-MOS P-MOSFET', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PMOS_SGD\n\ntransistor PMOS P-MOS P-MOSFET', 'pins':[
            Pin(num='1',name='S',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='D',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_BCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_BCE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_BCE\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_BCEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_BCEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_BCEC\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_BEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_BEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_BEC\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_BEC_BRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_BEC_BRT'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_BEC_BRT\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_CBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_CBE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_CBE\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_CEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_CEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_CEB\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_BCE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_BCE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_BCE\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_BCEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_BCEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_BCEC\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_BEC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_BEC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_BEC\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_CBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_CBE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_CBE\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_CEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_CEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_CEB\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_EBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_EBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_EBC\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_ECB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_ECB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_ECB\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_Darlington_ECBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_Darlington_ECBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP Darlington', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_Darlington_ECBC\n\ntransistor PNP Darlington', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_EBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_EBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_EBC\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_ECB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_ECB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_ECB\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_ECBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_ECBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_ECBC\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PNP_ECB_BRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PNP_ECB_BRT'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor PNP', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PNP_ECB_BRT\n\ntransistor PNP', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_PUJT_BEB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_PUJT_BEB'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'transistor UJT', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_PUJT_BEB\n\ntransistor UJT', 'pins':[
            Pin(num='1',name='B2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Photo_NPN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Photo_NPN'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'phototransistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Photo_NPN\n\nphototransistor NPN', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Photo_NPN_CBE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Photo_NPN_CBE'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'phototransistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Photo_NPN_CBE\n\nphototransistor NPN', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Photo_NPN_EBC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Photo_NPN_EBC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'phototransistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Photo_NPN_EBC\n\nphototransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Photo_NPN_EC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Photo_NPN_EC'}), 'ref_prefix':'Q', 'fplist':[''], 'footprint':'', 'keywords':'phototransistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Photo_NPN_EC\n\nphototransistor NPN', 'pins':[
            Pin(num='1',name='E',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_AGK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_AGK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_AGK\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_AKG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_AKG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_AKG\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_GAK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_GAK'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_GAK\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_GKA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_GKA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_GKA\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_KAG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_KAG'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_KAG\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_SCR_KGA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_SCR_KGA'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'SCR thyristor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_SCR_KGA\n\nSCR thyristor', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='G',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Triac', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Triac'}), 'ref_prefix':'D', 'fplist':[''], 'footprint':'', 'keywords':'TRIAC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Triac\n\nTRIAC', 'pins':[
            Pin(num='A1',name='A1',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='A2',func=pin_types.PASSIVE,unit=1),
            Pin(num='G',name='G',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR\n\nR res resistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFShield_OnePiece', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFShield_OnePiece'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'RF EMI shielding cabinet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nRFShield_OnePiece\n\nRF EMI shielding cabinet', 'pins':[
            Pin(num='1',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RFShield_TwoPieces', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RFShield_TwoPieces'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'RF EMI shielding cabinet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nRFShield_TwoPieces\n\nRF EMI shielding cabinet', 'pins':[
            Pin(num='1',name='Shield',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_45deg', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_45deg'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor diagonal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_45deg\n\nR res resistor diagonal', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network03'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network03\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network03_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network03_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network03_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '4']}] }),
        Part(**{ 'name':'R_Network03_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network03_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network03_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network04'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP5'], 'footprint':'Resistor_THT:R_Array_SIP5', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network04\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network04_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network04_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP5'], 'footprint':'Resistor_THT:R_Array_SIP5', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network04_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']}] }),
        Part(**{ 'name':'R_Network04_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network04_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP5'], 'footprint':'Resistor_THT:R_Array_SIP5', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network04_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network05'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network05\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network05_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network05_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network05_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']}] }),
        Part(**{ 'name':'R_Network05_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network05_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network05_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network06'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP7'], 'footprint':'Resistor_THT:R_Array_SIP7', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network06\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network06_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network06_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP7'], 'footprint':'Resistor_THT:R_Array_SIP7', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network06_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['1', '6']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']}] }),
        Part(**{ 'name':'R_Network06_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network06_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP7'], 'footprint':'Resistor_THT:R_Array_SIP7', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network06_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network07'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network07\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network07_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network07_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network07_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '1']}] }),
        Part(**{ 'name':'R_Network07_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network07_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network07_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network08'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP9'], 'footprint':'Resistor_THT:R_Array_SIP9', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network08\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network08_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network08_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP9'], 'footprint':'Resistor_THT:R_Array_SIP9', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network08_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['1', '6']},{'label': 'uF', 'num': 6, 'pin_nums': ['1', '7']},{'label': 'uG', 'num': 7, 'pin_nums': ['1', '8']},{'label': 'uH', 'num': 8, 'pin_nums': ['1', '9']}] }),
        Part(**{ 'name':'R_Network08_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network08_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP9'], 'footprint':'Resistor_THT:R_Array_SIP9', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network08_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network09'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network09\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network09_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network09_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network09_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '1']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '1']},{'label': 'uH', 'num': 8, 'pin_nums': ['9', '1']},{'label': 'uI', 'num': 9, 'pin_nums': ['10', '1']}] }),
        Part(**{ 'name':'R_Network09_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network09_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network09_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network10'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP11'], 'footprint':'Resistor_THT:R_Array_SIP11', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network10\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network10_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network10_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP11'], 'footprint':'Resistor_THT:R_Array_SIP11', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network10_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=10)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '1']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '1']},{'label': 'uH', 'num': 8, 'pin_nums': ['9', '1']},{'label': 'uI', 'num': 9, 'pin_nums': ['10', '1']},{'label': 'uJ', 'num': 10, 'pin_nums': ['11', '1']}] }),
        Part(**{ 'name':'R_Network10_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network10_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP11'], 'footprint':'Resistor_THT:R_Array_SIP11', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network10_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network11'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network11\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network11_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network11_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network11_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=10),
            Pin(num='12',name='R11.2',func=pin_types.PASSIVE,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['1', '8']},{'label': 'uH', 'num': 8, 'pin_nums': ['1', '9']},{'label': 'uI', 'num': 9, 'pin_nums': ['1', '10']},{'label': 'uJ', 'num': 10, 'pin_nums': ['11', '1']},{'label': 'uK', 'num': 11, 'pin_nums': ['12', '1']}] }),
        Part(**{ 'name':'R_Network11_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network11_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network11_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network12'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP13'], 'footprint':'Resistor_THT:R_Array_SIP13', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network12\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network12_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network12_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP13'], 'footprint':'Resistor_THT:R_Array_SIP13', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network12_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=10),
            Pin(num='12',name='R11.2',func=pin_types.PASSIVE,unit=11),
            Pin(num='13',name='R12.2',func=pin_types.PASSIVE,unit=12)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '1']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '1']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '1']},{'label': 'uH', 'num': 8, 'pin_nums': ['1', '9']},{'label': 'uI', 'num': 9, 'pin_nums': ['10', '1']},{'label': 'uJ', 'num': 10, 'pin_nums': ['1', '11']},{'label': 'uK', 'num': 11, 'pin_nums': ['1', '12']},{'label': 'uL', 'num': 12, 'pin_nums': ['13', '1']}] }),
        Part(**{ 'name':'R_Network12_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network12_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP13'], 'footprint':'Resistor_THT:R_Array_SIP13', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network12_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network13'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP14'], 'footprint':'Resistor_THT:R_Array_SIP14', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network13\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R12',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network13_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network13_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP14'], 'footprint':'Resistor_THT:R_Array_SIP14', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network13_Split\n\nR network star-topology', 'pins':[
            Pin(num='1',name='R1',func=pin_types.PASSIVE),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=10),
            Pin(num='12',name='R11.2',func=pin_types.PASSIVE,unit=11),
            Pin(num='13',name='R12.2',func=pin_types.PASSIVE,unit=12),
            Pin(num='14',name='R13.2',func=pin_types.PASSIVE,unit=13)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '4']},{'label': 'uD', 'num': 4, 'pin_nums': ['1', '5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6', '1']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '1']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '1']},{'label': 'uH', 'num': 8, 'pin_nums': ['9', '1']},{'label': 'uI', 'num': 9, 'pin_nums': ['10', '1']},{'label': 'uJ', 'num': 10, 'pin_nums': ['1', '11']},{'label': 'uK', 'num': 11, 'pin_nums': ['12', '1']},{'label': 'uL', 'num': 12, 'pin_nums': ['13', '1']},{'label': 'uM', 'num': 13, 'pin_nums': ['14', '1']}] }),
        Part(**{ 'name':'R_Network13_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network13_US'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP14'], 'footprint':'Resistor_THT:R_Array_SIP14', 'keywords':'R network star-topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network13_US\n\nR network star-topology', 'pins':[
            Pin(num='1',name='common',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R12',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x02_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x02_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x02_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x03_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x03_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP5'], 'footprint':'Resistor_THT:R_Array_SIP5', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x03_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x04_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x04_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x04_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x05_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x05_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP7'], 'footprint':'Resistor_THT:R_Array_SIP7', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x05_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x06_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x06_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x06_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x07_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x07_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP9'], 'footprint':'Resistor_THT:R_Array_SIP9', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x07_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='COM2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x08_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x08_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x08_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='COM2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x09_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x09_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP11'], 'footprint':'Resistor_THT:R_Array_SIP11', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x09_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='COM2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x10_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x10_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x10_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='COM2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Network_Dividers_x11_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Network_Dividers_x11_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP13'], 'footprint':'Resistor_THT:R_Array_SIP13', 'keywords':'R network divider topology', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Network_Dividers_x11_SIP\n\nR network divider topology', 'pins':[
            Pin(num='1',name='COM1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='COM2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack02'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack02\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R1.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack02_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack02_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack02_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack02_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack02_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP4'], 'footprint':'Resistor_THT:R_Array_SIP4', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack02_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'R_Pack02_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack02_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack02_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='R2.2',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '2']}] }),
        Part(**{ 'name':'R_Pack03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack03'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack03\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R1.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack03_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack03_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack03_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack03_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack03_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP6'], 'footprint':'Resistor_THT:R_Array_SIP6', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack03_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']}] }),
        Part(**{ 'name':'R_Pack03_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack03_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack03_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='R3.2',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'R_Pack04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack04'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack04\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R1.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack04_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack04_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack04_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack04_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack04_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP8'], 'footprint':'Resistor_THT:R_Array_SIP8', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack04_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '8']}] }),
        Part(**{ 'name':'R_Pack04_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack04_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack04_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='7',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='R4.2',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'R_Pack05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack05'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack05\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R2.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack05_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack05_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack05_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack05_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack05_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP10'], 'footprint':'Resistor_THT:R_Array_SIP10', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack05_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '9']}] }),
        Part(**{ 'name':'R_Pack05_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack05_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack05_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='9',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='8',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='7',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='6',name='R5.2',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '10']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '8']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['5', '6']}] }),
        Part(**{ 'name':'R_Pack06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack06'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack06\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R4.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack06_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack06_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack06_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack06_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack06_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP12'], 'footprint':'Resistor_THT:R_Array_SIP12', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack06_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='11',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='12',name='R6.2',func=pin_types.PASSIVE,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '7']},{'label': 'uE', 'num': 5, 'pin_nums': ['9', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['11', '12']}] }),
        Part(**{ 'name':'R_Pack06_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack06_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack06_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='10',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='9',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='8',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='7',name='R6.2',func=pin_types.PASSIVE,unit=6)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['9', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['5', '8']},{'label': 'uF', 'num': 6, 'pin_nums': ['7', '6']}] }),
        Part(**{ 'name':'R_Pack07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack07'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack07\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R6.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack07_SIP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack07_SIP'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP14'], 'footprint':'Resistor_THT:R_Array_SIP14', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack07_SIP\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack07_SIP_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack07_SIP_Split'}), 'ref_prefix':'RN', 'fplist':['Resistor_THT:R_Array_SIP14'], 'footprint':'Resistor_THT:R_Array_SIP14', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'http://www.vishay.com/docs/31509/csc.pdf', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack07_SIP_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='8',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='9',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='11',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='12',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='13',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='14',name='R7.2',func=pin_types.PASSIVE,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '6']},{'label': 'uD', 'num': 4, 'pin_nums': ['7', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['10', '9']},{'label': 'uF', 'num': 6, 'pin_nums': ['11', '12']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '13']}] }),
        Part(**{ 'name':'R_Pack07_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack07_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack07_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='12',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='11',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='10',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='9',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='8',name='R7.2',func=pin_types.PASSIVE,unit=7)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['14', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['12', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['11', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['5', '10']},{'label': 'uF', 'num': 6, 'pin_nums': ['6', '9']},{'label': 'uG', 'num': 7, 'pin_nums': ['8', '7']}] }),
        Part(**{ 'name':'R_Pack08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack08'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack08\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack08_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack08_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack08_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='14',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='13',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='12',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='11',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='10',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=8),
            Pin(num='9',name='R8.2',func=pin_types.PASSIVE,unit=8)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '16']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '14']},{'label': 'uD', 'num': 4, 'pin_nums': ['13', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '5']},{'label': 'uF', 'num': 6, 'pin_nums': ['6', '11']},{'label': 'uG', 'num': 7, 'pin_nums': ['10', '7']},{'label': 'uH', 'num': 8, 'pin_nums': ['8', '9']}] }),
        Part(**{ 'name':'R_Pack09', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack09'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack09\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R8.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack09_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack09_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack09_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='16',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='15',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='14',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='13',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='12',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='11',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=8),
            Pin(num='10',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=9)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '18']},{'label': 'uB', 'num': 2, 'pin_nums': ['17', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['15', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['14', '5']},{'label': 'uF', 'num': 6, 'pin_nums': ['6', '13']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '12']},{'label': 'uH', 'num': 8, 'pin_nums': ['8', '11']},{'label': 'uI', 'num': 9, 'pin_nums': ['9', '10']}] }),
        Part(**{ 'name':'R_Pack10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack10'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack10\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R10.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R9.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R8.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack10_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack10_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack10_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='18',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='17',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='16',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='15',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='14',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='13',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=8),
            Pin(num='12',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=9),
            Pin(num='10',name='R10.1',func=pin_types.PASSIVE,unit=10),
            Pin(num='11',name='R10.2',func=pin_types.PASSIVE,unit=10)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['20', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '19']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '18']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '17']},{'label': 'uE', 'num': 5, 'pin_nums': ['16', '5']},{'label': 'uF', 'num': 6, 'pin_nums': ['15', '6']},{'label': 'uG', 'num': 7, 'pin_nums': ['14', '7']},{'label': 'uH', 'num': 8, 'pin_nums': ['13', '8']},{'label': 'uI', 'num': 9, 'pin_nums': ['12', '9']},{'label': 'uJ', 'num': 10, 'pin_nums': ['10', '11']}] }),
        Part(**{ 'name':'R_Pack11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack11'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack11\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='R10.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='R11.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='R11.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='R10.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='R9.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='R8.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='R7.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='R6.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='R5.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='R4.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='R3.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='R2.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Pack11_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Pack11_Split'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network parallel topology isolated', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Pack11_Split\n\nR network parallel topology isolated', 'pins':[
            Pin(num='1',name='R1.1',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='R1.2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='R2.1',func=pin_types.PASSIVE,unit=2),
            Pin(num='21',name='R2.2',func=pin_types.PASSIVE,unit=2),
            Pin(num='20',name='R3.2',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='R3.1',func=pin_types.PASSIVE,unit=3),
            Pin(num='19',name='R4.2',func=pin_types.PASSIVE,unit=4),
            Pin(num='4',name='R4.1',func=pin_types.PASSIVE,unit=4),
            Pin(num='18',name='R5.2',func=pin_types.PASSIVE,unit=5),
            Pin(num='5',name='R5.1',func=pin_types.PASSIVE,unit=5),
            Pin(num='17',name='R6.2',func=pin_types.PASSIVE,unit=6),
            Pin(num='6',name='R6.1',func=pin_types.PASSIVE,unit=6),
            Pin(num='16',name='R7.2',func=pin_types.PASSIVE,unit=7),
            Pin(num='7',name='R7.1',func=pin_types.PASSIVE,unit=7),
            Pin(num='15',name='R8.2',func=pin_types.PASSIVE,unit=8),
            Pin(num='8',name='R8.1',func=pin_types.PASSIVE,unit=8),
            Pin(num='14',name='R9.2',func=pin_types.PASSIVE,unit=9),
            Pin(num='9',name='R9.1',func=pin_types.PASSIVE,unit=9),
            Pin(num='10',name='R10.1',func=pin_types.PASSIVE,unit=10),
            Pin(num='13',name='R10.2',func=pin_types.PASSIVE,unit=10),
            Pin(num='11',name='R11.1',func=pin_types.PASSIVE,unit=11),
            Pin(num='12',name='R11.2',func=pin_types.PASSIVE,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['22', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '21']},{'label': 'uC', 'num': 3, 'pin_nums': ['20', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['19', '4']},{'label': 'uE', 'num': 5, 'pin_nums': ['18', '5']},{'label': 'uF', 'num': 6, 'pin_nums': ['6', '17']},{'label': 'uG', 'num': 7, 'pin_nums': ['7', '16']},{'label': 'uH', 'num': 8, 'pin_nums': ['15', '8']},{'label': 'uI', 'num': 9, 'pin_nums': ['14', '9']},{'label': 'uJ', 'num': 10, 'pin_nums': ['10', '13']},{'label': 'uK', 'num': 11, 'pin_nums': ['12', '11']}] }),
        Part(**{ 'name':'R_Photo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Photo'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable light sensitive opto LDR', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Photo\n\nresistor variable light sensitive opto LDR', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Dual', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Dual'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Dual\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Dual_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Dual_MountingPin'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Dual_MountingPin\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Dual_Separate', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Dual_Separate'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Dual_Separate\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='5',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '5', '6']}] }),
        Part(**{ 'name':'R_Potentiometer_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_MountingPin'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_MountingPin\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Small'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Small\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Trim', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Trim'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable trimpot trimmer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Trim\n\nresistor variable trimpot trimmer', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_Trim_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_Trim_US'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable trimpot trimmer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_Trim_US\n\nresistor variable trimpot trimmer', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Potentiometer_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Potentiometer_US'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'resistor variable', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Potentiometer_US\n\nresistor variable', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Shunt', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Shunt'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res shunt resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Shunt\n\nR res shunt resistor', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Shunt_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Shunt_US'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res shunt resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Shunt_US\n\nR res shunt resistor', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Small'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Small\n\nR resistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Small_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Small_US'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'r resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Small_US\n\nr resistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Trim', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Trim'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor variable potentiometer trimmer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Trim\n\nR res resistor variable potentiometer trimmer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_US'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_US\n\nR res resistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Variable', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Variable'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor variable potentiometer rheostat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Variable\n\nR res resistor variable potentiometer rheostat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'R_Variable_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'R_Variable_US'}), 'ref_prefix':'R', 'fplist':[''], 'footprint':'', 'keywords':'R res resistor variable potentiometer rheostat', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nR_Variable_US\n\nR res resistor variable potentiometer rheostat', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Resonator', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Resonator'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'ceramic resonator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nResonator\n\nceramic resonator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Resonator_Small', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Resonator_Small'}), 'ref_prefix':'Y', 'fplist':[''], 'footprint':'', 'keywords':'ceramic resonator', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nResonator_Small\n\nceramic resonator', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RotaryEncoder', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RotaryEncoder'}), 'ref_prefix':'SW', 'fplist':[''], 'footprint':'', 'keywords':'rotary switch encoder', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nRotaryEncoder\n\nrotary switch encoder', 'pins':[
            Pin(num='A',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='C',name='C',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RotaryEncoder_Switch', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RotaryEncoder_Switch'}), 'ref_prefix':'SW', 'fplist':[''], 'footprint':'', 'keywords':'rotary switch encoder switch push button', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nRotaryEncoder_Switch\n\nrotary switch encoder switch push button', 'pins':[
            Pin(num='A',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='C',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='S1',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='S2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RotaryEncoder_Switch_MP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RotaryEncoder_Switch_MP'}), 'ref_prefix':'SW', 'fplist':[''], 'footprint':'', 'keywords':'rotary switch encoder switch push button', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nRotaryEncoder_Switch_MP\n\nrotary switch encoder switch push button', 'pins':[
            Pin(num='A',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='B',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='C',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MP',func=pin_types.PASSIVE,unit=1),
            Pin(num='S1',name='S1',func=pin_types.PASSIVE,unit=1),
            Pin(num='S2',name='S2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Solar_Cell', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Solar_Cell'}), 'ref_prefix':'SC', 'fplist':[''], 'footprint':'', 'keywords':'solar cell', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSolar_Cell\n\nsolar cell', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Solar_Cells', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Solar_Cells'}), 'ref_prefix':'SC', 'fplist':[''], 'footprint':'', 'keywords':'solar cell', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSolar_Cells\n\nsolar cell', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SparkGap', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SparkGap'}), 'ref_prefix':'E', 'fplist':[''], 'footprint':'', 'keywords':'spark gap ESD electrostatic suppression', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSparkGap\n\nspark gap ESD electrostatic suppression', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Speaker', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Speaker'}), 'ref_prefix':'LS', 'fplist':[''], 'footprint':'', 'keywords':'speaker sound', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSpeaker\n\nspeaker sound', 'pins':[
            Pin(num='1',name='1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Speaker_Crystal', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Speaker_Crystal'}), 'ref_prefix':'LS', 'fplist':[''], 'footprint':'', 'keywords':'crystal speaker ultrasonic transducer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSpeaker_Crystal\n\ncrystal speaker ultrasonic transducer', 'pins':[
            Pin(num='1',name='1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'R res thermistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor\n\nR res thermistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_NTC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_NTC'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'thermistor NTC resistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_NTC\n\nthermistor NTC resistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_NTC_3Wire', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_NTC_3Wire'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'thermistor NTC resistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_NTC_3Wire\n\nthermistor NTC resistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_NTC_4Wire', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_NTC_4Wire'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'thermistor NTC resistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_NTC_4Wire\n\nthermistor NTC resistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_NTC_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_NTC_US'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'thermistor NTC resistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_NTC_US\n\nthermistor NTC resistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_PTC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_PTC'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'resistor PTC thermistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_PTC\n\nresistor PTC thermistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_PTC_3Wire', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_PTC_3Wire'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'resistor PTC thermistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_PTC_3Wire\n\nresistor PTC thermistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_PTC_4Wire', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_PTC_4Wire'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'resistor PTC thermistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_PTC_4Wire\n\nresistor PTC thermistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_PTC_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_PTC_US'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'resistor PTC thermistor sensor RTD', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_PTC_US\n\nresistor PTC thermistor sensor RTD', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermistor_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermistor_US'}), 'ref_prefix':'TH', 'fplist':[''], 'footprint':'', 'keywords':'R res thermistor', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermistor_US\n\nR res thermistor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermocouple', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermocouple'}), 'ref_prefix':'TC', 'fplist':[''], 'footprint':'', 'keywords':'thermocouple temperature sensor cold junction', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermocouple\n\nthermocouple temperature sensor cold junction', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermocouple_Alt', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermocouple_Alt'}), 'ref_prefix':'TC', 'fplist':[''], 'footprint':'', 'keywords':'thermocouple temperature sensor cold junction', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermocouple_Alt\n\nthermocouple temperature sensor cold junction', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Thermocouple_Block', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Thermocouple_Block'}), 'ref_prefix':'TC', 'fplist':[''], 'footprint':'', 'keywords':'thermocouple temperature sensor cold junction', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nThermocouple_Block\n\nthermocouple temperature sensor cold junction', 'pins':[
            Pin(num='1',name='+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_1P_1S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_1P_1S'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_1P_1S\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='AA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SB',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_1P_1S_SO8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_1P_1S_SO8'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_1P_1S_SO8\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='AA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SA',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SB',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_1P_2S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_1P_2S'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_1P_2S\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='AA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SB',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SC',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_1P_SS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_1P_SS'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_1P_SS\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='AA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SB',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_Audio', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_Audio'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet sound', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_Audio\n\ntransformer coil magnet sound', 'pins':[
            Pin(num='0',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='AA',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='SB',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_SP_1S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_SP_1S'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_SP_1S\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='PR1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PM',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PR2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='S1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='S2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Transformer_SP_2S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Transformer_SP_2S'}), 'ref_prefix':'T', 'fplist':[''], 'footprint':'', 'keywords':'transformer coil magnet', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nTransformer_SP_2S\n\ntransformer coil magnet', 'pins':[
            Pin(num='1',name='IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='PM',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT2A',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2B',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Varistor', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Varistor'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'VDR resistance', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVaristor\n\nVDR resistance', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Varistor_US', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Varistor_US'}), 'ref_prefix':'RV', 'fplist':[''], 'footprint':'', 'keywords':'VDR resistance', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVaristor_US\n\nVDR resistance', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VoltageDivider', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VoltageDivider'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network voltage divider', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVoltageDivider\n\nR network voltage divider', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VoltageDivider_CenterPin1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VoltageDivider_CenterPin1'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network voltage divider', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVoltageDivider_CenterPin1\n\nR network voltage divider', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VoltageDivider_CenterPin3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VoltageDivider_CenterPin3'}), 'ref_prefix':'RN', 'fplist':[''], 'footprint':'', 'keywords':'R network voltage divider', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVoltageDivider_CenterPin3\n\nR network voltage divider', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Voltmeter_AC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Voltmeter_AC'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'voltmeter AC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVoltmeter_AC\n\nvoltmeter AC', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Voltmeter_DC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Voltmeter_DC'}), 'ref_prefix':'MES', 'fplist':[''], 'footprint':'', 'keywords':'voltmeter DC', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nVoltmeter_DC\n\nvoltmeter DC', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_C'}), 'ref_prefix':'C', 'fplist':['', ''], 'footprint':'', 'keywords':'EMI filter feedthrough capacitor', 'description':'', 'datasheet':'http://www.murata.com/~/media/webrenewal/support/library/catalog/products/emc/emifil/c31e.ashx?la=en-gb', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_C\n\nEMI filter feedthrough capacitor', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Filter_EMI_CommonMode', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Filter_EMI_CommonMode'}), 'ref_prefix':'FL', 'fplist':['', ''], 'footprint':'', 'keywords':'EMI common mode filter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nFilter_EMI_CommonMode\n\nEMI common mode filter', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Microphone_Ultrasound', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Microphone_Ultrasound'}), 'ref_prefix':'MK', 'fplist':['', ''], 'footprint':'', 'keywords':'microphone ultrasound crystal', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nMicrophone_Ultrasound\n\nmicrophone ultrasound crystal', 'pins':[
            Pin(num='1',name='-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Q_Photo_NPN_CE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Q_Photo_NPN_CE'}), 'ref_prefix':'Q', 'fplist':['', ''], 'footprint':'', 'keywords':'phototransistor NPN', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nQ_Photo_NPN_CE\n\nphototransistor NPN', 'pins':[
            Pin(num='1',name='C',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='E',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Speaker_Ultrasound', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Speaker_Ultrasound'}), 'ref_prefix':'LS', 'fplist':['', ''], 'footprint':'', 'keywords':'crystal speaker ultrasonic transducer', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Device.kicad_sym\nSpeaker_Ultrasound\n\ncrystal speaker ultrasonic transducer', 'pins':[
            Pin(num='1',name='1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])