from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_NXP_LPC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'LPC1102UK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1102UK'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-16_4x4_B2.17x2.32mm_P0.5mm'], 'footprint':'Package_CSP:WLCSP-16_4x4_B2.17x2.32mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1102_1104.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1102UK\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PIO1_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1104UK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1104UK'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-16_4x4_B2.17x2.32mm_P0.5mm'], 'footprint':'Package_CSP:WLCSP-16_4x4_B2.17x2.32mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1102_1104.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1104UK\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='A1',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='PIO1_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-101'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-101\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHI33-102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHI33-102'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHI33-102\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11E12FBD48-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11E12FBD48-201'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'nxp lpc arm microcontroller cortex', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11E1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11E12FBD48-201\n\nnxp lpc arm microcontroller cortex', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U12FBD48-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U12FBD48-201'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U12FBD48-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1224FBD48-101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1224FBD48-101'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1224FBD48-101\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1224FBD64-101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1224FBD64-101'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1224FBD64-101\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1763FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1763FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM 32-bit Cortex-M3 M3 NXP microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1763FBD100\n\nARM 32-bit Cortex-M3 M3 NXP microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC2141FBD64', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC2141FBD64'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC2141_42_44_46_48.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC2141FBD64\n\nARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'pins':[
            Pin(num='1',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.31',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.31',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P1.26',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.25',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RTXC1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.24',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1.23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P1.22',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='P1.21',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P1.20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RTXC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P1.30',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P1.29',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='P1.28',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='P1.27',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P1.18',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.25',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC811M001JDH16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC811M001JDH16'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC81XM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC811M001JDH16\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC812M101JD20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC812M101JD20'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC81XM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC812M101JD20\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC812M101JDH20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC812M101JDH20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC81XM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC812M101JDH20\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC812M101JTB16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC812M101JTB16'}), 'ref_prefix':'U', 'fplist':['Package_SON:NXP_XSON-16'], 'footprint':'Package_SON:NXP_XSON-16', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC81XM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC812M101JTB16\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC822M101JDH20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC822M101JDH20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC82X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC822M101JDH20\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC822M101JHI33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC822M101JHI33'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC82X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC822M101JHI33\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_26',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_25',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_24',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-102'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-102\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-103', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-103'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-103\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-201'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-202\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111FHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111FHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111FHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111JHN33-103', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111JHN33-103'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111JHN33-103\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1111JHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1111JHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1111JHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHI33-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHI33-202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHI33-202\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHI33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHI33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHI33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-101', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-101'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-101\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-102'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-102\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-103', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-103'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-103\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-201'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-202\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112FHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112FHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112FHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112JHI33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112JHI33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112JHI33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112JHN33-103', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112JHN33-103'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112JHN33-103\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1112JHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1112JHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1112JHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FBD48-302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FBD48-302'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FBD48-302\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-201'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-202\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-301'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-302'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-302\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113FHN33-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113FHN33-303'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113FHN33-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113JBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113JBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113JBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113JHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113JHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113JHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1113JHN33-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1113JHN33-303'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1113JHN33-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FBD48-302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FBD48-302'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FBD48-302\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FBD48-323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FBD48-323'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FBD48-323\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FBD48-333', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FBD48-333'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FBD48-333\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHI33-302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHI33-302'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHI33-302\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHI33-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHI33-303'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHI33-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-201'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-202\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-301'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-302'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-302\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-303'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114FHN33-333', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114FHN33-333'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114FHN33-333\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114JBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114JBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114JBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114JBD48-323', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114JBD48-323'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114JBD48-323\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114JBD48-333', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114JBD48-333'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114JBD48-333\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114JHI33-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114JHI33-303'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114JHI33-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1114JHN33-203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1114JHN33-203'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.7x4.7mm_ThermalVias', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1114JHN33-203\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO1_8',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1115FBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1115FBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1115FBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1115JBD48-303', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1115JBD48-303'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC111X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1115JBD48-303\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO1_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO3_4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO3_5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO1_10',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO3_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO3_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO1_11',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO3_2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO1_7',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO3_3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO1_8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11E13FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11E13FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'nxp lpc arm microcontroller cortex', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11E1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11E13FBD48-301\n\nnxp lpc arm microcontroller cortex', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11E14FBD48-401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11E14FBD48-401'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'nxp lpc arm microcontroller cortex', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11E14FBD48-401\n\nnxp lpc arm microcontroller cortex', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U13FBD48-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U13FBD48-201'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U13FBD48-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U14FBD48-201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U14FBD48-201'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U1X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U14FBD48-201\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U22FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U22FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U2X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U22FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U23FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U23FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U2X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U23FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U24FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U24FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U2X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U24FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U24FBD48-401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U24FBD48-401'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U2X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U24FBD48-401\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U34FBD48-311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U34FBD48-311'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U3X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U34FBD48-311\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U34FBD48-421', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U34FBD48-421'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U3X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U34FBD48-421\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U35FBD48-401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U35FBD48-401'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U3X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U35FBD48-401\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U36FBD48-401', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U36FBD48-401'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U3X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U36FBD48-401\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC11U37FBD48-401_', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC11U37FBD48-401_'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC11U3X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC11U37FBD48-401_\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO1_25',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO1_26',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO1_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO1_20',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO1_23',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO1_19',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO1_24',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO1_28',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO1_31',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO1_21',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO1_29',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_13',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_14',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_22',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO1_15',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_16',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PIO0_20',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1224FBD48-121', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1224FBD48-121'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1224FBD48-121\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1224FBD64-121', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1224FBD64-121'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1224FBD64-121\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1225FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1225FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1225FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1225FBD48-321', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1225FBD48-321'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1225FBD48-321\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1225FBD64-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1225FBD64-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1225FBD64-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1225FBD64-321', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1225FBD64-321'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1225FBD64-321\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1226FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1226FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1226FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1226FBD64-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1226FBD64-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1226FBD64-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1227FBD48-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1227FBD48-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1227FBD48-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='48',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1227FBD64-301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1227FBD64-301'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/LPC122X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1227FBD64-301\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='XTALIN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PIO0_25/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_26/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO2_12',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO2_13',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO2_14',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO2_15',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_29',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XTALOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO2_0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='VREF_CMP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='PIO2_1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO2_2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO2_3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PIO2_4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PIO2_5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PIO2_6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PIO2_7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PIO0_12/~{ISP}',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PIO0_13/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PIO0_30',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PIO0_31',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PIO1_0',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PIO1_1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PIO1_2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='WAKEUP/PIO1_3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PIO1_4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='PIO1_5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='PIO1_6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='RTCXOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='58',name='RTCXIN',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='PIO2_8',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PIO2_9',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PIO2_10',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PIO2_11',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='VDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='VSSIO',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_24',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1764FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1764FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1764FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1765FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1765FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1765FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1766FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1766FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1766FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1767FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1767FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1767FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1768FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1768FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1768FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC1769FBD100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC1769FBD100'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'ARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC1769_68_67_66_65_64_63.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC1769FBD100\n\nARM, 32-bit, Cortex-M3, M3, NXP, microcontroller', 'pins':[
            Pin(num='1',name='TDO/SWO',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='100',name='RTCK',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='~{RSTOUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='RTCX1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RTCX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='P1[31]',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P1[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='P0[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P0[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='P0[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TMS/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P0[30]',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P1[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P1[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P1[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P1[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P1[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P1[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P1[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{TRST}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='P1[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P1[27]',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P1[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P1[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P0[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P0[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SWDCLK',func=pin_types.INPUT,unit=1),
            Pin(num='50',name='P2[13]',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P2[12]',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P2[11]',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P2[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='55',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='P0[22]',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='P0[21]',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P0[20]',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P0[19]',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P0[26]',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P0[18]',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P0[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P0[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='P0[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='P2[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='P2[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P2[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P2[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P2[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P2[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P0[25]',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P2[3]',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='72',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='73',name='P2[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P2[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P2[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='P0[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='P0[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='P0[7]',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='P0[6]',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P0[24]',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='P0[5]',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='P0[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='P4[28]',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='VDD(REG)(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='85',name='P4[29]',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='P1[17]',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='P1[16]',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='P1[15]',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='P1[14]',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0[23]',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='P1[10]',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='P1[9]',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='P1[8]',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='P1[4]',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='P1[1]',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='P1[0]',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='VDD(3V3)',func=pin_types.PWRIN,unit=1),
            Pin(num='97',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='98',name='P0[2]',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P0[3]',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC2142FBD64', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC2142FBD64'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC2141_42_44_46_48.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC2142FBD64\n\nARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'pins':[
            Pin(num='1',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.31',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.31',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P1.26',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.25',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RTXC1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.24',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1.23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P1.22',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='P1.21',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P1.20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RTXC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P1.30',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P1.29',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='P1.28',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='P1.27',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P1.18',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.25',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC2144FBD64', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC2144FBD64'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC2141_42_44_46_48.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC2144FBD64\n\nARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'pins':[
            Pin(num='1',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.31',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.31',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P1.26',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.25',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RTXC1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.24',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1.23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P1.22',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='P1.21',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P1.20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RTXC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P1.30',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P1.29',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='P1.28',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='P1.27',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P1.18',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.25',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC2146FBD64', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC2146FBD64'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC2141_42_44_46_48.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC2146FBD64\n\nARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'pins':[
            Pin(num='1',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.31',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.31',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P1.26',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.25',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RTXC1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.24',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1.23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P1.22',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='P1.21',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P1.20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RTXC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P1.30',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P1.29',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='P1.28',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='P1.27',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P1.18',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.25',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC2148FBD64', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC2148FBD64'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'Package_QFP:LQFP-64_10x10mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-64_10x10mm_P0.5mm', 'keywords':'ARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC2141_42_44_46_48.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC2148FBD64\n\nARM, 16-bit, 32-bit, ARM7, NXP, microcontroller', 'pins':[
            Pin(num='1',name='P0.21',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.17',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P0.28',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P0.29',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P0.30',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P1.16',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P0.31',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='P0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P0.22',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P1.31',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P1.26',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='P0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P1.25',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RTXC1',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='P0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P0.7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P1.24',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P0.8',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='P0.9',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P0.10',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P1.23',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P0.11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='P0.12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P0.13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.19',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P1.22',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='P0.14',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='P1.21',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='P0.15',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P0.16',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P0.17',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P1.20',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='RTXC2',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='51',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='52',name='P1.30',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P0.18',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P0.19',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='P0.20',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='P1.29',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='58',name='P0.23',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='VSSA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='P1.28',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='62',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='P1.27',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P1.18',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P0.25',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC812M001JDH16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC812M001JDH16'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC81XM.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC812M001JDH16\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC824M201JDH20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC824M201JDH20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC82X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC824M201JDH20\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC824M201JHI33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC824M201JHI33'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC82X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC824M201JHI33\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_26',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_25',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_24',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC832M101FDH20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC832M101FDH20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC83X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC832M101FDH20\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_10',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LPC834M101FHI33', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LPC834M101FHI33'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'ARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/LPC83X.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_NXP_LPC.kicad_sym\nLPC834M101FHI33\n\nARM, 32-bit, Cortex-M0, M0, NXP, microcontroller', 'pins':[
            Pin(num='1',name='PIO0_13',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PIO0_16',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PIO0_27',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PIO0_26',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PIO0_25',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PIO0_24',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PIO0_15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PIO0_1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PIO0_9',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PIO0_8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PIO0_12',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VREFN',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VREFP',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='PIO0_7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PIO0_6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PIO0_0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PIO0_14',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PIO0_23',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PIO0_22',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PIO0_21',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PIO0_20',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PIO0_5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PIO0_19',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PIO0_18',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PIO0_17',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PIO0_4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PIO0_28',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PIO0_3',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PIO0_2',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PIO0_11',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PIO0_10',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])