from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Texas_MSP430 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CC430F5137xRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CC430F5137xRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'keywords':'TI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cc430f5137.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nCC430F5137xRGZ\n\nTI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'pins':[
            Pin(num='1',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RF_XIN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RF_XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='RF_P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RF_N',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GUARD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TEST',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P1.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE221IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE221IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe221.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE221IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE222IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE222IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe222.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE222IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE223IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE223IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe223.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE223IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SD2DO/URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A2.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A2.0-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1101AIDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1101AIDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1101a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1101AIDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1101AIDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1101AIDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1101a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1101AIDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1101AIPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1101AIPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1101a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1101AIPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1101AIRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1101AIRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1101a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1101AIRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1122IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1122IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1122IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1122IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1122IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1122IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1122IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1122IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1122IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1222IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1222IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1222.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1222IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1222IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1222IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1222.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1222IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1222IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1222IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1222.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1222IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F122IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F122IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F122IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F122IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F122IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F122IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F122IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F122IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F122IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/STE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2001IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2001IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2001IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/CAOUT/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2001IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2001IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2001IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/CAOUT/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2001IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2001IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2001IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA4/TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA5/TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA6/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA7/TDO/TDI/CAOUT/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2002IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2002IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2002.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2002IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2002IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2002IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2002.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2002IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2002IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2002IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2002.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2002IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2003IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2003IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2003.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2003IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2003IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2003IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2003.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2003IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2003IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2003IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2003.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2003IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2101IDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2101IDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2101IDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2101IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2101IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2101IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2101IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2101IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2101IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2101IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2101IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2101IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2112IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2112IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2112IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2112IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2112IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2112IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2112IRTV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2112IRTV'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2112IRTV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2232IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2232IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2232IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2232IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2232IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2232IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.0/TACLK/ADC10CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2232IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2232IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2232IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2234IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2234IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2234.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2234IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2234IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2234IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2234.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2234IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2234IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2234IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2234.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2234IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/OA0I0/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/OA0I1/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/OA0O/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/OA1I1/OA1O/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/OA1I0/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2330IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2330IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2330.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2330IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0/P1.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2330IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2330IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2330.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2330IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2618-EP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2618-EP'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2618-ep.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2618-EP\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A10',name='P8.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='P7.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='P7.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='A1/P6.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='XT2IN/P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='XT2OUT/P8.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='P8.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='A3/P6.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='P8.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B12',name='P7.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='A2/P6.2',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P8.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='P8.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P6.4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P7.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P7.3',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='DAC1/A5/P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DAC1/A5/P6.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='DAC0/A6/P6.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P7.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P7.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='SVSIN/DAC1/A7/P6.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='A0/P6.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='P8.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='E11',name='P7.0',func=pin_types.PWRIN,unit=1),
            Pin(num='E12',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='VREF+',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F1',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='F11',name='SVSOUT/TBOUTH/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='VeREF+/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G1',name='VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='SMCLK/P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='ACLK/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P1.0/TACLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='P1.1/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='UCA1STE/UCB1CLK/P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='MCLK/P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P1.2/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='P1.3/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='UCB1SDA/UCB1SIMO/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='UCB1SCL/UCB1SOMI/P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P1.4/SMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='P2.6/ADC12CLK/DMAE0/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P1.5/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='UCA1CLK/UCB1STE/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P1.6/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='P1.7/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='P4.3/TB3',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L12',name='P4.6/TB6',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L3',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='P2.7/TA0/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='P3.7/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='P4.4/TB4',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='P4.5/TB5',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='P2.1/TAINCLK/CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='M4',name='P2.5/Rosc/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='P3.6/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='P4.0/TB0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5217IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5217IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5217.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5217IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5217IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5217IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5217.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5217IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5227IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5227IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5227.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5227IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5227IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5227IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5227.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5227IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5232IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5232IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5232IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5237IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5237IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5237.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5237IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5242IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5242IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5242.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5242IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5247IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5247IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5247.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5247IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5304IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5304IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5304.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5304IPT\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5304IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5304IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5304.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5304IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5308IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5308IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5308.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5308IPT\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5308IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5308IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5308.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5308IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5308IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5308IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5308.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5308IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5308IZQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5308IZQE'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5308.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5308IZQE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5333IPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5333IPZ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5333IPZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5333IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5333IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5333IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5336IPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5336IPZ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5336.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5336IPZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5336IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5336IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5336.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5336IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5340IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5340IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5340.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5340IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P5.7/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS1',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5358IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5358IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5358.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5358IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6/UCB2SOMI/UCB2SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5/UCB2SIMO/UCB2SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3/UCA2RXD/UCA2SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2/UCA2TXD/UCA2SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P5.0/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P5.7/RTCCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='P5.1/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4/UCB2CLK/UCA2STE',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1/UCB2STE/UCA2CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2.0/P2MAP0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P5.6/ADC12CLK/DMAE0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2.1/P2MAP1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2.3/P2MAP3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='P1.3/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2.2/P2MAP2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2.4/P2MAP4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='P1.2/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='P1.6/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='P3.4/TA2CLK/SMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='P4.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2.5/P2MAP5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='P4.6/TB0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='P4.7/TB0OUTH/SVMOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2.6/P2MAP6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='P4.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='P4.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='P4.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2.7/P2MAP7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='P1.0/TA0CLK/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='P1.5/TA0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='P3.0/TA1CLK/CBOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='P3.6/TA2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='P3.7/TA2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='P4.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='P4.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='P1.1/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='P1.4/TA0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='P1.7/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='P3.5/TA2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5500IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5500IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5500.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5500IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5504IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5504IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5504.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5504IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5508IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5508IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5508.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5508IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5524IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5524IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5524.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5524IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='F2',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5630IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5630IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5630.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5630IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5633IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5633IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5633.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5633IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5636IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5636IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5636.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5636IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5658IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5658IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5658.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5658IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='P6.6/A6/DAC0/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/A12/CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6/UCB2SOMI/UCB2SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5/UCB2SIMO/UCB2SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/A7/DAC1/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/A13/CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/A15/DAC1/CB11',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3/UCA2RXD/UCA2SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2/UCA2TXD/UCA2SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/A14/DAC0/CB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4/UCB2CLK/UCA2STE',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1/UCB2STE/UCA2CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DMAE0/ADC12CLK/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='SMCLK/TA2CLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='SVMOUT/TB0OUTH/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='CBOUT/TA1CLK/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5720IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5720IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5720.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5720IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5722IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5722IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5722.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5722IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2001IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2001IN14'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2001IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2001IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2001IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2001IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2001IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2001IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2001.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2001IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2102IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2102IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2102.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2102IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2102IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2102IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2102.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2102IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2102IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2102IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2102.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2102IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2102IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2102IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2102.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2102IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2111IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2111IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2111IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/ADC10CLK/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2111IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2111IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2111IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/ADC10CLK/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2111IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2111IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2111IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TA0CLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2112IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2112IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2112IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2112IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2112IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2112IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2112IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2112IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2112IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2112IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2112IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2112.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2112IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2113IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2113IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2153.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2113IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2121IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2121IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2121IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2121IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2121IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2121IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2121IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2121IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2121IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2131IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2131IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2131IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2131IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2131IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2131IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2131IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2131IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2131IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2132IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2132IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2132IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2132IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2132IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2132IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/A4/VREF+/VeREF+/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2132IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2132IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2132IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2132IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2132IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2132IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2152IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2152IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2152.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2152IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2152IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2152IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2152.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2152IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2152IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2152IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2152.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2152IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2152IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2152IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2152.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2152IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/SCLK/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/SDI/SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2153IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2153IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2153.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2153IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2153IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2153IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2153.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2153IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2153IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2153IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2153.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2153IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2153IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2153IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2153.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2153IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2203IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2203IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2203.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2203IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2203IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2203IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2203.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2203IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2203IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2203IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2203.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2203IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2203IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2203IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2203.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2203IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2210ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2210ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2210.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2210ID\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2213IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2213IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2213.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2213IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2213IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2213IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2213.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2213IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2213IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2213IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2213.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2213IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2230ID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2230ID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2230.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2230ID\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/SCLK/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/SDO/SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SDI/SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='DVSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2233IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2233IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2233.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2233IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2233IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2233IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2233.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2233IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2233IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2233IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2233.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2233IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2233IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2233IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2233.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2233IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2444IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2444IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2444.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2444IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2444IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2444IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2444.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2444IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2444IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2444IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2444.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2444IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2755IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2755IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2755.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2755IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2755IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2755IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2755.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2755IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A6/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CC430F5133xRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CC430F5133xRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'keywords':'TI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cc430f5137.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nCC430F5133xRGZ\n\nTI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'pins':[
            Pin(num='1',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RF_XIN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RF_XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='RF_P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RF_N',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GUARD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TEST',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P1.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CC430F5135xRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CC430F5135xRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:VQFN-48-1EP_7x7mm_P0.5mm_EP4.1x4.1mm_ThermalVias', 'keywords':'TI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/cc430f5137.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nCC430F5135xRGZ\n\nTI MSP430 CC430 16-bit mixed signal microcontroller CC1101', 'pins':[
            Pin(num='1',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='RF_XIN',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RF_XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='RF_P',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RF_N',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='AVCC_RF',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC_RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='RBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GUARD',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TEST',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='DVCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='P1.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE231IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE231IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe231.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE231IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE232IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE232IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE232IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE233IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE233IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe233.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE233IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SD2DO/URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A2.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A2.0-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE251IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE251IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe251.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE251IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE252IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE252IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE252IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='(AVSS)',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='(AVSS)',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430AFE253IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430AFE253IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-24_4.4x7.8mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430afe253.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430AFE253IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TA2/SMCLK/TACLK/SVSIN/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='XT2IN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='XT2OUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='SDCLK/TA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='SD0DO/TA0/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SD1DO/UTXD0/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='SD2DO/URXD0/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TMS/SVSOUT/SIMO0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TCK/TA2/SOMI0/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDI/TDO/TA1/UCLK0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TCLK/TDI/TA0/STE0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A1.0-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A2.0+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='A2.0-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1111AIDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1111AIDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1111a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1111AIDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1111AIDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1111AIDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1111a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1111AIDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1111AIPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1111AIPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1111a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1111AIPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1111AIRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1111AIRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1111a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1111AIRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1121AIDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1121AIDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1121a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1121AIDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1121AIDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1121AIDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1121a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1121AIDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1121AIPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1121AIPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1121a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1121AIPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1121AIRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1121AIRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1121a.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1121AIRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/CA0/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/CA1/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1132IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1132IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1132IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1132IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1132IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1132IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1132IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1132IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1132IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='P2.3/A3/VREF-/VeREF-/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.4/A4/VREF+/VeREF+/TA2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='P2.5/Rosc',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/A0/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/A1/INCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/A2/TA0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1232IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1232IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1232IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1232IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1232IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1232IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F1232IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F1232IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f1232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F1232IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1/VeREF-/VREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA2/VeREF+/VREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='INCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/A5/STE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F123IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F123IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-28W_7.5x17.9mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f123.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F123IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F123IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F123IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f123.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F123IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/STE0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F123IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F123IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f123.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F123IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/SIMO0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/SOMI0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCLK0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UTXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/URXD0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='INCLK/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/CAOUT/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/STE0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2011IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2011IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2011.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2011IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/CAOUT/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2011IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2011IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2011.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2011IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/CAOUT/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2011IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2011IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2011.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2011IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA3/CAOUT/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CA4/TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA5/TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA6/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA7/TDO/TDI/CAOUT/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2012IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2012IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2012.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2012IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2012IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2012IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2012.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2012IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2012IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2012IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2012.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2012IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='A0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/A3/VREF-/VeREF-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/A4/VREF+/VeREF+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0/A5/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA1/A6/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A7/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2013IN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2013IN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2013.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2013IN\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2013IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2013IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2013.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2013IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2013IRSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2013IRSA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2013.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2013IRSA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TACLK/ACLK/A0+/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0/A0-/A4+/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA1/A1+/A4-/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VREF/A1-/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/A2+/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0/A2-/SCLK/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA1/A3+/SDO/SCL/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='A3-/SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2111IDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2111IDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2111IDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2111IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2111IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2111IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2111IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2111IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2111IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2111IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2111IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2111.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2111IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2121IDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2121IDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2121IDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2121IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2121IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2121IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2121IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2121IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2121IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2121IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2121IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2121.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2121IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2122IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2122IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2122IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2122IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2122IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2122IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2122IRTV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2122IRTV'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2122.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2122IRTV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2131IDGV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2131IDGV'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2131IDGV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2131IDW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2131IDW'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2131IDW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2131IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2131IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2131IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2131IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2131IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm'], 'footprint':'Package_DFN_QFN:VQFN-24-1EP_4x4mm_P0.5mm_EP2.45x2.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2131.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2131IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='10',name='P2.3/TA1/CA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.4/TA2/CA1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='TA1/TCLK/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='P2.5/CA5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P2.7/XOUT/CA7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P2.6/XIN/CA6',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P2.0/ACLK/CA2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P2.1/INCLK/CA3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.2/CAOUT/TA0/CA4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2132IPW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2132IPW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2132IPW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2132IRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2132IRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2132IRHB\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2132IRTV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2132IRTV'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2132.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2132IRTV\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.6/A6/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P3.7/A7/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='CA0/TA0.1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CA1/TA0.2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='CA7/XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='CAOUT/TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.0/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CA6/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='CA5/Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA2/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA3/TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CAOUT/CA4/TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2252IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2252IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2252IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2252IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2252IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2252IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.0/TACLK/ADC10CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2252IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2252IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2252IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2254IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2254IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2254.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2254IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2254IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2254IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2254.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2254IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2254IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2254IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2254.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2254IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/OA0I0/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/OA0I1/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/OA0O/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/OA1I1/OA1O/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/OA1I0/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2272IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2272IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2272.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2272IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2272IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2272IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2272.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2272IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P1.0/TACLK/ADC10CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2272IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2272IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2272.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2272IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2274IDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2274IDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2274.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2274IDA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2274IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2274IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2274.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2274IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/A3/VREF-/VeREF-/OA1I1/OA1O/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/A4/VREF+/VeREF+/OA1I0/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA1/TDI/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA2/TDI/TDO/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='ACLK/A0/OA0I0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/OA0O/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/OA0I1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2274IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2274IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2274.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2274IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/OA0I0/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/OA0I1/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/OA0O/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TA2/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TA0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TA1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/TB0/A12/OA0O',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/OA1I1/OA1O/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6/OA0I2',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/TB2/A14/OA0I3',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/TB1/A13/OA1O',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/OA1I0/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7/OA1I2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/TBOUTH/A15/OA1I3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2350IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2350IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2350.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2350IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0/P1.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2350IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2350IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2350.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2350IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2370IRHA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2370IRHA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2370.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2370IRHA\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0/P1.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F2370IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F2370IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f2370.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F2370IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='XIN/CA6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='XOUT/CA7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B4',name='TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='C4',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='ACLK/CA2/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0/CAOUT/CA4/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TAINCLK/CA3/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='TDI/TCLK',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA2/CA1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1/CA0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TDO/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='P3.0/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='ROSC/CA5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P4.5/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P4.6/TBOUTH/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P4.3/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P4.4/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5219IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5219IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5219.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5219IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5219IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5219IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5219.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5219IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5229IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5229IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5229.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5229IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5229IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5229IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5229.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5229IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='BSLEN',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E5',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVIO',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5234IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5234IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5234.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5234IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5239IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5239IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5239.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5239IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5244IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5244IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5244.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5244IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5249IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5249IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5249.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5249IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='P7.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='P7.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='P7.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='P7.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='P7.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='P7.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='~{RST}/NMI',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RSTDVCC}/SBWTDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5309IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5309IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5309.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5309IPT\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5309IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5309IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5309.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5309IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5309IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5309IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5309.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5309IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5309IZQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5309IZQE'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5309.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5309IZQE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5310IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5310IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5310.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5310IPT\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5310IRGC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5310IRGC'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:Texas_RGC0064B_VQFN-64-1EP_9x9mm_P0.5mm_EP4.25x4.25mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5310.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5310IRGC\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='54',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='56',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='57',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5310IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5310IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5310.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5310IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5310IZQE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5310IZQE'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-80_5.0x5.0mm_Layout9x9_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5310.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5310IZQE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='A4',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='LDOO',func=pin_types.PWROUT,unit=1),
            Pin(num='A7',name='LDOI',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A9',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B9',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C9',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='D7',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E9',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F1',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G1',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='CBOUT/TA1CLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G9',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='H2',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H9',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J4',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='SMCLK/TA2CLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5335IPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5335IPZ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5335.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5335IPZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5335IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5335IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5335.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5335IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5338IPZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5338IPZ'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-100_14x14mm_P0.5mm', 'Package_QFP:LQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-100_14x14mm_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5338.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5338IPZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='66',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='76',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='77',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='84',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='86',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='91',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='92',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5338IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5338IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5338.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5338IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5341IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5341IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5341.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5341IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P5.7/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS1',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5342IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5342IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5342.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5342IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PM_NONE/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PM_NONE/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='P5.7/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AVSS1',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5359IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5359IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5359.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5359IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='LDOI',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='LDOO',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6/UCB2SOMI/UCB2SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5/UCB2SIMO/UCB2SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3/UCA2RXD/UCA2SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2/UCA2TXD/UCA2SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='P5.0/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P5.7/RTCCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='P5.1/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4/UCB2CLK/UCA2STE',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1/UCB2STE/UCA2CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2.0/P2MAP0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='P5.6/ADC12CLK/DMAE0',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2.1/P2MAP1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2.3/P2MAP3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='P1.3/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2.2/P2MAP2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2.4/P2MAP4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='P1.2/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='P1.6/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='P3.4/TA2CLK/SMCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='P4.0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2.5/P2MAP5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='P4.6/TB0.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='P4.7/TB0OUTH/SVMOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2.6/P2MAP6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='P4.2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='P4.5/TB0.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='P4.4/TB0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2.7/P2MAP7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='P1.0/TA0CLK/ACLK',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='P1.5/TA0.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='P3.0/TA1CLK/CBOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='P3.6/TA2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='P3.7/TA2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='P4.1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='P4.3/TB0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='P1.1/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='P1.4/TA0.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='P1.7/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='P3.5/TA2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5501IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5501IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5501.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5501IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5502IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5502IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5502.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5502IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5503IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5503IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5503.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5503IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5505IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5505IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5505.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5505IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5506IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5506IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5506.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5506IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5507IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5507IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5507.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5507IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5509IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5509IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5509.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5509IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5510IRGZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5510IRGZ'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm'], 'footprint':'Package_DFN_QFN:Texas_RGZ0048A_VQFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5510.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5510IRGZ\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCORE',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='P5.0/A8/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P5.1/A9/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5526IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5526IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5526.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5526IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='F2',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5528IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5528IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-64_3.415x3.535mm_Layout8x8_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5528.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5528IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='P5.4/XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P5.5/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='A8',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='B1',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B2',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P5.0/A8/VREF+/VeREF+',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P5.1/A9/VREF-/VeREF-',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P5.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='D3',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='TA1CLK/CBOUT/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='TA1.0/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='P5.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='E4',name='P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='TA1.1/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E6',name='TA2.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='TA2CLK/SMCLK/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='TA1.2/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VUSB',func=pin_types.PWROUT,unit=1),
            Pin(num='F2',name='VBUS',func=pin_types.PWRIN,unit=1),
            Pin(num='F3',name='P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='PM_UCB1CLK/PM_UCA1STE/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='PM_UCB1STE/PM_UCA1CLK/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='RTCCLK/DMAE0/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='TA2.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='F8',name='TA2.1/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='PM_UCA1RXD/PM_UCA1SOMI/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='PM_UCB1SOMI/PM_UCB1SCL/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='UCA0RXD/UCA0SOMI/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='UCA0TXD/UCA0SIMO/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='UCB0CLK/UCA0STE/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='G8',name='UCB0SIMO/UCB0SDA/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='H3',name='PM_UCA1TXD/PM_UCA1SIMO/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='PM_UCB1SIMO/PM_UCB1SDA/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='H7',name='UCB0SOMI/UCB0SCL/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='UCB0STE/UCA0CLK/P2.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5631IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5631IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5631.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5631IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5632IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5632IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5632.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5632IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5634IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5634IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5634.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5634IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5635IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5635IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5635.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5635IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5637IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5637IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5637.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5637IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5638IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5638IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5638.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5638IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/CB4/A4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.BIDIR,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/CB2/A2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.BIDIR,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='P6.6/CB6/A6/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/CB5/A5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/CB1/A1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/CB0/A0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='B9',name='V18',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='P7.4/CB8/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/CB7/A7/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/CB9/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/CB11/A15/DAC1',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/CB10/A14/DAC0',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/CB3/A3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.BIDIR,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.BIDIR,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='ADC12CLK/DMAE0/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='TA2CLK/SMCLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='TB0OUTH/SVMOUT/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='TA1CLK/CBOUT/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430F5659IZQW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430F5659IZQW'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm'], 'footprint':'Package_BGA:Texas_MicroStar_Junior_BGA-113_7.0x7.0mm_Layout12x12_P0.5mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430f5659.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430F5659IZQW\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='P6.4/A4/CB4',func=pin_types.BIDIR,unit=1),
            Pin(num='A10',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A11',name='PU.1/DM',func=pin_types.BIDIR,unit=1),
            Pin(num='A12',name='PU.0/DP',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='P6.2/A2/CB2',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='PJ.1/TDI/TCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='DVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A6',name='DVCC3',func=pin_types.PWRIN,unit=1),
            Pin(num='A7',name='VBAK',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='AVSS3',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VUSB',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='P6.6/A6/DAC0/CB6',func=pin_types.BIDIR,unit=1),
            Pin(num='B10',name='PUR',func=pin_types.BIDIR,unit=1),
            Pin(num='B11',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B12',name='VSSU',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='P6.5/A5/CB5',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='P6.1/A1/CB1',func=pin_types.BIDIR,unit=1),
            Pin(num='B4',name='P6.0/A0/CB0',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='PJ.0/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='P7.3/XT2OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='P7.2/XT2IN',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='P7.4/A12/CB8',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='P9.6/UCB2SOMI/UCB2SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='P9.5/UCB2SIMO/UCB2SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='P6.7/A7/DAC1/CB7',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='P7.5/A13/CB9',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='P7.7/A15/DAC1/CB11',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='P9.3/UCA2RXD/UCA2SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='D12',name='P9.2/UCA2TXD/UCA2SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='P7.6/A14/DAC0/CB10',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VREF+/VeREF+/P5.0',func=pin_types.BIDIR,unit=1),
            Pin(num='D5',name='P6.3/A3/CB3',func=pin_types.BIDIR,unit=1),
            Pin(num='D6',name='PJ.3/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='RTCCLK/P5.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D8',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='P9.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E11',name='P9.0',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='P8.7',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='AVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='E4',name='VREF-/VeREF-/P5.1',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E7',name='PJ.2/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='E8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='E9',name='P9.4/UCB2CLK/UCA2STE',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='XIN',func=pin_types.INPUT,unit=1),
            Pin(num='F11',name='P8.5/UCB1SIMO/UCB1SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='DVCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='F2',name='AVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='F4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='F9',name='P9.1/UCB2STE/UCA2CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='XOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='G11',name='P8.4/UCB1CLK/UCA1STE',func=pin_types.BIDIR,unit=1),
            Pin(num='G12',name='DVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G2',name='AVSS2',func=pin_types.PWRIN,unit=1),
            Pin(num='G4',name='P2MAP0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='G9',name='P8.6/UCB1SOMI/UCB1SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='H1',name='DMAE0/ADC12CLK/P5.6',func=pin_types.BIDIR,unit=1),
            Pin(num='H11',name='P8.2/UCA1TXD/UCA1SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='H12',name='P8.3/UCA1RXD/UCA1SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='H2',name='P2MAP1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H4',name='P2MAP3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H6',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='H7',name='TA1.0/P3.1',func=pin_types.BIDIR,unit=1),
            Pin(num='H8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='P2MAP2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J11',name='P8.0/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J12',name='P8.1/UCB1STE/UCA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='J2',name='P2MAP4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J5',name='P5.5',func=pin_types.BIDIR,unit=1),
            Pin(num='J6',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='J7',name='TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='J8',name='SMCLK/TA2CLK/P3.4',func=pin_types.BIDIR,unit=1),
            Pin(num='J9',name='TB0.0/P4.0',func=pin_types.BIDIR,unit=1),
            Pin(num='K1',name='P2MAP5/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='K11',name='TB0.6/P4.6',func=pin_types.BIDIR,unit=1),
            Pin(num='K12',name='SVMOUT/TB0OUTH/P4.7',func=pin_types.BIDIR,unit=1),
            Pin(num='K2',name='P2MAP6/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='L1',name='DVCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='L10',name='TB0.2/P4.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L11',name='TB0.5/P4.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L12',name='TB0.4/P4.4',func=pin_types.BIDIR,unit=1),
            Pin(num='L2',name='P2MAP7/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='P5.2',func=pin_types.BIDIR,unit=1),
            Pin(num='L4',name='P5.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L5',name='ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L6',name='TA0.4/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='L7',name='CBOUT/TA1CLK/P3.0',func=pin_types.BIDIR,unit=1),
            Pin(num='L8',name='TA1.2/P3.3',func=pin_types.BIDIR,unit=1),
            Pin(num='L9',name='TA2.1/P3.6',func=pin_types.BIDIR,unit=1),
            Pin(num='M1',name='DVSS1',func=pin_types.PWRIN,unit=1),
            Pin(num='M10',name='TA2.2/P3.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M11',name='TB0.1/P4.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M12',name='TB0.3/P4.3',func=pin_types.BIDIR,unit=1),
            Pin(num='M2',name='VCORE',func=pin_types.PWRIN,unit=1),
            Pin(num='M3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='M4',name='P5.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M5',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='M6',name='TA0.3/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='M7',name='TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='M8',name='TA1.1/P3.2',func=pin_types.BIDIR,unit=1),
            Pin(num='M9',name='TA2.0/P3.5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5724IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5724IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5724.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5724IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5726IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5726IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5726.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5726IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5728IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5728IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5728.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5728IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5730IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5730IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5730.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5730IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5732IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5732IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5732.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5732IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5734IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5734IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5734.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5734IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5736IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5736IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5736.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5736IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430FR5738IRGE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430FR5738IRGE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm'], 'footprint':'Package_DFN_QFN:Texas_RGE0024C_VQFN-24-1EP_4x4mm_P0.5mm_EP2.1x2.1mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430fr5738.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430FR5738IRGE\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.1/DMAE0/RTCCLK/CD0/VeREF-/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PJ.3/TCK/CD9',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TB0CLK/UCA0TXD/UCA0SIMO/ACLK/P2.0',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='TB0.0/UCA0RXD/UCA0SOMI/P2.1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='UCB0CLK/P2.2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TA0.0/UCB0SIMO/UCB0SDA/P1.6',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TA1.0/UCB0SOMI/UCB0SCL/P1.7',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VCORE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.2/TA1CLK/CDOUT/CD1/VeREF+/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PJ.4/XIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PJ.5/XOUT',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA1.1/TA0CLK/CDOUT/CD2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA1.2/UCB0STE/CD3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TB0.1/UCA0STE/CD4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TB0.2/UCA0CLK/CD5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PJ.0/TDO/TB0OUTH/SMCLK/CD6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PJ.1/TDI/TCLK/MCLK/CD7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PJ.2/TMS/ACLK/CD8',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2101IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2101IN14'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2101IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2101IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2101IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2101IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2101IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2101IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2101.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2101IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2201IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2201IN14'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm', 'Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2201.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2201IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2201IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2201IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2201.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2201IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2201IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2201IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2201.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2201IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2202IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2202IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2202.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2202IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2202IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2202IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2202.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2202IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2202IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2202IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2202.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2202IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2202IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2202IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2202.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2202IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2211IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2211IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2211.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2211IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/ADC10CLK/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2211IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2211IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2211.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2211IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CA0/TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CA1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CA2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/ADC10CLK/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='CA4/SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='CA5/TA0.0/TMS/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='CA6/TA0.1/TDI/TCLK/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='CA7/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2211IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2211IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2211.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2211IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TA0CLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2212IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2212IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2212.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2212IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2212IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2212IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2212.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2212IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2212IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2212IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2212.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2212IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2212IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2212IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2212.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2212IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2213IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2213IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2213.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2213IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2221IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2221IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2221.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2221IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2221IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2221IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2221.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2221IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2221IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2221IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2221.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2221IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2231IN14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2231IN14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2231.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2231IN14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2231IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2231IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2231.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2231IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2231IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2231IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2231.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2231IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/TACLK/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/SDO/SCL/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TDO/SDI/SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2232IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2232IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2232IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2232IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2232IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2232IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/A4/VREF+/VeREF+/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2232IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2232IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2232IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2232IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2232IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2232.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2232IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2252IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2252IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2252IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2252IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2252IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2252IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2252IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2252IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2252IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2252IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2252IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2252.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2252IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/SCLK/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/SDI/SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2253IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2253IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2253.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2253IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2253IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2253IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2253.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2253IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2253IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2253IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2253.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2253IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2253IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2253IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2253.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2253IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2302IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2302IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2302.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2302IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2302IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2302IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2302.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2302IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2302IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2302IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2302.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2302IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2302IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2302IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2302.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2302IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2303IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2303IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2303.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2303IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2303IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2303IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2303.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2303IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2303IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2303IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2303.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2303IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2303IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2303IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2303.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2303IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2312IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2312IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2312.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2312IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2312IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2312IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2312.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2312IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2312IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2312IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2312.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2312IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2312IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2312IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2312.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2312IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2313IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2313IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2313.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2313IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2313IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2313IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2313.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2313IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2313IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2313IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2313.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2313IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2313IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2313IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2313.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2313IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2332IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2332IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2332.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2332IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2332IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2332IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2332.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2332IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/A4/VREF+/VeREF+/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2332IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2332IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2332.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2332IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2332IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2332IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2332.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2332IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2333IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2333IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2333IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2333IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2333IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2333IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2333IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2333IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2333IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2333IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2333IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2333.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2333IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2352IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2352IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2352.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2352IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2352IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2352IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2352.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2352IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2352IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2352IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2352.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2352IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2352IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2352IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2352.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2352IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/SCLK/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/SDI/SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2353IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2353IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2353.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2353IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2353IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2353IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2353.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2353IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2353IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2353IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2353.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2353IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2353IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2353IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2353.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2353IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2402IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2402IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2402.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2402IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2402IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2402IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2402.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2402IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2402IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2402IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2402.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2402IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2402IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2402IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2402.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2402IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2403IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2403IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2403.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2403IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2403IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2403IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2403.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2403IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2403IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2403IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2403.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2403IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2403IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2403IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2403.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2403IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2412IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2412IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2412.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2412IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2412IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2412IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2412.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2412IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2412IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2412IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2412.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2412IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2412IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2412IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2412.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2412IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/SDI/SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2413IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2413IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2413.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2413IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2413IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2413IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2413.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2413IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2413IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2413IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2413.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2413IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2413IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2413IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2413.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2413IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2432IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2432IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2432.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2432IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2432IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2432IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2432.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2432IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='SMCLK/TCK/A4/VREF+/VeREF+/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2432IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2432IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2432.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2432IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A0/ACLK/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/VREF+/VeREF+/A4/SMCLK/TA0.2/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2432IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2432IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2432.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2432IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='ACLK/A0/TA0CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='A1/TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2/TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SMCLK/TCK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/SCLK/A5/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='SDO/SCL/TDI/TCLK/A6/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SDI/SDA/TDO/TDI/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2433IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2433IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2433.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2433IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2433IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2433IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2433.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2433IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2433IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2433IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2433.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2433IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2433IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2433IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2433.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2433IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2452IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2452IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2452.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2452IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2452IPW14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2452IPW14'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'Package_SO:TSSOP-14_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-14_4.4x5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2452.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2452IPW14\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2452IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2452IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2452.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2452IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/SDO/SCL/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/SDI/SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/CAOUT/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/SCLK/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2452IRSA16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2452IRSA16'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm'], 'footprint':'Package_DFN_QFN:Texas_RSA_VQFN-16-1EP_4x4mm_P0.65mm_EP2.7x2.7mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2452.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2452IRSA16\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='TA0.0/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA0.1/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TCK/SMCLK/TA0.2/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TMS/TA0.0/SCLK/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TDI/TCLK/TA0.1/SDO/SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TDO/TDI/CAOUT/SDI/SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2453IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2453IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2453.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2453IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2453IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2453IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2453.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2453IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2453IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2453IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2453.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2453IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2453IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2453IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2453.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2453IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2513IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2513IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2513.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2513IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2513IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2513IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2513.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2513IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2513IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2513IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2513.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2513IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2513IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2513IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2513.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2513IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CAOUT/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2533IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2533IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2533.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2533IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2533IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2533IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2533.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2533IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2533IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2533IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2533.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2533IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2533IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2533IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2533.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2533IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/UCB0SIMO/UCB0SDA/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/VREF-/VeREF-/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2544IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2544IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2544.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2544IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2544IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2544IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2544.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2544IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2544IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2544IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2544.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2544IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2553IN20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2553IN20'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm', 'Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2553.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2553IN20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2553IPW20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2553IPW20'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2553.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2553IPW20\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P2.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P2.3/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P2.4/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P2.5/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='TDI/TCLK/UCB0SOMI/UCB0SCL/TA0.1/CA6/A6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TDO/TDI/UCB0SIMO/UCB0SDA/CAOUT/CA7/A7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='TEST/SBWTCK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='P2.7/XOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P2.6/XIN/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/CA0/A0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='UCA0RXD/UCA0SOMI/TA0.0/CA1/A1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='UCA0TXD/UCA0SIMO/TA0.1/CA2/A2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='CAOUT/VREF-/VeREF-/CA3/A3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/CA4/A4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/UCB0CLK/UCA0STE/TA0.0/CA5/A5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P2.0/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P2.1/TA1.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2553IPW28', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2553IPW28'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-28_4.4x9.7mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2553.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2553IPW28\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2553IRHB32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2553IRHB32'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:Texas_RHB0032E_VQFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2553.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2553IRHB32\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='TA0.0/UCA0RXD/UCA0SOMI/A1/CA1/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='TA1.1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='TA1.1/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.2/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.3/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.4/TA0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='TA1.0/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='TA1.2/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='TA1.2/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P3.5/TA0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P3.6/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='TA0.1/UCA0TXD/UCA0SIMO/A2/CA2/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P3.7/TA1CLK/CAOUT',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='TDI/TCLK/TA0.1/UCB0SOMI/UCB0SCL/A6/CA6/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='TDO/TDI/CAOUT/UCB0SIMO/UCB0SDA/A7/CA7/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='TA0.1/XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADC10CLK/CAOUT/VREF-/VeREF-/A3/CA3/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='TA0CLK/ACLK/A0/CA0/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='TCK/SMCLK/UCB0STE/UCA0CLK/VREF+/VeREF+/A4/CA4/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='TMS/TA0.0/UCB0CLK/UCA0STE/A5/CA5/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='P3.1/TA1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='P3.0/TA0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA1.0/P2.0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2744IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2744IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2744.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2744IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='Rosc/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2744IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2744IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2744.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2744IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/TB0/A12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/TB1/A13',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/TB2/A14',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/TBOUTH/A15',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='SMCLK/TCK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/UCB0STE/UCA0CLK/A5',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2744IYFF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2744IYFF'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm'], 'footprint':'Package_BGA:Texas_DSBGA-49_3.33x3.488mm_Layout7x7_P0.4mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2744.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2744IYFF\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='A1',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='A2',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='A5',name='TA0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='A6',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='B3',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='B4',name='TAINCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='B6',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='C7',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='D2',name='TDO/TDI/TA2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='D6',name='P4.0/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='D7',name='P4.1/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='E1',name='TMS/TA0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='TA1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='TDI/TCLK/TA1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E5',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='E6',name='P4.2/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='P4.3/A12/TB0',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='TACLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='TA1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='P3.6/A6',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='P4.7/TBCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='F6',name='P4.5/A14/TB2',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='P4.4/A13/TB1',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='TA2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='TA0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='TA2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='G4',name='P3.7/A7',func=pin_types.BIDIR,unit=1),
            Pin(num='G5',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='G6',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='G7',name='P4.6/A15/TBOUTH',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2855IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2855IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2855.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2855IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2855IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2855IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2855.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2855IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A6/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2955IDA38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2955IDA38'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-38_6.1x12.5mm_P0.65mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2955.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2955IDA38\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='P3.7/A7/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MSP430G2955IRHA40', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MSP430G2955IRHA40'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040B_VQFN-40-1EP_6x6mm_P0.5mm_EP4.15x4.15mm', 'keywords':'TI MSP430 16-bit mixed signal microcontroller', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/msp430g2955.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Texas_MSP430.kicad_sym\nMSP430G2955IRHA40\n\nTI MSP430 16-bit mixed signal microcontroller', 'pins':[
            Pin(num='1',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='P3.1/UCB0SIMO/UCB0SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='P3.2/UCB0SOMI/UCB0SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='P3.3/UCB0CLK/UCA0STE',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='P4.0/CA0/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='P4.1/CA1/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='P4.2/CA2/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='P4.3/A12/CA3/TB0.0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='P4.4/A13/CA4/TB0.1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='XOUT/P2.7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='P4.5/A14/CA5/TB0.2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='P4.6/A15/CA6/TB0OUTH',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='P4.7/CA7/TB0CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='P3.4/UCA0TXD/UCA0SIMO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='P3.5/UCA0RXD/UCA0SOMI',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='P3.6/A6/TA1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='P3.7/A6/TA1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='TA0.1/VREF-/VeREF-/A3/P2.3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='TA0.2/VREF+/VeREF+/A4/P2.4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='TA0CLK/ADC10CLK/P1.0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='XIN/P2.6',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='TA0.0/P1.1',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='TA0.1/P1.2',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='TA0.2/P1.3',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='TCK/SMCLK/P1.4',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='TMS/TA0.0/P1.5',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='TDI/TA0.1/P1.6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='TDO/TDI/TA0.2/P1.7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='SBWTCK/TEST',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='DVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='TA1.0/ROSC/P2.5',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='~{RST}/NMI/SBWTDIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='TA1CLK/ACLK/A0/P2.0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='TA0INCLK/SMCLK/A1/P2.1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='TA0.0/A2/P2.2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='P3.0/A5/UCB0STE/UCA0CLK',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])