from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Connector_Generic_MountingPin = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'Conn_01x01_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x01_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x01_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x02_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x02_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x02_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x03_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x03_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x03_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x04_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x04_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x04_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x05_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x05_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x05_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x06_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x06_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x06_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x07_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x07_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x07_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x08_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x08_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x08_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x09_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x09_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x09_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x10_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x10_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x10_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x11_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x11_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x11_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x12_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x12_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x12_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x13_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x13_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x13_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x14_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x14_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x14_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x15_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x15_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x15_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x16_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x16_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x16_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x17_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x17_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x17_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x18_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x18_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x18_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x19_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x19_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x19_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x20_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x20_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x20_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x21_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x21_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x21_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x22_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x22_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x22_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x23_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x23_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x23_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x24_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x24_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x24_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x25_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x25_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x25_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x26_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x26_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x26_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x27_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x27_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x27_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x28_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x28_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x28_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x29_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x29_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x29_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x30_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x30_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x30_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x31_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x31_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x31_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x32_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x32_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x32_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x33_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x33_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x33_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x34_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x34_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x34_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x35_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x35_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x35_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x36_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x36_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x36_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x37_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x37_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x37_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x38_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x38_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x38_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x39_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x39_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x39_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x40_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x40_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x40_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x41_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x41_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x41_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x42_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x42_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x42_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x43_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x43_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x43_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x44_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x44_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x44_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x45_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x45_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x45_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x46_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x46_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x46_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x47_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x47_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x47_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x48_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x48_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x48_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x49_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x49_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x49_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x50_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x50_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x50_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x51_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x51_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x51_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x52_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x52_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x52_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x53_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x53_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x53_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x54_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x54_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x54_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x55_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x55_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x55_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x56_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x56_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x56_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x57_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x57_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x57_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x58_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x58_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x58_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x59_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x59_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x59_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_01x60_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_01x60_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_01x60_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x01_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x01_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x01_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x01_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x01_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x01_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x01_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x01_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x01_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x02_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x02_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x02_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x02_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x02_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x02_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x02_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x02_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x02_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x02_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x02_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x02_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x02_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x02_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x02_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x03_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x03_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x03_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x03_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x03_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x03_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x03_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x03_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x03_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x03_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x03_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x03_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x03_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x03_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x03_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x04_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x04_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x04_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x04_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x04_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x04_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x04_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x04_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x04_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x04_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x04_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x04_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x04_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x04_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x04_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x05_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x05_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x05_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x05_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x05_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x05_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x05_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x05_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x05_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x05_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x05_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x05_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x05_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x05_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x05_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x06_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x06_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x06_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x06_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x06_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x06_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x06_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x06_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x06_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x06_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x06_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x06_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x06_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x06_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x06_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x07_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x07_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x07_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x07_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x07_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x07_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x07_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x07_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x07_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x07_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x07_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x07_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x07_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x07_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x07_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x08_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x08_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x08_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x08_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x08_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x08_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x08_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x08_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x08_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x08_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x08_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x08_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x08_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x08_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x08_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x09_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x09_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x09_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x09_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x09_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x09_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x09_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x09_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x09_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x09_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x09_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x09_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x09_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x09_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x09_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x10_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x10_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x10_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x10_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x10_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x10_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x10_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x10_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x10_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x10_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x10_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x10_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x10_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x10_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x10_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x11_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x11_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x11_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x11_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x11_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x11_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x11_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x11_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x11_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x11_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x11_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x11_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x11_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x11_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x11_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x12_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x12_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x12_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x12_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x12_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x12_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x12_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x12_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x12_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x12_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x12_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x12_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x12_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x12_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x12_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x13_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x13_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x13_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x13_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x13_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x13_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x13_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x13_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x13_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x13_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x13_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x13_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x13_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x13_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x13_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x14_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x14_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x14_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x14_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x14_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x14_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x14_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x14_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x14_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x14_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x14_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x14_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x14_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x14_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x14_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x15_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x15_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x15_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x15_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x15_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x15_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x15_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x15_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x15_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x15_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x15_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x15_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x15_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x15_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x15_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x16_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x16_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x16_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x16_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x16_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x16_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x16_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x16_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x16_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x16_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x16_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x16_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x16_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x16_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x16_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x17_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x17_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x17_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x17_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x17_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x17_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x17_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x17_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x17_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x17_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x17_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x17_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x17_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x17_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x17_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x18_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x18_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x18_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x18_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x18_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x18_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x18_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x18_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x18_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x18_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x18_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x18_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x18_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x18_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x18_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x19_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x19_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x19_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x19_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x19_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x19_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x19_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x19_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x19_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x19_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x19_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x19_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x19_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x19_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x19_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x20_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x20_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x20_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x20_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x20_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x20_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x20_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x20_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x20_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x20_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x20_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x20_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x20_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x20_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x20_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x21_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x21_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x21_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x21_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x21_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x21_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x21_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x21_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x21_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x21_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x21_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x21_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x21_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x21_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x21_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x22_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x22_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x22_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x22_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x22_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x22_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x22_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x22_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x22_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x22_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x22_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x22_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x22_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x22_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x22_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x23_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x23_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x23_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x23_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x23_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x23_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x23_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x23_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x23_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x23_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x23_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x23_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x23_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x23_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x23_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x24_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x24_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x24_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x24_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x24_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x24_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x24_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x24_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x24_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x24_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x24_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x24_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x24_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x24_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x24_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x25_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x25_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x25_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x25_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x25_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x25_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x25_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x25_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x25_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x25_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x25_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x25_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x25_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x25_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x25_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x26_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x26_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x26_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x26_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x26_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x26_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x26_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x26_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x26_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x26_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x26_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x26_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x26_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x26_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x26_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x27_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x27_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x27_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x27_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x27_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x27_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x27_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x27_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x27_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x27_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x27_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x27_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x27_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x27_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x27_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x28_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x28_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x28_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x28_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x28_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x28_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x28_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x28_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x28_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x28_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x28_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x28_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x28_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x28_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x28_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x29_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x29_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x29_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x29_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x29_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x29_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x29_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x29_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x29_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x29_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x29_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x29_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x29_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x29_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x29_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x30_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x30_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x30_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x30_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x30_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x30_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x30_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x30_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x30_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x30_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x30_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x30_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x30_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x30_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x30_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x31_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x31_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x31_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x31_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x31_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x31_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x31_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x31_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x31_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x31_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x31_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x31_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x31_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x31_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x31_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x32_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x32_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x32_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x32_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x32_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x32_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x32_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x32_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x32_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x32_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x32_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x32_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x32_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x32_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x32_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x33_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x33_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x33_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x33_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x33_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x33_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x33_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x33_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x33_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x33_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x33_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x33_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x33_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x33_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x33_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x34_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x34_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x34_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x34_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x34_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x34_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x34_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x34_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x34_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x34_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x34_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x34_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x34_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x34_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x34_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x35_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x35_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x35_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x35_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x35_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x35_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x35_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x35_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x35_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x35_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x35_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x35_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x35_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x35_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x35_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x36_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x36_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x36_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x36_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x36_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x36_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x36_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x36_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x36_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x36_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x36_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x36_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x36_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x36_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x36_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x37_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x37_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x37_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x37_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x37_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x37_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x37_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x37_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x37_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x37_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x37_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x37_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x37_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x37_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x37_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x38_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x38_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x38_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x38_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x38_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x38_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x38_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x38_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x38_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x38_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x38_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x38_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x38_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x38_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x38_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x39_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x39_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x39_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x39_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x39_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x39_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x39_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x39_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x39_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x39_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x39_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x39_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x39_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x39_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x39_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x40_Counter_Clockwise_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x40_Counter_Clockwise_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x40_Counter_Clockwise_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='Pin_79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='Pin_80',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x40_Odd_Even_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x40_Odd_Even_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x40_Odd_Even_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='Pin_79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='Pin_80',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x40_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x40_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x40_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x40_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x40_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x40_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x40_Top_Bottom_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x40_Top_Bottom_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x40_Top_Bottom_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='Pin_76',func=pin_types.PASSIVE,unit=1),
            Pin(num='77',name='Pin_77',func=pin_types.PASSIVE,unit=1),
            Pin(num='78',name='Pin_78',func=pin_types.PASSIVE,unit=1),
            Pin(num='79',name='Pin_79',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='80',name='Pin_80',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x41_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x41_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x41_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x41_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x41_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x41_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x42_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x42_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x42_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x42_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x42_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x42_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x43_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x43_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x43_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x43_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x43_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x43_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x44_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x44_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x44_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x44_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x44_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x44_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x45_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x45_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x45_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x45_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x45_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x45_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x46_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x46_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x46_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x46_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x46_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x46_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x47_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x47_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x47_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x47_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x47_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x47_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x48_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x48_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x48_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x48_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x48_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x48_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x49_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x49_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x49_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x49_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x49_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x49_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x50_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x50_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x50_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x50_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x50_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x50_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x51_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x51_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x51_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x51_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x51_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x51_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x52_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x52_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x52_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x52_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x52_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x52_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x53_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x53_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x53_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x53_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x53_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x53_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x54_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x54_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x54_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x54_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x54_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x54_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x55_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x55_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x55_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x55_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x55_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x55_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x56_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x56_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x56_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a56',name='Pin_a56',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b56',name='Pin_b56',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x56_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x56_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x56_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='56a',name='Pin_56a',func=pin_types.PASSIVE,unit=1),
            Pin(num='56b',name='Pin_56b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x57_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x57_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x57_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a56',name='Pin_a56',func=pin_types.PASSIVE,unit=1),
            Pin(num='a57',name='Pin_a57',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b56',name='Pin_b56',func=pin_types.PASSIVE,unit=1),
            Pin(num='b57',name='Pin_b57',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x57_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x57_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x57_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='56a',name='Pin_56a',func=pin_types.PASSIVE,unit=1),
            Pin(num='56b',name='Pin_56b',func=pin_types.PASSIVE,unit=1),
            Pin(num='57a',name='Pin_57a',func=pin_types.PASSIVE,unit=1),
            Pin(num='57b',name='Pin_57b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x58_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x58_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x58_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a56',name='Pin_a56',func=pin_types.PASSIVE,unit=1),
            Pin(num='a57',name='Pin_a57',func=pin_types.PASSIVE,unit=1),
            Pin(num='a58',name='Pin_a58',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b56',name='Pin_b56',func=pin_types.PASSIVE,unit=1),
            Pin(num='b57',name='Pin_b57',func=pin_types.PASSIVE,unit=1),
            Pin(num='b58',name='Pin_b58',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x58_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x58_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x58_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='56a',name='Pin_56a',func=pin_types.PASSIVE,unit=1),
            Pin(num='56b',name='Pin_56b',func=pin_types.PASSIVE,unit=1),
            Pin(num='57a',name='Pin_57a',func=pin_types.PASSIVE,unit=1),
            Pin(num='57b',name='Pin_57b',func=pin_types.PASSIVE,unit=1),
            Pin(num='58a',name='Pin_58a',func=pin_types.PASSIVE,unit=1),
            Pin(num='58b',name='Pin_58b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x59_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x59_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x59_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a56',name='Pin_a56',func=pin_types.PASSIVE,unit=1),
            Pin(num='a57',name='Pin_a57',func=pin_types.PASSIVE,unit=1),
            Pin(num='a58',name='Pin_a58',func=pin_types.PASSIVE,unit=1),
            Pin(num='a59',name='Pin_a59',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b56',name='Pin_b56',func=pin_types.PASSIVE,unit=1),
            Pin(num='b57',name='Pin_b57',func=pin_types.PASSIVE,unit=1),
            Pin(num='b58',name='Pin_b58',func=pin_types.PASSIVE,unit=1),
            Pin(num='b59',name='Pin_b59',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x59_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x59_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x59_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='56a',name='Pin_56a',func=pin_types.PASSIVE,unit=1),
            Pin(num='56b',name='Pin_56b',func=pin_types.PASSIVE,unit=1),
            Pin(num='57a',name='Pin_57a',func=pin_types.PASSIVE,unit=1),
            Pin(num='57b',name='Pin_57b',func=pin_types.PASSIVE,unit=1),
            Pin(num='58a',name='Pin_58a',func=pin_types.PASSIVE,unit=1),
            Pin(num='58b',name='Pin_58b',func=pin_types.PASSIVE,unit=1),
            Pin(num='59a',name='Pin_59a',func=pin_types.PASSIVE,unit=1),
            Pin(num='59b',name='Pin_59b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x60_Row_Letter_First_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x60_Row_Letter_First_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x60_Row_Letter_First_MountingPin\n\nconnector', 'pins':[
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1),
            Pin(num='a1',name='Pin_a1',func=pin_types.PASSIVE,unit=1),
            Pin(num='a10',name='Pin_a10',func=pin_types.PASSIVE,unit=1),
            Pin(num='a11',name='Pin_a11',func=pin_types.PASSIVE,unit=1),
            Pin(num='a12',name='Pin_a12',func=pin_types.PASSIVE,unit=1),
            Pin(num='a13',name='Pin_a13',func=pin_types.PASSIVE,unit=1),
            Pin(num='a14',name='Pin_a14',func=pin_types.PASSIVE,unit=1),
            Pin(num='a15',name='Pin_a15',func=pin_types.PASSIVE,unit=1),
            Pin(num='a16',name='Pin_a16',func=pin_types.PASSIVE,unit=1),
            Pin(num='a17',name='Pin_a17',func=pin_types.PASSIVE,unit=1),
            Pin(num='a18',name='Pin_a18',func=pin_types.PASSIVE,unit=1),
            Pin(num='a19',name='Pin_a19',func=pin_types.PASSIVE,unit=1),
            Pin(num='a2',name='Pin_a2',func=pin_types.PASSIVE,unit=1),
            Pin(num='a20',name='Pin_a20',func=pin_types.PASSIVE,unit=1),
            Pin(num='a21',name='Pin_a21',func=pin_types.PASSIVE,unit=1),
            Pin(num='a22',name='Pin_a22',func=pin_types.PASSIVE,unit=1),
            Pin(num='a23',name='Pin_a23',func=pin_types.PASSIVE,unit=1),
            Pin(num='a24',name='Pin_a24',func=pin_types.PASSIVE,unit=1),
            Pin(num='a25',name='Pin_a25',func=pin_types.PASSIVE,unit=1),
            Pin(num='a26',name='Pin_a26',func=pin_types.PASSIVE,unit=1),
            Pin(num='a27',name='Pin_a27',func=pin_types.PASSIVE,unit=1),
            Pin(num='a28',name='Pin_a28',func=pin_types.PASSIVE,unit=1),
            Pin(num='a29',name='Pin_a29',func=pin_types.PASSIVE,unit=1),
            Pin(num='a3',name='Pin_a3',func=pin_types.PASSIVE,unit=1),
            Pin(num='a30',name='Pin_a30',func=pin_types.PASSIVE,unit=1),
            Pin(num='a31',name='Pin_a31',func=pin_types.PASSIVE,unit=1),
            Pin(num='a32',name='Pin_a32',func=pin_types.PASSIVE,unit=1),
            Pin(num='a33',name='Pin_a33',func=pin_types.PASSIVE,unit=1),
            Pin(num='a34',name='Pin_a34',func=pin_types.PASSIVE,unit=1),
            Pin(num='a35',name='Pin_a35',func=pin_types.PASSIVE,unit=1),
            Pin(num='a36',name='Pin_a36',func=pin_types.PASSIVE,unit=1),
            Pin(num='a37',name='Pin_a37',func=pin_types.PASSIVE,unit=1),
            Pin(num='a38',name='Pin_a38',func=pin_types.PASSIVE,unit=1),
            Pin(num='a39',name='Pin_a39',func=pin_types.PASSIVE,unit=1),
            Pin(num='a4',name='Pin_a4',func=pin_types.PASSIVE,unit=1),
            Pin(num='a40',name='Pin_a40',func=pin_types.PASSIVE,unit=1),
            Pin(num='a41',name='Pin_a41',func=pin_types.PASSIVE,unit=1),
            Pin(num='a42',name='Pin_a42',func=pin_types.PASSIVE,unit=1),
            Pin(num='a43',name='Pin_a43',func=pin_types.PASSIVE,unit=1),
            Pin(num='a44',name='Pin_a44',func=pin_types.PASSIVE,unit=1),
            Pin(num='a45',name='Pin_a45',func=pin_types.PASSIVE,unit=1),
            Pin(num='a46',name='Pin_a46',func=pin_types.PASSIVE,unit=1),
            Pin(num='a47',name='Pin_a47',func=pin_types.PASSIVE,unit=1),
            Pin(num='a48',name='Pin_a48',func=pin_types.PASSIVE,unit=1),
            Pin(num='a49',name='Pin_a49',func=pin_types.PASSIVE,unit=1),
            Pin(num='a5',name='Pin_a5',func=pin_types.PASSIVE,unit=1),
            Pin(num='a50',name='Pin_a50',func=pin_types.PASSIVE,unit=1),
            Pin(num='a51',name='Pin_a51',func=pin_types.PASSIVE,unit=1),
            Pin(num='a52',name='Pin_a52',func=pin_types.PASSIVE,unit=1),
            Pin(num='a53',name='Pin_a53',func=pin_types.PASSIVE,unit=1),
            Pin(num='a54',name='Pin_a54',func=pin_types.PASSIVE,unit=1),
            Pin(num='a55',name='Pin_a55',func=pin_types.PASSIVE,unit=1),
            Pin(num='a56',name='Pin_a56',func=pin_types.PASSIVE,unit=1),
            Pin(num='a57',name='Pin_a57',func=pin_types.PASSIVE,unit=1),
            Pin(num='a58',name='Pin_a58',func=pin_types.PASSIVE,unit=1),
            Pin(num='a59',name='Pin_a59',func=pin_types.PASSIVE,unit=1),
            Pin(num='a6',name='Pin_a6',func=pin_types.PASSIVE,unit=1),
            Pin(num='a60',name='Pin_a60',func=pin_types.PASSIVE,unit=1),
            Pin(num='a7',name='Pin_a7',func=pin_types.PASSIVE,unit=1),
            Pin(num='a8',name='Pin_a8',func=pin_types.PASSIVE,unit=1),
            Pin(num='a9',name='Pin_a9',func=pin_types.PASSIVE,unit=1),
            Pin(num='b1',name='Pin_b1',func=pin_types.PASSIVE,unit=1),
            Pin(num='b10',name='Pin_b10',func=pin_types.PASSIVE,unit=1),
            Pin(num='b11',name='Pin_b11',func=pin_types.PASSIVE,unit=1),
            Pin(num='b12',name='Pin_b12',func=pin_types.PASSIVE,unit=1),
            Pin(num='b13',name='Pin_b13',func=pin_types.PASSIVE,unit=1),
            Pin(num='b14',name='Pin_b14',func=pin_types.PASSIVE,unit=1),
            Pin(num='b15',name='Pin_b15',func=pin_types.PASSIVE,unit=1),
            Pin(num='b16',name='Pin_b16',func=pin_types.PASSIVE,unit=1),
            Pin(num='b17',name='Pin_b17',func=pin_types.PASSIVE,unit=1),
            Pin(num='b18',name='Pin_b18',func=pin_types.PASSIVE,unit=1),
            Pin(num='b19',name='Pin_b19',func=pin_types.PASSIVE,unit=1),
            Pin(num='b2',name='Pin_b2',func=pin_types.PASSIVE,unit=1),
            Pin(num='b20',name='Pin_b20',func=pin_types.PASSIVE,unit=1),
            Pin(num='b21',name='Pin_b21',func=pin_types.PASSIVE,unit=1),
            Pin(num='b22',name='Pin_b22',func=pin_types.PASSIVE,unit=1),
            Pin(num='b23',name='Pin_b23',func=pin_types.PASSIVE,unit=1),
            Pin(num='b24',name='Pin_b24',func=pin_types.PASSIVE,unit=1),
            Pin(num='b25',name='Pin_b25',func=pin_types.PASSIVE,unit=1),
            Pin(num='b26',name='Pin_b26',func=pin_types.PASSIVE,unit=1),
            Pin(num='b27',name='Pin_b27',func=pin_types.PASSIVE,unit=1),
            Pin(num='b28',name='Pin_b28',func=pin_types.PASSIVE,unit=1),
            Pin(num='b29',name='Pin_b29',func=pin_types.PASSIVE,unit=1),
            Pin(num='b3',name='Pin_b3',func=pin_types.PASSIVE,unit=1),
            Pin(num='b30',name='Pin_b30',func=pin_types.PASSIVE,unit=1),
            Pin(num='b31',name='Pin_b31',func=pin_types.PASSIVE,unit=1),
            Pin(num='b32',name='Pin_b32',func=pin_types.PASSIVE,unit=1),
            Pin(num='b33',name='Pin_b33',func=pin_types.PASSIVE,unit=1),
            Pin(num='b34',name='Pin_b34',func=pin_types.PASSIVE,unit=1),
            Pin(num='b35',name='Pin_b35',func=pin_types.PASSIVE,unit=1),
            Pin(num='b36',name='Pin_b36',func=pin_types.PASSIVE,unit=1),
            Pin(num='b37',name='Pin_b37',func=pin_types.PASSIVE,unit=1),
            Pin(num='b38',name='Pin_b38',func=pin_types.PASSIVE,unit=1),
            Pin(num='b39',name='Pin_b39',func=pin_types.PASSIVE,unit=1),
            Pin(num='b4',name='Pin_b4',func=pin_types.PASSIVE,unit=1),
            Pin(num='b40',name='Pin_b40',func=pin_types.PASSIVE,unit=1),
            Pin(num='b41',name='Pin_b41',func=pin_types.PASSIVE,unit=1),
            Pin(num='b42',name='Pin_b42',func=pin_types.PASSIVE,unit=1),
            Pin(num='b43',name='Pin_b43',func=pin_types.PASSIVE,unit=1),
            Pin(num='b44',name='Pin_b44',func=pin_types.PASSIVE,unit=1),
            Pin(num='b45',name='Pin_b45',func=pin_types.PASSIVE,unit=1),
            Pin(num='b46',name='Pin_b46',func=pin_types.PASSIVE,unit=1),
            Pin(num='b47',name='Pin_b47',func=pin_types.PASSIVE,unit=1),
            Pin(num='b48',name='Pin_b48',func=pin_types.PASSIVE,unit=1),
            Pin(num='b49',name='Pin_b49',func=pin_types.PASSIVE,unit=1),
            Pin(num='b5',name='Pin_b5',func=pin_types.PASSIVE,unit=1),
            Pin(num='b50',name='Pin_b50',func=pin_types.PASSIVE,unit=1),
            Pin(num='b51',name='Pin_b51',func=pin_types.PASSIVE,unit=1),
            Pin(num='b52',name='Pin_b52',func=pin_types.PASSIVE,unit=1),
            Pin(num='b53',name='Pin_b53',func=pin_types.PASSIVE,unit=1),
            Pin(num='b54',name='Pin_b54',func=pin_types.PASSIVE,unit=1),
            Pin(num='b55',name='Pin_b55',func=pin_types.PASSIVE,unit=1),
            Pin(num='b56',name='Pin_b56',func=pin_types.PASSIVE,unit=1),
            Pin(num='b57',name='Pin_b57',func=pin_types.PASSIVE,unit=1),
            Pin(num='b58',name='Pin_b58',func=pin_types.PASSIVE,unit=1),
            Pin(num='b59',name='Pin_b59',func=pin_types.PASSIVE,unit=1),
            Pin(num='b6',name='Pin_b6',func=pin_types.PASSIVE,unit=1),
            Pin(num='b60',name='Pin_b60',func=pin_types.PASSIVE,unit=1),
            Pin(num='b7',name='Pin_b7',func=pin_types.PASSIVE,unit=1),
            Pin(num='b8',name='Pin_b8',func=pin_types.PASSIVE,unit=1),
            Pin(num='b9',name='Pin_b9',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_02x60_Row_Letter_Last_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_02x60_Row_Letter_Last_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_02x60_Row_Letter_Last_MountingPin\n\nconnector', 'pins':[
            Pin(num='10a',name='Pin_10a',func=pin_types.PASSIVE,unit=1),
            Pin(num='10b',name='Pin_10b',func=pin_types.PASSIVE,unit=1),
            Pin(num='11a',name='Pin_11a',func=pin_types.PASSIVE,unit=1),
            Pin(num='11b',name='Pin_11b',func=pin_types.PASSIVE,unit=1),
            Pin(num='12a',name='Pin_12a',func=pin_types.PASSIVE,unit=1),
            Pin(num='12b',name='Pin_12b',func=pin_types.PASSIVE,unit=1),
            Pin(num='13a',name='Pin_13a',func=pin_types.PASSIVE,unit=1),
            Pin(num='13b',name='Pin_13b',func=pin_types.PASSIVE,unit=1),
            Pin(num='14a',name='Pin_14a',func=pin_types.PASSIVE,unit=1),
            Pin(num='14b',name='Pin_14b',func=pin_types.PASSIVE,unit=1),
            Pin(num='15a',name='Pin_15a',func=pin_types.PASSIVE,unit=1),
            Pin(num='15b',name='Pin_15b',func=pin_types.PASSIVE,unit=1),
            Pin(num='16a',name='Pin_16a',func=pin_types.PASSIVE,unit=1),
            Pin(num='16b',name='Pin_16b',func=pin_types.PASSIVE,unit=1),
            Pin(num='17a',name='Pin_17a',func=pin_types.PASSIVE,unit=1),
            Pin(num='17b',name='Pin_17b',func=pin_types.PASSIVE,unit=1),
            Pin(num='18a',name='Pin_18a',func=pin_types.PASSIVE,unit=1),
            Pin(num='18b',name='Pin_18b',func=pin_types.PASSIVE,unit=1),
            Pin(num='19a',name='Pin_19a',func=pin_types.PASSIVE,unit=1),
            Pin(num='19b',name='Pin_19b',func=pin_types.PASSIVE,unit=1),
            Pin(num='1a',name='Pin_1a',func=pin_types.PASSIVE,unit=1),
            Pin(num='1b',name='Pin_1b',func=pin_types.PASSIVE,unit=1),
            Pin(num='20a',name='Pin_20a',func=pin_types.PASSIVE,unit=1),
            Pin(num='20b',name='Pin_20b',func=pin_types.PASSIVE,unit=1),
            Pin(num='21a',name='Pin_21a',func=pin_types.PASSIVE,unit=1),
            Pin(num='21b',name='Pin_21b',func=pin_types.PASSIVE,unit=1),
            Pin(num='22a',name='Pin_22a',func=pin_types.PASSIVE,unit=1),
            Pin(num='22b',name='Pin_22b',func=pin_types.PASSIVE,unit=1),
            Pin(num='23a',name='Pin_23a',func=pin_types.PASSIVE,unit=1),
            Pin(num='23b',name='Pin_23b',func=pin_types.PASSIVE,unit=1),
            Pin(num='24a',name='Pin_24a',func=pin_types.PASSIVE,unit=1),
            Pin(num='24b',name='Pin_24b',func=pin_types.PASSIVE,unit=1),
            Pin(num='25a',name='Pin_25a',func=pin_types.PASSIVE,unit=1),
            Pin(num='25b',name='Pin_25b',func=pin_types.PASSIVE,unit=1),
            Pin(num='26a',name='Pin_26a',func=pin_types.PASSIVE,unit=1),
            Pin(num='26b',name='Pin_26b',func=pin_types.PASSIVE,unit=1),
            Pin(num='27a',name='Pin_27a',func=pin_types.PASSIVE,unit=1),
            Pin(num='27b',name='Pin_27b',func=pin_types.PASSIVE,unit=1),
            Pin(num='28a',name='Pin_28a',func=pin_types.PASSIVE,unit=1),
            Pin(num='28b',name='Pin_28b',func=pin_types.PASSIVE,unit=1),
            Pin(num='29a',name='Pin_29a',func=pin_types.PASSIVE,unit=1),
            Pin(num='29b',name='Pin_29b',func=pin_types.PASSIVE,unit=1),
            Pin(num='2a',name='Pin_2a',func=pin_types.PASSIVE,unit=1),
            Pin(num='2b',name='Pin_2b',func=pin_types.PASSIVE,unit=1),
            Pin(num='30a',name='Pin_30a',func=pin_types.PASSIVE,unit=1),
            Pin(num='30b',name='Pin_30b',func=pin_types.PASSIVE,unit=1),
            Pin(num='31a',name='Pin_31a',func=pin_types.PASSIVE,unit=1),
            Pin(num='31b',name='Pin_31b',func=pin_types.PASSIVE,unit=1),
            Pin(num='32a',name='Pin_32a',func=pin_types.PASSIVE,unit=1),
            Pin(num='32b',name='Pin_32b',func=pin_types.PASSIVE,unit=1),
            Pin(num='33a',name='Pin_33a',func=pin_types.PASSIVE,unit=1),
            Pin(num='33b',name='Pin_33b',func=pin_types.PASSIVE,unit=1),
            Pin(num='34a',name='Pin_34a',func=pin_types.PASSIVE,unit=1),
            Pin(num='34b',name='Pin_34b',func=pin_types.PASSIVE,unit=1),
            Pin(num='35a',name='Pin_35a',func=pin_types.PASSIVE,unit=1),
            Pin(num='35b',name='Pin_35b',func=pin_types.PASSIVE,unit=1),
            Pin(num='36a',name='Pin_36a',func=pin_types.PASSIVE,unit=1),
            Pin(num='36b',name='Pin_36b',func=pin_types.PASSIVE,unit=1),
            Pin(num='37a',name='Pin_37a',func=pin_types.PASSIVE,unit=1),
            Pin(num='37b',name='Pin_37b',func=pin_types.PASSIVE,unit=1),
            Pin(num='38a',name='Pin_38a',func=pin_types.PASSIVE,unit=1),
            Pin(num='38b',name='Pin_38b',func=pin_types.PASSIVE,unit=1),
            Pin(num='39a',name='Pin_39a',func=pin_types.PASSIVE,unit=1),
            Pin(num='39b',name='Pin_39b',func=pin_types.PASSIVE,unit=1),
            Pin(num='3a',name='Pin_3a',func=pin_types.PASSIVE,unit=1),
            Pin(num='3b',name='Pin_3b',func=pin_types.PASSIVE,unit=1),
            Pin(num='40a',name='Pin_40a',func=pin_types.PASSIVE,unit=1),
            Pin(num='40b',name='Pin_40b',func=pin_types.PASSIVE,unit=1),
            Pin(num='41a',name='Pin_41a',func=pin_types.PASSIVE,unit=1),
            Pin(num='41b',name='Pin_41b',func=pin_types.PASSIVE,unit=1),
            Pin(num='42a',name='Pin_42a',func=pin_types.PASSIVE,unit=1),
            Pin(num='42b',name='Pin_42b',func=pin_types.PASSIVE,unit=1),
            Pin(num='43a',name='Pin_43a',func=pin_types.PASSIVE,unit=1),
            Pin(num='43b',name='Pin_43b',func=pin_types.PASSIVE,unit=1),
            Pin(num='44a',name='Pin_44a',func=pin_types.PASSIVE,unit=1),
            Pin(num='44b',name='Pin_44b',func=pin_types.PASSIVE,unit=1),
            Pin(num='45a',name='Pin_45a',func=pin_types.PASSIVE,unit=1),
            Pin(num='45b',name='Pin_45b',func=pin_types.PASSIVE,unit=1),
            Pin(num='46a',name='Pin_46a',func=pin_types.PASSIVE,unit=1),
            Pin(num='46b',name='Pin_46b',func=pin_types.PASSIVE,unit=1),
            Pin(num='47a',name='Pin_47a',func=pin_types.PASSIVE,unit=1),
            Pin(num='47b',name='Pin_47b',func=pin_types.PASSIVE,unit=1),
            Pin(num='48a',name='Pin_48a',func=pin_types.PASSIVE,unit=1),
            Pin(num='48b',name='Pin_48b',func=pin_types.PASSIVE,unit=1),
            Pin(num='49a',name='Pin_49a',func=pin_types.PASSIVE,unit=1),
            Pin(num='49b',name='Pin_49b',func=pin_types.PASSIVE,unit=1),
            Pin(num='4a',name='Pin_4a',func=pin_types.PASSIVE,unit=1),
            Pin(num='4b',name='Pin_4b',func=pin_types.PASSIVE,unit=1),
            Pin(num='50a',name='Pin_50a',func=pin_types.PASSIVE,unit=1),
            Pin(num='50b',name='Pin_50b',func=pin_types.PASSIVE,unit=1),
            Pin(num='51a',name='Pin_51a',func=pin_types.PASSIVE,unit=1),
            Pin(num='51b',name='Pin_51b',func=pin_types.PASSIVE,unit=1),
            Pin(num='52a',name='Pin_52a',func=pin_types.PASSIVE,unit=1),
            Pin(num='52b',name='Pin_52b',func=pin_types.PASSIVE,unit=1),
            Pin(num='53a',name='Pin_53a',func=pin_types.PASSIVE,unit=1),
            Pin(num='53b',name='Pin_53b',func=pin_types.PASSIVE,unit=1),
            Pin(num='54a',name='Pin_54a',func=pin_types.PASSIVE,unit=1),
            Pin(num='54b',name='Pin_54b',func=pin_types.PASSIVE,unit=1),
            Pin(num='55a',name='Pin_55a',func=pin_types.PASSIVE,unit=1),
            Pin(num='55b',name='Pin_55b',func=pin_types.PASSIVE,unit=1),
            Pin(num='56a',name='Pin_56a',func=pin_types.PASSIVE,unit=1),
            Pin(num='56b',name='Pin_56b',func=pin_types.PASSIVE,unit=1),
            Pin(num='57a',name='Pin_57a',func=pin_types.PASSIVE,unit=1),
            Pin(num='57b',name='Pin_57b',func=pin_types.PASSIVE,unit=1),
            Pin(num='58a',name='Pin_58a',func=pin_types.PASSIVE,unit=1),
            Pin(num='58b',name='Pin_58b',func=pin_types.PASSIVE,unit=1),
            Pin(num='59a',name='Pin_59a',func=pin_types.PASSIVE,unit=1),
            Pin(num='59b',name='Pin_59b',func=pin_types.PASSIVE,unit=1),
            Pin(num='5a',name='Pin_5a',func=pin_types.PASSIVE,unit=1),
            Pin(num='5b',name='Pin_5b',func=pin_types.PASSIVE,unit=1),
            Pin(num='60a',name='Pin_60a',func=pin_types.PASSIVE,unit=1),
            Pin(num='60b',name='Pin_60b',func=pin_types.PASSIVE,unit=1),
            Pin(num='6a',name='Pin_6a',func=pin_types.PASSIVE,unit=1),
            Pin(num='6b',name='Pin_6b',func=pin_types.PASSIVE,unit=1),
            Pin(num='7a',name='Pin_7a',func=pin_types.PASSIVE,unit=1),
            Pin(num='7b',name='Pin_7b',func=pin_types.PASSIVE,unit=1),
            Pin(num='8a',name='Pin_8a',func=pin_types.PASSIVE,unit=1),
            Pin(num='8b',name='Pin_8b',func=pin_types.PASSIVE,unit=1),
            Pin(num='9a',name='Pin_9a',func=pin_types.PASSIVE,unit=1),
            Pin(num='9b',name='Pin_9b',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-05Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-05Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-05Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-07Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-07Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-07Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-09Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-09Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-09Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-11Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-11Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-11Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-13Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-13Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-13Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-15Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-15Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-15Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-17Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-17Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-17Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-19Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-19Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-19Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-21Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-21Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-21Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-23Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-23Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-23Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-25Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-25Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-25Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-27Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-27Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-27Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-29Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-29Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-29Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-31Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-31Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-31Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-33Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-33Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-33Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-35Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-35Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-35Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-37Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-37Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-37Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-39Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-39Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-39Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-41Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-41Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-41Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-43Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-43Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-43Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-45Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-45Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-45Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-47Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-47Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-47Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-49Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-49Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-49Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-51Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-51Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-51Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-53Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-53Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-53Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-55Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-55Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-55Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-57Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-57Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-57Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-59Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-59Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-59Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-61Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-61Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-61Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-63Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-63Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-63Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-65Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-65Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-65Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-67Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-67Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-67Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-69Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-69Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-69Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-71Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-71Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-71Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-73Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-73Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-73Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Conn_2Rows-75Pins_MountingPin', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Conn_2Rows-75Pins_MountingPin'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'connector', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/Connector_Generic_MountingPin.kicad_sym\nConn_2Rows-75Pins_MountingPin\n\nconnector', 'pins':[
            Pin(num='1',name='Pin_1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Pin_10',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Pin_11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Pin_12',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Pin_13',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Pin_14',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Pin_15',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Pin_16',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='Pin_17',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='Pin_18',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='Pin_19',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='Pin_2',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='Pin_20',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='Pin_21',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='Pin_22',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='Pin_23',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='Pin_24',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='Pin_25',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='Pin_26',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='Pin_27',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='Pin_28',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='Pin_29',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Pin_3',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Pin_30',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='Pin_31',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='Pin_32',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='Pin_33',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='Pin_34',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='Pin_35',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='Pin_36',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='Pin_37',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='Pin_38',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='Pin_39',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Pin_4',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='Pin_40',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='Pin_41',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='Pin_42',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='Pin_43',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='Pin_44',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='Pin_45',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='Pin_46',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='Pin_47',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='Pin_48',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='Pin_49',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Pin_5',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='Pin_50',func=pin_types.PASSIVE,unit=1),
            Pin(num='51',name='Pin_51',func=pin_types.PASSIVE,unit=1),
            Pin(num='52',name='Pin_52',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='Pin_53',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='Pin_54',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='Pin_55',func=pin_types.PASSIVE,unit=1),
            Pin(num='56',name='Pin_56',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='Pin_57',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='Pin_58',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='Pin_59',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Pin_6',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='Pin_60',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='Pin_61',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='Pin_62',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='Pin_63',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='Pin_64',func=pin_types.PASSIVE,unit=1),
            Pin(num='65',name='Pin_65',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='Pin_66',func=pin_types.PASSIVE,unit=1),
            Pin(num='67',name='Pin_67',func=pin_types.PASSIVE,unit=1),
            Pin(num='68',name='Pin_68',func=pin_types.PASSIVE,unit=1),
            Pin(num='69',name='Pin_69',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Pin_7',func=pin_types.PASSIVE,unit=1),
            Pin(num='70',name='Pin_70',func=pin_types.PASSIVE,unit=1),
            Pin(num='71',name='Pin_71',func=pin_types.PASSIVE,unit=1),
            Pin(num='72',name='Pin_72',func=pin_types.PASSIVE,unit=1),
            Pin(num='73',name='Pin_73',func=pin_types.PASSIVE,unit=1),
            Pin(num='74',name='Pin_74',func=pin_types.PASSIVE,unit=1),
            Pin(num='75',name='Pin_75',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Pin_8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Pin_9',func=pin_types.PASSIVE,unit=1),
            Pin(num='MP',name='MountPin',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])