from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Converter_DCDC = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ATA00AA18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00AA18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00AA18S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00F18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00F18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00F18S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Ag9905LP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Ag9905LP'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Silvertel_Ag99xxLP_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Silvertel_Ag99xxLP_THT', 'keywords':'Silvertel isolated isolation dc-dc converter transformer power-over-ethernet over temperature protection short-circuit protection', 'description':'', 'datasheet':'https://silvertel.com/images/datasheets/Ag9900M-datasheet-ultra-miniature-isolated-Power-over-Ethernet-POE-module.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nAg9905LP\n\nSilvertel isolated isolation dc-dc converter transformer power-over-ethernet over temperature protection short-circuit protection', 'pins':[
            Pin(num='1',name='+VDC',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='+VDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='-VDC',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='ADJ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VIN-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BD8314NUV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BD8314NUV'}), 'ref_prefix':'U', 'fplist':['Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.2x2mm'], 'footprint':'Package_SON:VSON-10-1EP_3x3mm_P0.5mm_EP1.2x2mm', 'keywords':'DCDC converter', 'description':'', 'datasheet':'http://rohmfs.rohm.com/en/products/databook/datasheet/ic/power/switching_regulator/bd8314nuv-e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nBD8314NUV\n\nDCDC converter', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SWOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VREG',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='LX',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='LX',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='STB',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='INV',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0305D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0305D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0305D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0305S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0305S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0305S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4803D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4803D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4803D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4803S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4803S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4803S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0503D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0503D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0503D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0503DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0503DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0503DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0503S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0503S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0503S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0503SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0503SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0503SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205D12\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205S05\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2403SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2403SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2403SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2405S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2405S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2405S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0503SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0503SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0503SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0503SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0503SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0503SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024D05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024D05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024D05\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024S3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024S3V3'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024S3V3\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTE0624D03', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTE0624D03'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'keywords':'XP_POWER isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_JTE06.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTE0624D03\n\nXP_POWER isolated DC/DC Converter module', 'pins':[
            Pin(num='11',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1026', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1026'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'monolithic switched capacitor voltage doubler inverter ', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1026fb.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nLT1026\n\nmonolithic switched capacitor voltage doubler inverter ', 'pins':[
            Pin(num='1',name='C1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='C1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0303SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0303SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0303SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S0505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S0505SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S0505SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D051505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D051505SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D051505SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ3T05150505MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ3T05150505MC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ3'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/datasheet?/data/power/ncl/kdc_mgj3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ3T05150505MC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Dis}/Sync',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MYRGPxx0060x21RC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MYRGPxx0060x21RC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MYRxP'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MYRxP', 'keywords':'Fixed step-down converter', 'description':'', 'datasheet':'https://www.murata.com/products/productdata/8816428285982/MYRGP-WB-RC.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMYRGPxx0060x21RC\n\nFixed step-down converter', 'pins':[
            Pin(num='1',name='Lx',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='V_{OUT}',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CE/MODE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V_{IN}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MYRGPxx0060x21RF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MYRGPxx0060x21RF'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MYRxP'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MYRxP', 'keywords':'Adjustable step-down converter', 'description':'', 'datasheet':'https://www.murata.com/products/productdata/8816428318750/MYRGP-WB-RF.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMYRGPxx0060x21RF\n\nAdjustable step-down converter', 'pins':[
            Pin(num='1',name='Lx',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V_{SS}',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CE/MODE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{SS}',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V_{IN}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='L1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='L2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S1203SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S1203SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S1203SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NSD10-xxDyy', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSD10-xxDyy'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_MeanWell_NSD10_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_MeanWell_NSD10_THT', 'keywords':'meanwell isolated isolation dc-dc DC/DC converter regulated dual 10W', 'description':'', 'datasheet':'https://www.meanwell.com/webapp/product/search.aspx?prod=NSD10-D', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNSD10-xxDyy\n\nmeanwell isolated isolation dc-dc DC/DC converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Control',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NSD10-xxSyy', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NSD10-xxSyy'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_MeanWell_NSD10_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_MeanWell_NSD10_THT', 'keywords':'meanwell isolated isolation dc-dc DC/DC converter regulated single 10W', 'description':'', 'datasheet':'https://www.meanwell.com/webapp/product/search.aspx?prod=NSD10-S', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNSD10-xxSyy\n\nmeanwell isolated isolation dc-dc DC/DC converter regulated single 10W', 'pins':[
            Pin(num='1',name='+IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-IN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='-OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Control',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-3.3_1.5-W36-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-3.3_1.5-W36-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-3.3_1.5-W36-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-3.3_1.5-W36H-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-3.3_1.5-W36H-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-3.3_1.5-W36H-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78000W_EUS-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78000W_EUS-5'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUS_R-PDSS-T5_THT'], 'footprint':'Module:Texas_EUS_R-PDSS-T5_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78000w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78000W_EUS-5\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vo_Adj',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VO',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78020W_EUK-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78020W_EUK-7'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUK_R-PDSS-T7_THT'], 'footprint':'Module:Texas_EUK_R-PDSS-T7_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78020w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78020W_EUK-7\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VO_Adj',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VO_Sense',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VO',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78060W_EUW-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78060W_EUW-7'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUW_R-PDSS-T7_THT'], 'footprint':'Module:Texas_EUW_R-PDSS-T7_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78060w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78060W_EUW-7\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VO_Adj',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VO_Sense',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VO',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPA60-2405SFW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPA60-2405SFW'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://recom-power.com/pdf/Powerline_DC-DC/RPA60-FW.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPA60-2405SFW\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM5.0-6.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM5.0-6.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-6.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM5.0-6.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPMH3.3-1.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPMH3.3-1.5'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom DC-DC converter', 'description':'', 'datasheet':'https://recom-power.com/pdf/Innoline/RPMH-1.5.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPMH3.3-1.5\n\nRecom DC-DC converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TC7662AxPA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC7662AxPA'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'charge pump DC-to-DC converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21468B.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTC7662AxPA\n\ncharge pump DC-to-DC converter', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='CAP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OSC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TC7662Bx0A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC7662Bx0A'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'charge pump DC-to-DC converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21469a.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTC7662Bx0A\n\ncharge pump DC-to-DC converter', 'pins':[
            Pin(num='1',name='BOOST',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CAP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='LV',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OSC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TC7662BxPA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC7662BxPA'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'charge pump DC-to-DC converter', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/21469a.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTC7662BxPA\n\ncharge pump DC-to-DC converter', 'pins':[
            Pin(num='1',name='BOOST',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CAP+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CAP-',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='LV',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OSC',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-0511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-0511'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-0511\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEA1-0505HI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEA1-0505HI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxHI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxHI_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tea1hi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEA1-0505HI\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1211\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1222', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1222'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1222\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11011WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11011WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11011WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11021WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11021WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11021WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2411WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2411WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2411WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2421WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2421WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2421WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-1211\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-1222', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-1222'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-1222\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0505D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0505D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0505D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0505S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0505S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-0510', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-0510'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-0510\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-2410WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-2410WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-2410WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS43060RTE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS43060RTE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_S-PWQFN-N16_EP1.2x0.8mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_S-PWQFN-N16_EP1.2x0.8mm_ThermalVias', 'keywords':'Boost DC-DC', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tps43060.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTPS43060RTE\n\nBoost DC-DC', 'pins':[
            Pin(num='1',name='RT/CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VCC',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='BOOT',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='HDRV',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PGOOD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='EN',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ISNSâ\x80\x93',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ISNS+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='LDRV',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='PGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPS61022', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPS61022'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RWU0007A_VQFN-7_2x2mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Texas_RWU0007A_VQFN-7_2x2mm_P0.5mm', 'keywords':'step-up', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tps61022.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTPS61022\n\nstep-up', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VIN',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPSM53602RDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPSM53602RDA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia'], 'footprint':'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'keywords':'step down DCDC converter regulator', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpsm53602.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTPSM53602RDA\n\nstep down DCDC converter regulator', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V5V',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PGOOD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='FB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-0511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-0511'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-0511\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00A18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00A18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00A18S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00A36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00A36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00A36S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00AA36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00AA36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00AA36S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00B18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00B18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00B18S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00B36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00B36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00B36S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00BB18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00BB18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00BB18S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00BB36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00BB36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00BB36S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00C18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00C18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00C18S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00C36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00C36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00C36S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00CC18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00CC18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00CC18S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00CC36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00CC36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter dual', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00CC36S-L\n\nDC/DC converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00F36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00F36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00F36S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00H18S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00H18S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00H18S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ATA00H36S-L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ATA00H36S-L'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_Artesyn_ATA_SMD', 'keywords':'DC/DC converter single', 'description':'', 'datasheet':'https://www.artesyn.com/power/assets/ata_series_ds_01apr2015_79c25814fd.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nATA00H36S-L\n\nDC/DC converter single', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0503D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0503D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0503D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0503S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0503S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0503S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0505D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0505D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0505D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0505S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0505S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0509D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0509D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0509D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0509S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0509S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0509S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0512D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0512D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0512D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0512S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0512S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0515D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0515D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0515D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0515S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0515S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0524D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0524D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0524D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA0524S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA0524S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA0524S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1203D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1203D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1203D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1203S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1203S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1203S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1205D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1205D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1205D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1205S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1205S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1205S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1209D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1209D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1209D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1209S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1209S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1209S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1212D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1212D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1212D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1212S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1212S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1215D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1215D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1215D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1215S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1215S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1215S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1224D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1224D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1224D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA1224S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA1224S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA1224S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2403D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2403D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2403D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2403S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2403S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2403S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2405D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2405D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2405D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2405S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2405S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2409D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2409D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2409D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2409S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2409S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2409S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2412D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2412D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2412D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2412S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2412S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2415D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2415D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2415D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2415S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2415S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2424D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2424D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2424D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA2424S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA2424S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IAxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA2424S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4805D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4805D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4805D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4805S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4805S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4805S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4809D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4809D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4809D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4809S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4809S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4809S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4812D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4812D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4812D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4812S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4812S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4812S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4815D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4815D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4815D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4815S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4815S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4815S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4824D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4824D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4824D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IA4824S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IA4824S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IA48xxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IA.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIA4824S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0505D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0505D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0505D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0505DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0505DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0505DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0505S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0505S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0505SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0505SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0505SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0509D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0509D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0509D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0509DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0509DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0509DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0509S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0509S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0509S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0509SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0509SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0509SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0512D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0512D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0512D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0512DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0512DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0512DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0512S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0512S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0512SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0512SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0512SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0515D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0515D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0515D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0515DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0515DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0515DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0515S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0515S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0515SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0515SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0515SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0524D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0524D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0524D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0524DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0524DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0524DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0524S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0524S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0524S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH0524SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH0524SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH0524SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1203D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1203D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1203D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1203DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1203DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1203DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1203S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1203S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1203S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1203SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1203SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1203SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1205D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1205D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1205D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1205DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1205DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1205DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1205S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1205S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1205S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1205SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1205SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1205SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1209D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1209D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1209D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1209DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1209DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1209DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1209S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1209S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1209S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1209SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1209SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1209SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1212D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1212D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1212D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1212DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1212DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1212DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1212S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1212S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1212SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1212SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1212SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1215D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1215D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1215D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1215DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1215DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1215DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1215S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1215S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1215S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1215SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1215SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1215SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1224D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1224D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1224D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1224DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1224DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1224DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1224S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1224S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1224S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH1224SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH1224SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH1224SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2403D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2403D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2403D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2403DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2403DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2403DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2403S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2403S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2403S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2403SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2403SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2403SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2405D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2405D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2405D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2405DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2405DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2405DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2405S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2405S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2405SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2405SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2405SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2409D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2409D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2409D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2409DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2409DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2409DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2409S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2409S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2409S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2409SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2409SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2409SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2412D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2412D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2412D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2412DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2412DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2412DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2412S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2412S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2412SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2412SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2412SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2415D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2415D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2415D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2415DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2415DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2415DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2415S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2415S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2415SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2415SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2415SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2424D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2424D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2424D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2424DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2424DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2424DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2424S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2424S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2424S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH2424SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH2424SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH2424SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4803D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4803D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4803D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4803DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4803DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4803DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4803S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4803S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4803S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4803SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4803SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4803SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4805D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4805D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4805D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4805DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4805DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4805DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4805S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4805S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4805S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4805SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4805SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4805SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4809D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4809D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4809D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4809DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4809DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4809DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4809S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4809S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4809S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4809SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4809SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4809SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4812D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4812D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4812D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4812DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4812DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4812DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4812S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4812S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4812S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4812SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4812SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4812SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4815D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4815D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4815D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4815DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4815DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4815DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4815S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4815S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4815S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4815SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4815SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4815SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4824D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4824D'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxD_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4824D\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4824DH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4824DH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxDH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4824DH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='3',name='+Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT),
            Pin(num='6',name='0V',func=pin_types.PWROUT),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4824S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4824S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4824S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IH4824SH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IH4824SH'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-IHxxxxSH_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_IH.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nIH4824SH\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT),
            Pin(num='5',name='0V',func=pin_types.PWROUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205D15\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205S12\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205S15\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0205S24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0205S24'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0205S24\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224D12\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224D15\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224S05\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224S12\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224S15\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0224S24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0224S24'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0224S24\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248D12\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter dual', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248D15\n\nDC/DC Converter dual', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248S05\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248S12\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248S15\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ISU0248S24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ISU0248S24'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ISU02_SMD', 'keywords':'DC/DC Converter', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_ISU02.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nISU0248S24\n\nDC/DC Converter', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2403SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2403SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2403SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2405S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2405S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2405SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2405SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2405SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2405SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2405SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2405SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2409SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2409SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2409SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2409SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2409SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2409SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2412S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2412S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2412S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2412S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2412S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2412SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2412SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2412SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2412SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2412SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2412SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2415S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2415S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2415S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2415S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2415S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2415SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2415SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2415SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2415SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2415SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2415SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2424SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2424SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2424SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ2424SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ2424SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ2424SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4803SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4803SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4803SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4803SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4803SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4803SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4805S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4805S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4805S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4805S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4805S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4805S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4805SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4805SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4805SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4805SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4805SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4805SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4809SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4809SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4809SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4809SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4809SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4809SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4812S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4812S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4812S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4812S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4812S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4812S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4812SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4812SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4812SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4812SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4812SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4812SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4815S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4815S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4815S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4815S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4815S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4815S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4815SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4815SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4815SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4815SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4815SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4815SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4824SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4824SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4824SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITQ4824SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITQ4824SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITQxxxxS-H_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITQ.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITQ4824SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0503SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0503SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0503SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0503SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0503SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0503SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0505SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0505SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0505SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0509SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0509SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0509SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0509SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0509SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0509SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0509SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0509SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0509SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0509SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0509SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0509SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0512SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0512SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0512SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0515SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0515SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0515SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0524SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0524SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0524SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0524SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0524SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0524SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0524SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0524SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0524SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX0524SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX0524SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX0524SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1203SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1203SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1203SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1203SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1203SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1203SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1203SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1203SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1203SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1203SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1203SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1203SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1205SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1205SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1205SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1209SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1209SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1209SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1209SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1209SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1209SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1209SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1209SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1209SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1209SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1209SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1209SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1212SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1212SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1212SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1215SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1215SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1215SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1224SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1224SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1224SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1224SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1224SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1224SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1224SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1224SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1224SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX1224SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX1224SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX1224SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2403SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2403SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2403SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2403SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2403SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2403SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2403SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2403SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2403SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2403SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2403SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2403SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2405SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2405SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2405SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2409SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2409SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2409SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2409SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2409SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2409SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2409SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2409SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2409SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2409SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2409SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2409SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2412SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2412SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2412SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2415SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2415SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2415SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2424SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2424SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2424SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2424SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2424SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2424SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2424SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2424SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2424SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX2424SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX2424SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX2424SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4803SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4803SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4803SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4803SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4803SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4803SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4803SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4803SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4803SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4803SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4803SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4803SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4805SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4805SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4805SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4809SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4809SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4809SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4809SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4809SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4809SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4809SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4809SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4809SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4809SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4809SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4809SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4812SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4812SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4812SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815S'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815S\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815S-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815S-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815S-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815S-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815S-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815S-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815S-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815S-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815S-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4815SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4815SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4815SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4824SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4824SA'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4824SA\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4824SA-H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4824SA-H'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITXxxxxSA_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4824SA-H\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4824SA-HR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4824SA-HR'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4824SA-HR\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'ITX4824SA-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITX4824SA-R'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'XP_POWER DC/DC isolated Converter module', 'description':'', 'datasheet':'https://www.xppower.com/pdfs/SF_ITX.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nITX4824SA-R\n\nXP_POWER DC/DC isolated Converter module', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524D05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524D05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524D05\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524D12\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524D15\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524S05\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524S12\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524S15\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1524S3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1524S3V3'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1524S3V3\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548D05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548D05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548D05\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548D12\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548D15\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548S05\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548S12\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548S15\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD1548S3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD1548S3V3'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD15.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD1548S3V3\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024D12\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024D15\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024S05\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024S12\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2024S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2024S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2024S15\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048D05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048D05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048D05\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048D12\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down dual', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048D15\n\nisolated isolation dc-dc converter step-down dual', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Common',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048S05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048S05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048S05\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048S12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048S12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048S12\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048S15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048S15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048S15\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTD2048S3V3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTD2048S3V3'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTDxxxxxxx_THT', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://www.xppower.com/portals/0/pdfs/SF_JTD20.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTD2048S3V3\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='On/~{Off}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTE0624D05', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTE0624D05'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'keywords':'XP_POWER isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_JTE06.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTE0624D05\n\nXP_POWER isolated DC/DC Converter module', 'pins':[
            Pin(num='11',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTE0624D12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTE0624D12'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'keywords':'XP_POWER isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_JTE06.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTE0624D12\n\nXP_POWER isolated DC/DC Converter module', 'pins':[
            Pin(num='11',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTE0624D15', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTE0624D15'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'keywords':'XP_POWER isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_JTE06.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTE0624D15\n\nXP_POWER isolated DC/DC Converter module', 'pins':[
            Pin(num='11',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'JTE0624D24', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'JTE0624D24'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER_JTExxxxDxx_THT', 'keywords':'XP_POWER isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.xppower.com/Portals/0/pdfs/SF_JTE06.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nJTE0624D24\n\nXP_POWER isolated DC/DC Converter module', 'pins':[
            Pin(num='11',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='COM',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VIN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0305SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0305SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0305SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0309SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0309SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0309SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0312SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0312SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0312SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0315SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0315SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0315SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0503SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0503SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0503SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0505SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0505SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0509SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0509SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0512SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0512SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0512SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S0515SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S0515SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S0515SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1205SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1205SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1205SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1209SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1209SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1209SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1212SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1212SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1212SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1215SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1215SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1215SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1505SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1505SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1509SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1509SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1512SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1512SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1512SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S1515SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S1515SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S1515SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S2405SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S2405SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S2405SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S2409SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S2409SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S2409SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S2412SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S2412SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S2412SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE1S2415SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE1S2415SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE1SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE1S2415SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S0509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S0509SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S0509SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S0512SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S0512SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S0512SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S0515SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S0515SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S0515SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S1205SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S1205SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S1205SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S1209SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S1209SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S1209SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S1212SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S1212SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S1212SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MEE3S1215SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MEE3S1215SC'}), 'ref_prefix':'PS', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'murata DC/DC isolated converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mee3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMEE3S1215SC\n\nmurata DC/DC isolated converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D051509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D051509SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D051509SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D051515SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D051515SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D051515SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D051802SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D051802SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D051802SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D052003SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D052003SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D052003SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D052005SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D052005SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D052005SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D121505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D121505SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D121505SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D121509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D121509SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D121509SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D121802SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D121802SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D121802SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D122003SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D122003SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D122003SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D122005SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D122005SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D122005SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D151505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D151505SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D151505SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D151509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D151509SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D151509SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D151515SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D151515SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D151515SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D151802SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D151802SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D151802SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D152003SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D152003SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D152003SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D152005SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D152005SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D152005SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D241505SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D241505SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D241505SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D241509SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D241509SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D241509SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D241709SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D241709SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D241709SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D241802SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D241802SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D241802SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D242003SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D242003SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D242003SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ2D242005SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ2D242005SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ2DxxxxxxSC_THT', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/pub/data/power/ncl/kdc_mgj2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ2D242005SC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='0V',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ3T12150505MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ3T12150505MC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'Converter_DCDC:Converter_DCDC_Murata_MGJ3'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/datasheet?/data/power/ncl/kdc_mgj3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ3T12150505MC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Dis}/Sync',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MGJ3T24150505MC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MGJ3T24150505MC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'Converter_DCDC:Converter_DCDC_Murata_MGJ3'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MGJ3', 'keywords':'DC/DC converter', 'description':'', 'datasheet':'https://power.murata.com/datasheet?/data/power/ncl/kdc_mgj3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nMGJ3T24150505MC\n\nDC/DC converter', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Dis}/Sync',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='~',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S1205SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S1205SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S1205SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S1212SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S1212SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S1212SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S2403SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S2403SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S2403SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S2405SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S2405SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S2405SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCS1S2412SC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCS1S2412SC'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_NCS1SxxxxSC_THT', 'keywords':'Murata isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://power.murata.com/data/power/ncl/kdc_ncs1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nNCS1S2412SC\n\nMurata isolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Control',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-12_1.0-W36-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-12_1.0-W36-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-12_1.0-W36-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-12_1.0-W36H-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-12_1.0-W36H-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-12_1.0-W36H-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-5_1.5-W36-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-5_1.5-W36-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Vertical', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-5_1.5-W36-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OKI-78SR-5_1.5-W36H-C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OKI-78SR-5_1.5-W36H-C'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_OKI-78SR_Horizontal', 'keywords':'dc-dc murata Step-Down DC/DC-Regulator', 'description':'', 'datasheet':'https://power.murata.com/data/power/oki-78sr.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nOKI-78SR-5_1.5-W36H-C\n\ndc-dc murata Step-Down DC/DC-Regulator', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78000H_EUS-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78000H_EUS-5'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUS_R-PDSS-T5_THT', 'Module:Texas_EUS_R-PDSS-T5_THT'], 'footprint':'Module:Texas_EUS_R-PDSS-T5_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78000w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78000H_EUS-5\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vo_Adj',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VO',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78020H_EUK-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78020H_EUK-7'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUK_R-PDSS-T7_THT', 'Module:Texas_EUK_R-PDSS-T7_THT'], 'footprint':'Module:Texas_EUK_R-PDSS-T7_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78020w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78020H_EUK-7\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VO_Adj',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VO_Sense',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VO',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PTN78060H_EUW-7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PTN78060H_EUW-7'}), 'ref_prefix':'U', 'fplist':['Module:Texas_EUW_R-PDSS-T7_THT', 'Module:Texas_EUW_R-PDSS-T7_THT'], 'footprint':'Module:Texas_EUW_R-PDSS-T7_THT', 'keywords':'texas dc-dc converter step down buck', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/ptn78060w.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nPTN78060H_EUW-7\n\ntexas dc-dc converter step down buck', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{Inhibit}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VO_Adj',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VO_Sense',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VO',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPA60-2412SFW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPA60-2412SFW'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://recom-power.com/pdf/Powerline_DC-DC/RPA60-FW.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPA60-2412SFW\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPA60-2415SFW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPA60-2415SFW'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://recom-power.com/pdf/Powerline_DC-DC/RPA60-FW.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPA60-2415SFW\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPA60-2424SFW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPA60-2424SFW'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPA60-xxxxSFW', 'keywords':'isolated isolation dc-dc converter step-down', 'description':'', 'datasheet':'https://recom-power.com/pdf/Powerline_DC-DC/RPA60-FW.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPA60-2424SFW\n\nisolated isolation dc-dc converter step-down', 'pins':[
            Pin(num='1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Trim',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM3.3-1.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM3.3-1.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-1.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM3.3-1.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM3.3-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM3.3-2.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-2.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM3.3-2.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM3.3-3.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM3.3-3.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-3.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM3.3-3.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM3.3-6.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM3.3-6.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-6.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM3.3-6.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM5.0-1.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM5.0-1.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-1.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM5.0-1.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM5.0-2.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM5.0-2.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-2.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM5.0-2.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPM5.0-3.0', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPM5.0-3.0'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom dc-dc converter', 'description':'', 'datasheet':'https://www.recom-power.com/pdf/Innoline/RPM-3.0.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPM5.0-3.0\n\nRecom dc-dc converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SEQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPMH12-1.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPMH12-1.5'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom DC-DC converter', 'description':'', 'datasheet':'https://recom-power.com/pdf/Innoline/RPMH-1.5.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPMH12-1.5\n\nRecom DC-DC converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPMH15-1.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPMH15-1.5'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom DC-DC converter', 'description':'', 'datasheet':'https://recom-power.com/pdf/Innoline/RPMH-1.5.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPMH15-1.5\n\nRecom DC-DC converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPMH24-1.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPMH24-1.5'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom DC-DC converter', 'description':'', 'datasheet':'https://recom-power.com/pdf/Innoline/RPMH-1.5.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPMH24-1.5\n\nRecom DC-DC converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPMH5.0-1.5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPMH5.0-1.5'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0'], 'footprint':'Converter_DCDC:Converter_DCDC_RECOM_RPMx.x-x.0', 'keywords':'Recom DC-DC converter', 'description':'', 'datasheet':'https://recom-power.com/pdf/Innoline/RPMH-1.5.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nRPMH5.0-1.5\n\nRecom DC-DC converter', 'pins':[
            Pin(num='A1',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='+VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B5',name='+VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='CTRL',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='Sense',func=pin_types.INPUT,unit=1),
            Pin(num='D1',name='PGood',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='E3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0511E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0511E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0511E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0512E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0512E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0512E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0513E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0513E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0513E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0521E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0521E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0521E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0522E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0522E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0522E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-0523E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-0523E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-0523E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1211E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1211E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1211E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1212E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1212E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1212E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1213E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1213E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1213E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1221E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1221E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1221E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1222E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1222E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1222E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-1223E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-1223E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-1223E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2411E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2411E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2411E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2412E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2412E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2412E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2413E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2413E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2413E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2421E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2421E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2421E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2422E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2422E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2422E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA1-2423E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA1-2423E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA1-2423E\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0511'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0511\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0512'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0512\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0513'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0513\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0521', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0521'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0521\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0522', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0522'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0522\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-0523', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-0523'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-0523\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1211\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1212\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1213'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1213\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1221', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1221'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1221\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1222', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1222'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1222\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-1223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-1223'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-1223\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2411\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2412\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2413'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2413\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2421', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2421'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2421\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2422', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2422'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2422\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBA2-2423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBA2-2423'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tba2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTBA2-2423\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 2W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-0512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-0512'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-0512\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-0513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-0513'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-0513\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-1211\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-1212\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-1213'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-1213\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-2411\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-2412\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDU1-2413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDU1-2413'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TDU1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tdu1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTDU1-2413\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEA1-0505', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEA1-0505'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tea1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEA1-0505\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEA1-0505E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEA1-0505E'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tea1e.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEA1-0505E\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1210WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1210WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1210WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1211WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1211WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1211WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1212WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1212WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1212WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1213WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1213WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1213WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1215WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1215WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1215WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-1219WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-1219WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-1219WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2410WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2410WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2410WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2411WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2411WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2411WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2412WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2412WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2412WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2413WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2413WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2413WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2415WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2415WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2415WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-2419WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-2419WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-2419WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4810WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4810WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4810WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4811WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4811WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4811WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4812WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4812WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4812WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4813WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4813WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4813WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4815WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4815WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4815WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC2-4819WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC2-4819WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC2-4819WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2410UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2410UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2410UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2411UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2411UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2411UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2412UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2412UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2412UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2413UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2413UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2413UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2421UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2421UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2421UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2422UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2422UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2422UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEC3-2423UI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEC3-2423UI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tec3ui.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEC3-2423UI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1212\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1213'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1213\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1215', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1215'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1215\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-1223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-1223'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-1223\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2411\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2411WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2411WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2411WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2412\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2412WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2412WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2412WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2413'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2413\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2413WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2413WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2413WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2415', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2415'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2415\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2415WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2415WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2415WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2422', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2422'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2422\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2422WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2422WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2422WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2423'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2423\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-2423WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-2423WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-2423WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4811', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4811'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4811\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4811WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4811WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4811WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4812', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4812'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4812\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4812WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4812WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4812WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4813', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4813'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4813\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4813WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4813WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4813WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4815', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4815'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4815\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4815WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4815WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4815WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4822', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4822'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4822\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4822WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4822WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4822WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4823', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4823'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4823\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEL12-4823WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEL12-4823WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEL12-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'https://www.tracopower.com/sites/default/files/products/datasheets/tel12wi_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEL12-4823WI\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='COMMON',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT+',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11012WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11012WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11012WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11013WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11013WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11013WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11015WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11015WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11015WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11022WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11022WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11022WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-11023WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-11023WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten20wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-11023WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated dual 20W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2410WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2410WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2410WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2412WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2412WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2412WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2413WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2413WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2413WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2422WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2422WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2422WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-2423WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-2423WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-2423WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4810WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4810WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4810WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4811WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4811WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4811WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4812WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4812WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4812WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4813WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4813WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4813WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='TRIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4821WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4821WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4821WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4822WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4822WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4822WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN20-4823WIN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN20-4823WIN'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-xxxx_THT', 'keywords':'Traco isolated DC/DC Converter module', 'description':'', 'datasheet':'http://www.tracopower.com/products/ten20win.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN20-4823WIN\n\nTraco isolated DC/DC Converter module', 'pins':[
            Pin(num='1',name='VIN+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='CM',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='VOUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='ON/~{OFF}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11011WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11011WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11011WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11012WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11012WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11012WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11013WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11013WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11013WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11015WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11015WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11015WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated single 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='Trim',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11022WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11022WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated dual 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11022WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated dual 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEN40-11023WIRH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEN40-11023WIRH'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEN40-110xxWIRH_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TEN20-110xxWIRH_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC railway converter regulated dual 40W', 'description':'', 'datasheet':'https://www.tracopower.com/products/ten40wirh.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTEN40-11023WIRH\n\nTraco isolated isolation dc-dc DC/DC railway converter regulated dual 40W', 'pins':[
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-1212\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-1223', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-1223'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-1223\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-2411\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-2412\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-2422', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-2422'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-2422\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-2423', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-2423'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-2423\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-4811', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-4811'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-4811\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-4812', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-4812'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Single_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated single 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-4812\n\nTraco reinforced isolated isolation dc-dc converter regulated single 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-4822', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-4822'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-4822\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THB10-4823', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THB10-4823'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_THB10-xxxx_Dual_THT', 'keywords':'Traco reinforced isolated isolation dc-dc converter regulated dual 10W', 'description':'', 'datasheet':'https://www.tracopower.com/products/thb10.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTHB10-4823\n\nTraco reinforced isolated isolation dc-dc converter regulated dual 10W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='-Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0512D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0512D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0512D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0512S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0512S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0515D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0515D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0515D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-0515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-0515S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-0515S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1205D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1205D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1205D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1205S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1205S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1205S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1212D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1212D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1212D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1212S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1212S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1215D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1215D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1215D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1215S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1215S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1215S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1505D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1505D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1505D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1505S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1505S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1512D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1512D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1512D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1512S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1512S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1515D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1515D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1515D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-1515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-1515S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-1515S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2405D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2405D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2405D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2405S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2405S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2412D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2412D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2412D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2412S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2412S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2415D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2415D'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxD_24xxD_Dual_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxD_12xxD_Dual_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2415D\n\nTraco isolated isolation dc-dc DC/DC converter not-regulated non-regulated dual 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='Com',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMA-2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMA-2415S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA1-xxxxE_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TBA2-xxxx_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxxE_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMA-15xxS_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMA-05xxS_12xxS_Single_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tma.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMA-2415S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0303S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0303S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0303S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0305S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0305S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0305S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0503S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0503S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0503S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0505S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0505S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0505S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0509S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0509S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0509S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0512S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0512S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0512S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-0515S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-0515S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-0515S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-1205S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-1205S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-1205S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-1209S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-1209S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-1209S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-1212S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-1212S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-1212S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-1215S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-1215S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-1215S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-2405S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-2405S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-2405S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-2409S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-2409S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-2409S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-2412S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-2412S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-2412S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TME-2415S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TME-2415S'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tme.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTME-2415S\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-0511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-0511'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-0511\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-0512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-0512'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-0512\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-1210', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-1210'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-1210\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-1211\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-1212\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-2410', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-2410'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-2410\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-2411\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-2412\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-4810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-4810'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-4810\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-4811', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-4811'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-4811\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR-4812', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR-4812'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR-4812\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='-VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-2411WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-2411WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-2411WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-2412WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-2412WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-2412WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-2413WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-2413WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-2413WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-4810WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-4810WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-4810WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-4811WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-4811WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-4811WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-4812WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-4812WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-4812WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR2-4813WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR2-4813WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TMR-2xxxxWI_THT', 'keywords':'Traco isolated isolation dc-dc converter transformer', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr2wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR2-4813WI\n\nTraco isolated isolation dc-dc converter transformer', 'pins':[
            Pin(num='1',name='-VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ON/~{OFF}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='-VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2411WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2411WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2411WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2412WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2412WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2412WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2413WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2413WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2413WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2415WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2415WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2415WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2422WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2422WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2422WI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-2423WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-2423WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-2423WI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4811WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4811WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4811WI\n\nTraco isolated isolation dc-dc DC/DC converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4812WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4812WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4812WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4813WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4813WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4813WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4815WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4815WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc converter regulated single 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4815WI\n\nTraco isolated isolation dc-dc converter regulated single 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='-Vout',func=pin_types.PWROUT),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4822WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4822WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4822WI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMR4-4823WI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMR4-4823WI'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEC3-24xxUI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMR4-xxxxWI_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_XP_POWER-ITxxxxxS_THT', 'keywords':'Traco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmr4wi.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMR4-4823WI\n\nTraco isolated isolation dc-dc DC/DC converter regulated dual 4W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='OnOff',func=pin_types.INPUT),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT),
            Pin(num='6',name='+Vout',func=pin_types.PWROUT),
            Pin(num='7',name='Common',func=pin_types.PWROUT),
            Pin(num='8',name='-Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-0511', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-0511'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-0511\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-0512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-0512'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-0512\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-0513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-0513'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-0513\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-1211\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-1212\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-1213'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-1213\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-2411\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-2412\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TMU3-2413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMU3-2413'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TEA1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_03xxS_05xxS_12xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TME_24xxS_Single_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-05xx_12xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TMU3-24xx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_Murata_MEE3SxxxxSC_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tmu3.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTMU3-2413\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 3W', 'pins':[
            Pin(num='1',name='-Vin',func=pin_types.PWRIN),
            Pin(num='2',name='+Vin',func=pin_types.PWRIN),
            Pin(num='3',name='-Vout',func=pin_types.PWROUT),
            Pin(num='4',name='+Vout',func=pin_types.PWROUT)], 'unit_defs':[] }),
        Part(**{ 'name':'TPSM53603RDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPSM53603RDA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia'], 'footprint':'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'keywords':'step down DCDC converter regulator', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpsm53603.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTPSM53603RDA\n\nstep down DCDC converter regulator', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V5V',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PGOOD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='FB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPSM53604RDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPSM53604RDA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia'], 'footprint':'Package_DFN_QFN:Texas_B3QFN-14-1EP_5x5.5mm_P0.65mm_ThermalVia', 'keywords':'step down DCDC converter regulator', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpsm53604.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTPSM53604RDA\n\nstep down DCDC converter regulator', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='V5V',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='PGOOD',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='FB',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-0512', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-0512'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-0512\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-0513', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-0513'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-0513\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-1211', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-1211'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-1211\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-1212', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-1212'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-1212\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-1213', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-1213'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-1213\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-2411', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-2411'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-2411\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-2412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-2412'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-2412\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRI1-2413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRI1-2413'}), 'ref_prefix':'U', 'fplist':['Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT'], 'footprint':'Converter_DCDC:Converter_DCDC_TRACO_TRI1-xxxx_THT', 'keywords':'Traco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'description':'', 'datasheet':'https://www.tracopower.com/products/tri1.pdf', 'search_text':'/usr/share/kicad/symbols/Converter_DCDC.kicad_sym\nTRI1-2413\n\nTraco isolated isolation dc-dc converter not-regulated non-regulated single 1W', 'pins':[
            Pin(num='1',name='+Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-Vin',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='-Vout',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='+Vout',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] })])